(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    926009,      15625]
NotebookOptionsPosition[    924136,      15561]
NotebookOutlinePosition[    924526,      15578]
CellTagsIndexPosition[    924483,      15575]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Array Gain", "Title",
 CellChangeTimes->{{3.414755945462914*^9, 3.41475595157847*^9}}],

Cell[TextData[{
 "This notebook computes and displays the H-plane gain for a vertical stack \
of horizontally-polarized antennas over perfect flat ground, relative to a \
single antenna in free space. The algorithm is straight-forward pattern \
multiplication, and thus does not account for interaction between the \
antennas.\nThe ArrayGain function has 3 arguments, ",
 StyleBox["a", "Code"],
 ", ",
 StyleBox["h", "Code"],
 ", and ",
 StyleBox["alpha", "Code"],
 ". The first two arguments are lists of antenna drive voltages and antenna \
heights above ground, respectively. The lists must have the same length. The \
sum of the magnitudes of the drive voltages must equal the list length to \
achieve proper gain normalization. The unit of height is wavelength. ",
 StyleBox["alpha", "Code"],
 " is the vertical angle measured from the horizontal plane; typically this \
is the independent variable in creating pattern plots."
}], "Text",
 CellChangeTimes->{{3.414755823871284*^9, 3.414755884656123*^9}, {
  3.4147559265713243`*^9, 3.414755933993854*^9}, {3.414755964667012*^9, 
  3.414756129553087*^9}, {3.41475616480317*^9, 3.414756206275875*^9}, {
  3.414756238733315*^9, 3.414756314832082*^9}, {3.4147563530256577`*^9, 
  3.414756496662465*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"ArrayGain", "(", 
    RowBox[{"a_", ",", "h_", ",", "alpha_"}], ")"}], ":=", 
   RowBox[{
    RowBox[{"20", " ", 
     RowBox[{
      SubscriptBox["log", "10"], "(", 
      RowBox[{"\[LeftBracketingBar]", 
       RowBox[{
        RowBox[{"Plus", "@@", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"sgn", "(", "a", ")"}], " ", 
           SqrtBox[
            RowBox[{"\[LeftBracketingBar]", "a", "\[RightBracketingBar]"}]], 
           " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", "h", " ", 
             RowBox[{"sin", "(", "alpha", ")"}]}]]}], ")"}]}], "-", 
        RowBox[{"Plus", "@@", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"sgn", "(", "a", ")"}], " ", 
           SqrtBox[
            RowBox[{"\[LeftBracketingBar]", "a", "\[RightBracketingBar]"}]], 
           " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "h", " ", 
             RowBox[{"sin", "(", "alpha", ")"}]}]]}], ")"}]}]}], 
       "\[RightBracketingBar]"}], ")"}]}], "-", 
    RowBox[{"10", " ", 
     RowBox[{
      SubscriptBox["log", "10"], "(", 
      RowBox[{"Length", "[", "a", "]"}], ")"}]}]}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.4147473324149714`*^9, 3.414747340117215*^9}}],

Cell["\<\
The following cells create a grid for the polar pattern plots. The outermost \
gain level is set by the maxGain parameter. With this display, it is easy to \
quickly assess the relative merits of different phasing choices, which is \
rather more difficult with the ARRL normalized non-linear radial scaling \
scheme for antenna pattern plots.\
\>", "Text",
 CellChangeTimes->{{3.414756784690297*^9, 3.4147570712352877`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxGain", " ", "=", " ", "11"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"circles", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{"x", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "maxGain"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"gainGrid", "=", 
   RowBox[{"PolarPlot", "[", 
    RowBox[{"circles", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", 
       RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"GrayLevel", "[", 
        RowBox[{".5", ",", ".5"}], "]"}], "}"}]}]}], "]"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.414748284864915*^9, 3.4147483326430273`*^9}, {
   3.414748542658256*^9, 3.414748567251107*^9}, {3.414748837811935*^9, 
   3.41474884076399*^9}, {3.414749025078476*^9, 3.414749034816293*^9}, {
   3.414749154537552*^9, 3.4147491554599857`*^9}, 3.414749284555187*^9, {
   3.414749373317298*^9, 3.414749380747568*^9}, {3.414754314269712*^9, 
   3.414754315923896*^9}, 3.4147544094794807`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"radialGrid", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"maxGain", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"Pi", "/", "18"}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"Pi", "/", "18"}], "]"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"maxGain", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"Pi", "/", "9"}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"Pi", "/", "9"}], "]"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"maxGain", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"Pi", "/", "6"}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"Pi", "/", "6"}], "]"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"maxGain", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", 
              RowBox[{"Pi", "/", "9"}]}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", 
              RowBox[{"Pi", "/", "9"}]}], "]"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"maxGain", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"5", 
              RowBox[{"Pi", "/", "18"}]}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"5", 
              RowBox[{"Pi", "/", "18"}]}], "]"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"maxGain", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"Pi", "/", "3"}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"Pi", "/", "3"}], "]"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"maxGain", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"7", 
              RowBox[{"Pi", "/", "18"}]}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"7", 
              RowBox[{"Pi", "/", "18"}]}], "]"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"maxGain", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"4", 
              RowBox[{"Pi", "/", "9"}]}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"4", 
              RowBox[{"Pi", "/", "9"}]}], "]"}]}], "}"}]}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "maxGain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"GrayLevel", "[", 
        RowBox[{".5", ",", ".5"}], "]"}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.414753475522697*^9, 3.41475348333743*^9}, {
   3.414753549267342*^9, 3.414753696135536*^9}, {3.414753750396821*^9, 
   3.414753819918034*^9}, {3.414754016239564*^9, 3.414754282702591*^9}, 
   3.414754414651987*^9, {3.414754580294506*^9, 3.414754582271068*^9}, 
   3.414755747810383*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"grid", " ", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"gainGrid", ",", "radialGrid"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.414752198909037*^9, 3.4147522070146847`*^9}, {
   3.414754343201045*^9, 3.4147543528042707`*^9}, 3.414754419345326*^9}],

Cell[BoxData[
 StyleBox["Example", "Subtitle"]], "Input",
 CellChangeTimes->{{3.4147565318468122`*^9, 3.41475655648203*^9}}],

Cell["\<\
Set up the height list for the KC1XX 4-stack of 20m yagis. The list is \
bottom-up, but order doesn't matter as long as you know which slot is which \
antenna when you fuss with the drives list.\
\>", "Text",
 CellChangeTimes->{{3.4147565713324003`*^9, 3.414756694837946*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"spacing", " ", "=", " ", "50.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h0", " ", "=", " ", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"h0", ",", " ", 
     RowBox[{"h0", "+", "spacing"}], ",", " ", 
     RowBox[{"h0", "+", 
      RowBox[{"2.0", "*", "spacing"}]}], ",", " ", 
     RowBox[{"h0", "+", 
      RowBox[{"3.0", "*", "spacing"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"height", " ", "=", " ", 
   RowBox[{"h", "*", "2", "*", "Pi", "*", "14.15", "*", 
    RowBox[{"0.3048", "/", "299.79"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.4147467999565163`*^9, {3.4147482616759567`*^9, 3.414748280546748*^9}}],

Cell["\<\
Each of the following cells sets a drive voltages lists and plots the \
resulting array gain. Decades ago, OH8OS found that the optimum (maximum \
gain) drive voltages for any vertical angle have phase angles quite close to \
either 0\[Degree] or 180\[Degree]. So, it makes sense to examine all \
combinations of equal power splits with these two phase angles. Thus, each \
drive voltage is either 1 or -1. There are 16 combinations, but, due to the \
symmetry of the antenna system and its perfect-ground image, only eight \
combinations have distinct patterns. They are enumerated here by keeping the \
top drive voltage phase always at 0\[Degree] and evalating all combinations \
of phasing for the bottom three antennas.\
\>", "Text",
 CellChangeTimes->{{3.414757093580912*^9, 3.414757495705402*^9}, {
   3.4147579687650337`*^9, 3.414758285092417*^9}, 3.414758640138262*^9, {
   3.414758775494213*^9, 3.4147589445784903`*^9}, {3.414759595501049*^9, 
   3.41475959836312*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"drive", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"low", " ", "=", " ", 
   RowBox[{"PolarPlot", "[", 
    RowBox[{
     RowBox[{"ArrayGain", "[", 
      RowBox[{"drive", ",", "height", ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "maxGain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Array Gain for drive [1,1,1,1]\>\""}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"low", ",", "grid"}], "]"}]}], "Input",
 CellChangeTimes->{{3.41474668457058*^9, 3.414746777265751*^9}, {
  3.4147469053450403`*^9, 3.414746922105953*^9}, {3.4147469894986362`*^9, 
  3.414746993168701*^9}, {3.414747050886303*^9, 3.41474706589158*^9}, {
  3.4147471546560783`*^9, 3.4147471595428*^9}, {3.414747204281204*^9, 
  3.414747234472851*^9}, {3.414747269739746*^9, 3.414747311131422*^9}, {
  3.414747685657402*^9, 3.414747686847406*^9}, {3.414748362509151*^9, 
  3.414748424965287*^9}, {3.414748494209344*^9, 3.414748556929154*^9}, {
  3.414748654622649*^9, 3.414748717422875*^9}, {3.414748764785789*^9, 
  3.414748765135943*^9}, {3.414748796898699*^9, 3.414748798321002*^9}, {
  3.4147488770687103`*^9, 3.4147488993898697`*^9}, {3.414748942727558*^9, 
  3.414748945605701*^9}, {3.414749260250078*^9, 3.4147492638159313`*^9}, {
  3.414749310563262*^9, 3.4147493534354143`*^9}, {3.414749532205264*^9, 
  3.414749536508419*^9}, {3.414749577779962*^9, 3.4147495785222273`*^9}, {
  3.41474961160553*^9, 3.4147497316875677`*^9}, {3.414758303815454*^9, 
  3.414758308446959*^9}, {3.4147583893710957`*^9, 3.41475842868291*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwUV3c81e8Xly3bxb2uvbL3ns+HokE0KaWkVCQjKVEZWV8NUQghlFBEw4g8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      "]]}}, {{{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], LineBox[CompressedData["
1:eJw12Hk4VP37B3BtluKxhXr0oEgblSUheSNrKSVFlpIlovBk6ZGUpY2ikCxJ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       "]], LineBox[CompressedData["
1:eJw12Hc8lf3/B3Ato7iFULdCkRbKSEheyEgphSKjZEQU7oxuSSmNm6KQjErI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       "]], LineBox[CompressedData["
1:eJw12Hk4lF0bAHAG80xJZclS3rIUbQq9ZEn3qayRijYvSSJSlix5o4WyJ1I+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       "]], LineBox[CompressedData["
1:eJw12Hc4le//AHAjezxGRh+FIi2UkZC8b7LTkiKjZEQIn4w+khKpKArJqCQZ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       "]], 
      LineBox[CompressedData["
1:eJw12Hk4ldv3AHCSeTq8iZCkEpcmuaZi7UpFJN1cSpkzKxm6lKQylCJjinQN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       "]], LineBox[CompressedData["
1:eJw12Hk8VOv/AHApTEl2h3IrFG0KXbKkz6OskYo2t9JGStlJ0YKrLIkW15p9
SdZBhIqMJXuMbJFlNGHsO9l+z+n3+s4/M+/X68ycc57nfLaRuGpjZM7OxsYm
vIqNjXz//5co+t8neX7thpUVAgkc2/jPaJoFuGiJapGO3Ma2ZzTNGZYj75xf
xla/eUnGgeYORyWuCC1h93oGO4ykecGZhhabBeytxuHXboY+A9+c71bz2K97
9o7Z0V5AbtPNDbPYf/XeGNibFwiiao9PTmHHyEy/GEwLhnNjew6MY0/uPNb5
Ji4M/FZdKRrG1r3Ool0LjQCl+xKsAWwFWamwAJ1o0LCxfs/E7j9sJWhFiwHO
QR2ZHmw2xec6R9XjQH9VukoHNiqrkJPJi4eH+lvxDRJoW60Vd3faGxBI3oOq
sc3qjMc/7HgL1nNlHaXYcu6HnYLjkuF2ZdRSLrbtZll0LDQN+Dy63TOwLSNj
XWWEMsAzKD3pDXbQ0tooNx0qPDGc/BGE3VlqHW1Cy4Q7+y2HnmEzM1oKyh5l
wcKMdYQndpKs8jN59WzYnSrZZ4t9+YWJISXvHfy35YCYFnY3t/14Ztp7SAKJ
gyrYKcGDLptu5YGQd9gqWWxtpRMJnjvyof2kmqMgduzjUw2n4wpg8KzaXPsy
gcZyIxUnQz5BNMTvq8U+L1buZHKmECymItYWYqveqoEiwSLwy9JMiMRemp7N
0tT5DGcMr7uex24KmfrGTSuG5isXvuhhV97cN/VxKw1EDjNzDmDrfm+ssXpE
g6x/qS4C2PrFQfF1B0ugXkQxrmSJQL/mqWV+70thyV3NVgj7X/+Ip/OpXyCs
6MSv34sEynbn3v1asAKGFyJGurF/MvQuHHKpgLWGjJwUbOntPbfddSpBuXHL
loPYToEbBdkZVSCU0n1BdwHv78MvrYMidVDdmDkjg01ZLZz/5EEdSJ4qkeTC
PlrRyiPxsw4ic9/Kl/4mUHvbbZ5TmV9hcihwlwr29XW5IW0J9eDbbe+zYZ5A
dNqC8i5EB0XVQJ2+OQJl9lR22jvQIU2VLaQIW1RPRu5DIh3uUz6MWmOnyDIb
jvI0gptcvUvFLIFu6dFmzb83AqNfgs1iBq9vb/qKr2MTCEYL1p6cJFChlWCQ
T1Ir+Gksnt+KfTDOPe9yayu0BJ1+OjJBoMVvtc4HKG1gde9itQ/2VMqaql6L
NihXaa3/ME4gnhnupAMy3+H5tX0TPGME0sjyjKtOaAfTG5cDLYcItCkk8HJU
bCfUOy8pyGIb5m1Iu0HvhOlpafvRQQIdWnj2UJ69CyzFpOj22NHaMWnFV7qA
fqxd1IlFoKw70YLWfN0Q9W0XzaKfQA7Xam3vf+2G2JSApxw/8XoY3tp8/RgD
1i5+SP/Ui/fXTvtplRkDVM8cveOE/Ug/OHPvfewHLyZ6GQQyObF/50wyA+QO
9Ed97CFQqcTjAndKL1T0UesudOF84EIQT0t6YUNiiee57wQ6d8Fa00yFCZxm
Zkoc2DrhOgpFJ5iw0cHPL7ONQMnbrtaJ3WCCqY+z9Frs8pYp3rogJtxb84Pv
XQuOX/2ydIUpJlRv4yie+0YgmZ8F64fSf0G4HX+I+lcCae5waxHf1g+XqY8a
musIJGIYl3ldvR9S2R9G2WAXhF7bTD3TDw92KcxH1RKIc/9kmoYP9nBK3EI1
gXbXNYZcGumH7SlPmiMrCHRKokblSd4A7KDqFAcW43he9vd1NRgEulWMOGQR
aP/pxQfD9iMQ0vxaoTyTQImMr96WviNQyOU8aIA95he6qS9mBAwOfNUyoRLI
fD6ipbN+BBx1j0RYpRPIrtcoqmLvKKRVM1o9kwk0nEoVf8waBZlNAc+tYgk0
39wZ/5U6Bi+rKu13vMDxYEWXkpSZgN+3YxNKrhNIWJXi6mE4DeI0KadXSgTK
MdzCKXdlDgRcxJ7VrSYQn3iu0y/lBTDl/Fx8p1wEhfXV+vloLwPVhcFr4iWC
XDo6ktX92FCOVIEkj6YIsh4uzJNgrULu4sGUtdPCSLUsT3n48mpkFibC+zlB
GI01iLoW5a9BOhUmPc16wsjhOHGneicnkhgaCU0eEELbKYp3hv240CxYZNF8
hZAYBx+vJp2Cvk/wcx3aLIQWN+t8Md2zDv0t5ZZTny2I3FqdMz/d4EZU9js5
q9UEUb3ViD7r/Xo0vGX3xZVCAbSeckO4b44HZdmnmP6nLYDqGBQJujgv2nGv
kYOjiB9JdgjfvraDD21qkvLpUuNHojereZaz+ZCL7SEfqfd8KDHg2zG6Mj+6
t5MuFC3Jh86ltoceLuVHCrna7J0yvMijV/Jqt4YAEvilYTQ5wIPUvNtGZkoF
kKgPZa/T2/Uo9GPyVQskiOw9pFZMnLnR+IJAR366IBLa4Enrl1qHbDMHe5a2
CqHkqeHFM90UxC1qmeb2RAj9muyq2xXBhT46HRQVYQoh0yD199LKnGjiHF+Z
qLYweslgdFgz16BmZ8Ec9XBhZMsZaOZmuxoJN3InBo8LI5HNFrVqvOyoRXzd
22cHRVDo+31VHlQ2tH6M69MbNxF0dWt869ZLy3AiMb7OshTvm/2WxEbvBTCW
FXTrWBJBcj5ffCWt50Bo8mBiviKBThzSfbHh/DRse06JX4+fG83mrcbOzhNQ
kMHhpfGMQO5KGfJMywmwUli3pgvbg9Pgo5HpBBwvzBa+70+g+t1BzXu0JmCp
hDXzLgDX4bOZ238ITMCTrDCqxEsCFdnsvbw3fRymC0OXfwURKO3RQEvgzzGg
bFWa2BqN81SYccVi9Ah8j1F/cxLHhXvNIe7LPiOwLtfleTV2ffn3bzS7EdjQ
E7RJC8eVmdHrpSeHRyB13Iw4kE2gv3u9M9b+HIZsH6kEkRwcl6PSfXPSw0CU
PiVK8wgkAXVK7qmDoPzaVL+1iEBcpu85mgMHYfifydvan/H5qRssdj0YhOhk
Wbl32JYCboyGY4NguNcv3B/HdbbE+/JNoyzotCvmgBKcpwPKg8LlWfCDL1ja
vxzn6ViN/mO5/eD1zc+fWYPziGL6Jp6ofpCoyZnUwnlkZs/G8WqvfqAIriwl
YBNWxv/qmvTDraahVeZk3nFfdVx9sQ8Wr/N86cR5KnyAvUH4cB+Ir9mpVUwn
UEdMyLBnLRN4nh/hOtxKoBIRfh6VXCYc1a3iCcb+ERffNhTJhF8btfMHsZMb
3VyNbZngt1p05RXOk1MWFYPigkzI7Vil3Y3z6tHjNjXR537Cp6m2IosfBJLX
lF+y7mXAJNI6r4DztopE5PxfVQxQpyiqeWB3fwyNqaEy4J1TbUYD9suTa2Z2
PGRADnXijA3O+wd3i336IcoAa97+1wm4Tgj93SqjbNgD5ozjnMu/cF2vMhKz
sOsClg27timuO2GT8+mZh7pAMdk5LxqbtaKYt8DdBQoBt4sY2P9cXtzhn9gJ
Cnn1vua4jm3jo75Obf8Byd5XievD+PvuOwPrtTqgxiKL03gUH28ZsFIg1ga3
roQodeC6Sb+9ceQfVitUNLHSeXCd3Tuz3fV3QSvEP31ceQg7Wi7eQflCK7z7
+JwZhV0X4TmREdkCe3wH8i5OEUjvu1DVM6lmQEprar5MEyjQ5+WszFQTNNH/
vTGJfTJL5mtxaRNY/4PebMZ1nnLx4aMp8yZQ9rLidsQWapGeP530Dfbse2K9
EfcFeq65E2tlG4G2Z1vUadw3VIhGi0Yt0cFMT/qSK3aivcrU/jo63L15vjga
WynoytcLNnRQvn3hNgtb16FxZ0pmA1xvfnvhHu5TIsui+NWU6kG1dD7hMe5j
tDU8Bqo56+FSEss7AZuz8DxHfvpXsCY4N5Rhjy08m50fq4PzyQXL7LgvSv/6
WvWOUy2ouvG4uGDff3PEzeRhFb7+6ZazuM/iPIAiHxBVQHm1muKIfTJEVzOG
Wgnrw6orA7DnrnTv62NUgHKEF3s5Nte/zDwrnS/QuRKjK4v7vDr230f9u8tB
4pI9pza2clqPQ/q9ctgzNXfaFDvJ2P/FcEoZeLLLJD/D7qSIylnwlULg5G/p
PmyFCbdUz7cl8FzJzn4Re7TFsy7mcAkk3wg7zo/7zLyY4nXtjjTwFF9TpIJ9
rqw6WK/tM3QW77J/jC39V6Wjmf1nmLXeqx+MzZmyk/MR92c4eoSRk4Q9oTEe
dt21EAylTFAVNvMpoSmv+QHiXF13UnAfnbGzOOXqnQJw4Z0LEMEuPEULfZWU
D7bukt7bsB/wBhJT6/Ogkc1NFrCr2SvTpeA9FL3K+q6P7XF0c7uRXS5U8r4U
O4c9mz2xitr0Djh+njGwwc7SbV7dyfUO/BvUkAt2MhH3lls1G1j0mjJyLhi6
UDxqHpkJL05OPA7BtjZ2Dn5ZTwV+xyefY7DvenaNF7JToWKqzC8ZO8RgS7hs
XSqss9P+XoBN17yb6qmQAvESXudp5JzV9QW1B70F/zB760psaqr9JfmFN3Dk
A0WwHrsN/eD1upQIquZ6es3YDLnbJh0l8cBw/ZufnJvGBD2PyO+Ig7c/Ky3J
uardw6fpsV8MTD9Ze+YXtqwcTfZdTxTsNJiks7DZuzr/upD8GuK3ePWMkHOJ
gYLvaodQKBwpdZ/Arsp57J6sFgS1SanZ09iXTGIFTq55BVvhkPMcttRYbMhI
aACwJ9yr+Y1tlJTnorrbB/K/mmYvYttfFR14/NEDvHKHd5Nz6MPjb9ljw+9C
kpG0EjmnfsvJv79f5S7YeNw4SJoeSZ0pbXYGducXh0lnvDNm9fE7g3d6sCFp
Rw6XellvJxA562RO2n2xUq9ouxMopg1bkuYrXF1yosQRNlcY2JKOlVbKcVh2
ACODIhfS62djQvId7UHF38mfdMI1fX59AXtIW7ftFemw5h6fjgw7GNLPDybt
dbrFZYVlC9XiIdGkqzS63/vSrIFzTjqTdEGJWFLakhXUh3HnkBar2h9Sr2wF
ZuwteaRnbdbfFcm4Bawtkp9Jq05eV4oNvwFOgT61pF+0F2wva7aAlxfj60mv
+zwt1M9vAfcGExpJq/tITcp6m0Pi6YttpJncoowTJWYwJC/YQdq3fKbeYfka
LNMzOkknjjql5ztehYfXInr//N4iEdGRcQWGjUaYpLXuv3m6wroMMlzS/aQP
Vkg1+NJMYf6T3hDpE4MdafXKF+HlZ8UR0l9OO/uKZJyHaS/KGOmQy2eOxIaf
g43mVydJ15yK3NLPfxY6XAam/tz/WO2CrPdpuHH67AxpK7a+FodlYyicSpkl
/Y57MDvf0Qg6z/XNke4Ibg9YYZ2ASve1v0nHMx1bfGmG8NBGYIE0p5ZAgEiG
PixJsC/+WW+Tl9qx4bqgHdr6xx5Gujn5jodBuVll+c/1XbyiExuuDH8eL/J4
xf+wd8B/5HKT6+EbaaByr+Dg//5H+T8l5GVh
       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHASkmSIY9jmWRlL3VS37yJjXGVoQCmipAF1dU0XJfOYzFOS
JCWzlHmWMoZShxAyc0hkfNe+7/Pb/+z9efbznOesddZ3OmLWDsa2W+jo6Hjp
6ejI+/9fguh/TzZXPd5tbhII5QiPq6deA5sMmhRpNu9TBeqp7vDvmws8G9i3
nmoyqJTch56Mhtg17MJ6ZSpKDYZDf0tnr2B3atVLymo+ADE5r1PL2IN5B+KU
SqLgeWt7xCK2geXK2wPycZDkQFyYx37AkOL1Z2oiXOG7UDWDnWSR8/kY9yOQ
/JRYOIFNx2lJldR8DFGlHYdHsTm2ywXKbKSB2Ce604PYb102J+VK0qHviBwD
Fbv7T9mNPbcy4B69/rEe7DuHJ0oU5DOhfIs7XiCBTjmcYlNOfQE8ToHONdjN
jiHxyubZ0P34AX0p9iV1lwJl7hwwqQrvzMK+vlb3llczD7imfXnTsO2owtt4
xfJBy/zObBy20vrATspGPuj4aZ/1xc4e2XN4V0khXHggPe6GHZy2asYZXQRu
zvRsjtjxQdWS7LeKIeB2JpsZtnZXeS6LfAn4nKial8JWvmSuufKoFBJEPAg+
bF2/cptFjzK4oaf6iQV7bXwvZc6sHHYHJTBPbRBoLHFIeHhXJYwd1jJ4gW0d
naT6/Vg1HDo+sSMBW3R42xfL/GqQSA69GIA99DDk0BfRGkiXaq+6hP1MT0y6
fb0G3uYa2PJgG+bfcil5XQeujZPldNg8GSGNKtL1UPdP8PPJdQI99zSoy4qq
h5WZFrUq7M8HGKsSnRogOcHuqA32oIvhA9c9TbB2Xetz7Bper/uQuMSj96Aa
VLDDDXuteog6QPkAE0/Zqi2wL+w7TUkJ+wBFjAHPhbDPvGDapHi2AK/YU9fE
VQIFbHl0bcv5NpgSZOL1WiGQN4vIuGVoB9SIuR03w65TN1BXe9cBskPf1/di
72nepbuLsRPYTiUOD/8mUJXc7vMNHp0gWJmdp4EtvsPLX/b6R1hiZNIfXSLQ
oxKp6a/Hu+HhjLxnCfZvlZhXuX7d0Bx/SiUIO2m3D5tvTTeMBubwymPPXwh+
JH+oByZCk4ev/iLQepb1rztyn6AgXMa75SeBblo+9lpi7oXrIzF1qjQCbaO7
fj+1jgqtj1d5VucIRIyrf3Jco0LGl+9LVdjSEo7FSLUPNq01buhjJzeZU749
6YPyOCNhi1kC2fxk06T49MPHlJAE22kCrV5hay4WHYBaV8ctMuM4Hl6dXqb2
D8LtYpnL38YI5DOZzF6+Mggp7+6Zx2IPy8h+S6IMweq87CIjdkCF7lMLwyEQ
VT413zdKILegiOru8iFgX1Zhcx0mUF7K7OfSpO/wY96jxeIbgVz9Ol0MzEfg
4qrvL2bsEKXOpRjnEdBkf1lY0E8g7s++koMRI+BwxXSOBdsu4LLv340jUBKt
ZptHxd/PONEsVnUU7He6ak/1EoiVXXvuw84fwBmrNsfZRSCuau+VnzVjcE7E
uTL3I4E8g0xsVfvHYEH5t8QJbKfuRsfbv8dgunngZVAngcpX56/MKY3DkNKZ
irV2Ah1XGH0/kjQO01nKgx9aCKS4/cvOijsTsD/nqopQI4FO3OfJENs9BQJP
KvWeNhDIQXncNU1nCpqyy4flsbf2C7eK207BD7+3aYfqCeRfmrgoljoFZbBw
9GQt3i9Hg70ClGl40aizcqmSQKEdfDM0+hlQWpYNUXiNP8/T6MOh3lkQpbvy
WO8pgSyp/wZur6UB01OriLJ0HA8zElIV7TTYFljEpYQ9dKTOzamfBj5VTh1c
TwjULi1o8uk3Dahyrn90p+Lzn6OV/0h5Hn5qFDzTSiJQEPuVVfGUeWBYzJDt
jsTn96QZmndZADreGOUcTwLt9nLueqawCK5dkTFqfxGo9pjqobivyyDKtnme
nodAsiptedZOa1B1SfdEQ68AKhfd3Gddswk3mS/+sT9SAAk0ikdKPadHLWoB
kZG6Auj7C/p5HUMGtOGpaMK+wo9eVPa/9BjdimJ+mX/7lsyPaiM+Xa9MZELN
lgmcF9X50czPJPbtituQCffRc1I9fIhpL3HhxlcWJF0RU0Cz5UN7VB8WVrqy
otTmFreDS7xonnHs8onFHWhDayI/2YUXuf/u/JM/cCcq+2jveXuNgpCMVfre
FXbkcrbQ5L4DBb21T6VPqeJAUSvnYrv6eVDe1k4xqjsncs+9NXPWmAc96Z39
U0qaC5mxffBTLuRGsj03Td71cqFUF1NnJYIb0U7csM302IWGFYRFTb13oam1
fxhTeblRie9xPo6PXIhLz7vgr7fcKBme98TIcyHeQlmhrwY8KIgw0pK4zYnm
hE2qm0d4UPrKfUalEg6U7ye40OJMQXw7du9+xMiB4turvH1+URBvqebBQ147
EcOJMWqnOy8S1K3qeMvIhtgEjZrRPC8KTTKn5YWwIiZVWkP8RT50U0loj8IU
C3LgehjR2MGH6Aq2naG32oYkrdRNhPbzIx/mLaKT2Uwo7j1b7Nd4flT313Jd
PScjyhAbnD1B40d9dKExcS4MaGdcf14tEkDDXEUf/31Nj/Kv89A6wgUQ5Wzk
+3Z2OjRYeC26p1MAlTSPPf7Xew00GmjqDNz4nC54Pj88sQy7Mwu5bQwIdPJE
RvDF4EXY+pdKk5gbgdTtDdiLPRZhd0Tx/V7s6XMMKqw3F4HZcq02wp1AQvty
ThSeXATj8LLmdQ8ChY8a0m+hLMK8W+FyhxeBtisccAxO/QlNlgUfrX0J9JP7
sNHZogXY3j7uIB1BoFd1ys1jfTSQi7wVp4rjQn9JLU8cx4lVl9rHGuz0FC+j
czU0eMCknHoSxxW7cmJFawYN9BxS5+wzCPStl90o14EGGaKm1xIyCaRT3ON3
mZ4GjuwSDcMvCfQx/a+iVMk5iGWN3yJThOu0AZ1iJ2UOuCcIr2fYPg+aLjOw
zMHlpKBQmWKch6sm9jZ/mQWLYImL0jiu14y8ufSvz4Ki+Q6q8BsCGa0f8d0f
PgMvHzIqrJYRqHHssVpu1xQsLBlKW9URyGx88Xj4myno4DNN6sBuDkyZuZEy
Bd+QaaY6zivam8EzcnZTsL589J4ozjs51+WpSauT0JEW/mcvzlNBHIrvbopP
guiXnPYD7wnUU0atrHcYh7edrefTOnAen304HGs6Di+eUyIYcR78dDU686ra
OFiLyJy1w9Y2oHDsYBgHya1Jz+Vx3kxqvWpnEDMG3T0vjXJxnpX3l48vLfsB
1HnZoiefCBTWtrPzNMsoNLxvrzzURyA+j4NPWiZHYL6/fDYWm4m5n1OzdQTW
CxzSfmJ7F+a8U3o4Ap4SRMRLnOed8ufztgiNAD2XTQhlAPdJP6R7Y5SH4f3e
88wfhwhk8UtA0uPMEBxWOLs2/YNAAq2cGT/UhuAobeDuYVyHFrxEeowFcd15
thEYgK168KGG7OAgRNxdEBPDdY2n8LJFm/0gOD1KdjSYIJDmAT56dk9c9yTa
/YOnCFSR4eGVo9sHxoLM0S9w3Vz0fMdjz9kHV39zGoxgB/88fUjyCxWQS0O0
MK7Dtt+jVGKvUUGGKjsYjl1vrTX3T9hX2CdWeubGPIGyNmquSXX1gj6Y1+7C
dVxe31u/N6kXDN/Hp2tjWz5laAyx7YWeCmc+V2xV3oqo+V+f4XrT5msqtsbJ
7LQ3/J+B5Q+dnpRFnJdHurQOXOiB0MDNsJ24b4BbtjrDMj2wmPUy/hB2NeOx
+Qdz3VD8dOLAZfK9ko7O1N1uUPekyJVhd1mIMSWndwGOxSnrZQJ9Lw2Pmh3v
hHh2w6lE3MfIGNyIiMvvBAGHMpFq7F5F0WPq7p1A15A3MoJtIGvX/mBHJ/AI
Kskp4r7IvVU5TUmpA+J5bMPeYHPOGFaVj7VCtZBeRynus/ai1IPljq0QuGdr
IRXb8tymZNlyC5Ts46OsYz9u9LUu2Yb7siHds0dwnxZQy5qdJfsePm+WdRVi
z2VLbMnIbYYMfuX8DmzKcX9q6sFmCGxc2jmDPVvcLhet+w60Pt/TlsJ9IkNR
g7WLXSMoCLplh2KPOMQIO841wAb3fd8MbA2jOccrLg3g1NZPrcA+/WNw0DSg
Hmbf32eZwT5ymU9lT2Yt+Pzhb66N+9Rsg+g+EeVauHOXVcEC21/nqwp3SQ3c
NezzdMAW57T+stpYDX4bV1JjsAdaHNvC2irhKAfH137stNxiodvfKuBN2a9n
s9j91mz9p2fL4ZW67M9N7LIy+QZB9jJ4/MJ+uwjuw6cVon9tCJdCIb17lwJ2
LL1h1oDiW7Dn6hY6gp3qMfcyzbAELC7YKp7Bdt903epj+RqkRRIXL2EnJj6c
s75ZDKWp/EfIucBuqjhWLKwQuljmtP2x6UMuWtClFMBVfx3WSOwQgS91/dn5
MD4/apiE/WrKIyGhJRf+6F0zycE+fjJEeO5tDkSt3eIpIees+0fvZH3JhlVL
5dNV2BJ/52rarLwA1y+qlCbsddF7kUICWeCg732qDft8mIldj1omBERwcZNz
03R1XWuYWQbUB00akXPVqVrnVm3XdLgtxMo+hC2QxOS4EZcGyopO+j/IOekM
b1lRSSpMpAsxT2FzbY2405ubDP3XODTmsHlNnaa05+IhwUFvbQE7oZxrskAp
BlZSmvYvYdtbFfqIOkSCwmTozG/si3Xy4fznQyFbJ16anDOVmmjhtK++oJs1
0beOvWuv49nIIg8QYL3HTc6p4qY+nGUaHvBJo40gffyNS/NImzt82r4pTvqD
8Y4jahNukKLPpEKaOe+70ICwK2hGFOiTVjei9LC8dIFdx3mMSdttUwrbp+YC
ElFmZ0lfuce94WfyD2zvDbQhHbZYRlUIcIZpqUB30jF6ClFneJyh2WrTm/QF
N3/9u2l/w7jCWT/Swmqrb7rKbsP0nbwI0sXu09HuNCdg/rAlnbR8/huDp55O
MB8YmklaLfg2QxurE4h8XnlJenUyz1Fc2hEOS/1bRJrfqSUqsug6BNwTrSct
R2dOP9p2DbxqKptIs158d0Ntwh5KItU/kBYUNdUeEL4K09+nOkkfuOSUv0/N
DsZtKD2kl444C/ubXAHZO+K9/+2HhuovhQBbsNMb6if9+iTN6m6aDdizxgyS
ziiNa+kquwSvzssPk25RzUp3p1nBcj7dOOmZfRSONlYroCs+Ovnffug4uotL
XwRdvQvT/+1/w/CTyKJz8EhUl0Zas+Sgm9qEObyw4Vgg3aTheHJA2Ax+Hyz9
SdrLO1Ta3+QMBCTr/iJtfDByTSHgFJhFliyR3qPi3dlVZgL2vKy/SS/6mmW6
04ygXB6tkI5fF/EUlz4Jxp1nVklvrch6FllkADLbjNdI7zdeMh4Q1oOjrYrr
pGOL5DYUArQgRnLmP9Pd0XruTlMHJdaIDdL+GkmZkUVHYDt5/Mh4rPiMLQ8+
5M+BvePxpd6aoYoj//uf5f8AtE1S4w==
       "]], LineBox[CompressedData["
1:eJw12Hc8Vf//AHBURsgeRfco0kIZCeH1JiOlJUVGH6GIwscqodCkUkiiksyM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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHDVSYakY57ZLoW4RUoR34VISokKxb2IJheRIZSha0hJSSTk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       "]], LineBox[CompressedData["
1:eJw12HlYTO37APBCaaOFtGqZQ+qtLOlto+4HoUTy8hbRinaSeIukaCGiVZRo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       "]], LineBox[CompressedData["
1:eJw12Hc8lf/7B3C7kmSUEdl34tMy0kfF9dagJGVUyEoRkRmlbBnZZZSQLUKl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       "]]}}, {{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.832885283134289`, 1.9101299543362336`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.336618828644992`, 3.762221576582356}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {9.526279441628825, 5.5}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {8.42648887430876, 7.070663706551931}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {7.070663706551931, 8.42648887430876}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {5.5, 9.526279441628825}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {3.762221576582356, 10.336618828644992`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {1.9101299543362336`, 10.832885283134289`}}]}}}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox["\"Array Gain for drive [1,1,1,1]\"", TraditionalForm],
  PlotRange->{{0, 11}, {0, 11}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.4147484705278997`*^9, 3.414748496425335*^9}, 
   3.414748531244379*^9, 3.414748576413869*^9, 3.4147486659644203`*^9, {
   3.4147486998820057`*^9, 3.414748718840427*^9}, 3.414748766596281*^9, 
   3.414748799905353*^9, {3.414748878872445*^9, 3.414748903326495*^9}, 
   3.414748947212563*^9, {3.4147492979203672`*^9, 3.4147493228601913`*^9}, 
   3.414749355002654*^9, 3.414749385762484*^9, 3.41474958117518*^9, {
   3.414749619952819*^9, 3.414749733099772*^9}, 3.414754361145783*^9, 
   3.4147543957237263`*^9, 3.4147544317230177`*^9, 3.414758430464425*^9, 
   3.4147584692586813`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"drive", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1", ",", "1", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"PolarPlot", "[", 
    RowBox[{
     RowBox[{"ArrayGain", "[", 
      RowBox[{"drive", ",", "height", ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "maxGain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Array Gain for drive [-1,1,1,1]\>\""}]}], 
    "]"}], ",", "grid"}], "]"}]}], "Input",
 CellChangeTimes->{{3.41474668457058*^9, 3.414746777265751*^9}, {
  3.4147469053450403`*^9, 3.414746922105953*^9}, {3.4147469894986362`*^9, 
  3.414746993168701*^9}, {3.414747050886303*^9, 3.41474706589158*^9}, {
  3.4147471546560783`*^9, 3.4147471595428*^9}, {3.414747204281204*^9, 
  3.414747234472851*^9}, {3.414747269739746*^9, 3.414747311131422*^9}, {
  3.414747685657402*^9, 3.414747686847406*^9}, {3.414748362509151*^9, 
  3.414748424965287*^9}, {3.414748494209344*^9, 3.414748556929154*^9}, {
  3.414748654622649*^9, 3.414748717422875*^9}, {3.414748764785789*^9, 
  3.414748765135943*^9}, {3.414748796898699*^9, 3.414748798321002*^9}, {
  3.4147488770687103`*^9, 3.4147488993898697`*^9}, {3.414748942727558*^9, 
  3.414748945605701*^9}, {3.414749260250078*^9, 3.4147492638159313`*^9}, {
  3.414749310563262*^9, 3.4147493534354143`*^9}, {3.414749532205264*^9, 
  3.414749536508419*^9}, {3.414749577779962*^9, 3.4147495785222273`*^9}, {
  3.41474961160553*^9, 3.4147497316875677`*^9}, {3.414749770514632*^9, 
  3.414749777009856*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwUV3dczd8bb++9Jy1ES0mD8pwGRRkNFFGESsLXigYJpYxoyGiJpko7Ks6N
ptJet33bu3u7t26av/v76/N6v57Pecb7Gec8iuev2V5kYWJies/OxPT/r3OI
h/PyGyuC/XCe2kTlRUwW3Tv6W9WY4GYxUChYEYMd7wnY/lTWJ9SNLnxLaE3G
CuXcYpFxuwhrFdjJlDsT643lH/fbrE34TzpCZGE4Gw9kSfWouGgSov5RZfRK
cvHsft8DuvpqBInLV0+mK+fjpoZq5eFnqgSVRziOV7sAt2itOMQbbSWIkcLS
cskF+JdTcFLpLhXCTSGR+4lXCvGBsqaW/84rEc7vYplPySjE+ZeKz+v8VCD8
PaU4yVZUiLWOVza5399EWJKar+55VYgbRl/7yGJZQvVC5B2/fYz/pcx6Du2W
JtCQofzz3wU486I9RyZRgqD68nWsjnIBFh7Orz+XLEZwvv/psZZLPhasbVx8
/0aEYFCmcH/WLw+Pb+f1PpMsRNjlRdB645uLA/zPPU35zE/g1dCsED2bgzs5
3JNPavEQcj0P8alszcavtApblsc4CEQlA7+C9Ezs5k5vvfKHlSB4mL36WFc6
3vNmgFWyhYmg9NvD/mdvCtbojHbNXlvBp/z/FHoVfcYvTrXNDkYtYlz790KC
x0c8l8v9esaDgokKL8P6pj/gl9bqFdxT43h8+OBEHI7EUu4nWk609GEhm0vl
DnGhmHmm+PVH5Rrs6v1Na8j3DuYQ2nVUaSoPhOqd7o96nYf2kEK5PUJDEENY
jnzdGA5h/x1tOTY6CextjRfYz32AbaeU3kXtoYCL39nXR4QTwdOyJW7p4hKo
KjlMfpb8AocjAnuM/67AorXIk7bir5DYz6z4XHIDzhrv5KIY5MLYQ+W3Zpks
6K3FBZTBWwR2L7v31u5gQycrT4T2P/wOPi8/HDWKYUcT2eOlqxsl0C7tOvzH
iQuBD4eJYAgBeP+NDVx04UfCFfSKWUIFfDOeqrMKEUDpW7sor8SrwGWULdAo
TRA1fz8Rc+9KNQz6vmLOHhNClVh6h7NCLZgEqfnyeQqj4DPPW9b96sD8dE7T
rUlhtD+99+KO7r+QNWA129UrgjoKYpmLDzfC5v1i6fy2okh/iDk2dr0RqMa5
Fwt/iaKKuUgr8tcmWJuxiix/J4auZEb5hom2APvDc4ICihKosVM71renDfZY
LdumBEqgsTrniqjYdngynhn2d0ACKYQLpN482wE2/EvrvBGSKPB4ZKtUfye4
6TzYbTEmiU4LJn/5GkcEncfU0OMGUqjPxexw2pkuuF1C+bOtSQoFSh8Mu0js
Bv8I+3ZOaWn0ZtAYL0X1AJZYOUk9I42c2esbwmx6oVfJVlW+XxolqSh5elb0
QaO7Htc0lkEbunanP9UPgEXrt0onigzyMjp/OG8bCR7ZR93ZoSCLivamSYw9
IAHXvSyflduySE3DpjpUYxCUbk5K8cfKoi+DrgODgYPAssG//22ZLPr6wFhN
q2MQHs5UWu5ilUMSKz6Ct/yGwNb84fYjCnKIHJBqZ/93CDJzE7KX9sihi04g
tyQ3DIq/Au/q28mhUwke7Haew7BYGvZLwEMO5dVWvXL4NgwfeB/eC/STQ1fF
nZRXWUeghuPGrjcv5BBTxWVW7SMjEJ31Y9fhGDmUcODIick3I/D29pcr6aly
qCbReJNs3wj8JzATkJ0rhwqprAaFyqNwkTxbfq5YDtm7pThkuY1Cu8AaELAc
irRe51lMG4UFXuPMv7/kUMv7nZkPJkehbuW+37PfcojjqMpV4+1jwBo70rxc
Jof0R5oPKV4ag6yfl57J/ZRDlzcF8cp/HIMYJxV9SpEcSlFdRkpdY5DbGCd/
76scqlB2NVESHodjVgSj/M9y6GOv3RaBA+Mw/r7MMjFaDsU+eFTefncc5DaP
fzF9yvCv7FrulbRx4H4nFxR5Rw4Z8BH3EDrG4dHZUxlvzsshtwbxs2WsE/DP
cjHFwprhn8iev84aEyDzrLQgaZcc8pIXGg21n4CP7sPlWVIM3NeXpX1vAuLf
dd52WZFFmU7LTaYfJmDPXLPUt25ZNHpO5l1G8QQEvT2YkftdFmltujnu1DEB
eurq3dZRsqjW9JmhCWUCUs/MLgdelUUiOX+iDnBNwhaWs9w2+2VR1p3SV45y
k3Dht0l6rrQsundu3eSSxiQovvqh8mlKBomuduxz2DsJ5OB7LvIlMkh9340I
mQOTIFIZPCj7VAbxpaWWRB+ehF+87H/e2sqgvyOeH77bTIL+wLW6FzIyKM8y
846H7SQIH8jRpjHqOaq9Zjzs6CRoJTU1lCdKo21hl7vFDk7CkWU7jqXz0ojn
b71f/75JeNJNk2LZIo2Uj4mpDWlPAgfhq2/hsBRinVfh9VWchPc85Gr+RCn0
zj9g9RX/JKiYB+xkOiOFuObKNAUWJ6DnD77xRFwK6WVpSnV3TcCJb37dkbWS
KJY/xbO/hMHPHa0x9Z2SCPFs4dl+YwKi9JeTP/ZJIL7x9CeGFhMQ0R3//W6o
BNLfPJwrKTUB+ssTfZu7xNGnb7s7qzPG4TBr7oUOf3EkK8tLPXt9HH43fREm
bBJHL9dfD1lqMepBSlB2+qQY6q1Uk3sdNwa8cUGbhcmiaELM7EzqkTEIUaoL
3PFEFIlr8hs++TcK1nrf2GlJIkiqSvAled8otI281CzBQmh007X+2kfDEMtt
KnPeWAiJ5HbaOLAPg/pMxI/kq4IogU2oTz9gCLIvkJytgR9t27Emyn1uEBLR
gS3Inwsdqqi40xnWDyk3nrRc0eNEroPhz3bL9MGlEDVX3lF2FIOBMBjeA7dP
8hzS3MaK7ue8WnG0JkIBj1Dk6KFl2KM6k6hf0wQ6HjJuDmmVmJ31+rlRgQT8
cO5w67BZD56UVKC+VMnHMntoDm8nR7F1h6bfmSsEnL2fT8zsFw2LVJi9y5Ko
x1ekLZozRtgI93PCT0Qt9mFTb6p/xgcpwrFfv+hlHFQ8/8L0ztEuGcJD4U1u
x/toeE1AXs/LVJ6Qrfy+iNS1iIeVouw77BUJwft8OrsdV7CUVrGaVbAq4QtT
XUfsT1bCJ6qTdOzsDsLlZu5DzjXsBPmu/aOXSzQIafNnH4aocREMT9r6d3zU
ITzvUTKUjhYg/LvxzdzafTfhV7Hw9IdUYULKyUQV3ReGBO26J9CsIU4o0b21
ZfsyIgT8N8H10EKOcJsjtX0kwpSgXp32ZllyM6FpXn5KO2YPoYFtUyKLiwRh
lUdZ15dPj+CslpKWnSBCqLDbl0qZ3EkQ8LNn2dHNRwjYrPw5fmorIUBwWxrv
JCth0Tzz/uwjSYLmjrILb7UWsPjFNas9r8UZ8e3J9XtMxQN6ftVLJaIEj806
Z7eQKXgyWMuQ/6wQwXXI52kd2yzeK/T60QktdgLz4E7rivIhXJ4s0VUk2Y2X
5no7DFSLsbzMf7/OcbEhixN72bM+D8MhNkrkDiN2lJuTLT32bwTSoj36DS9x
INR6L7HMYgyCrlIcouK4EIuj7Lhd/QQoWL3buZrKh4QnjfOIz2dB4ImKm2+W
MAoxD0/Y70OFHtVHYjt5RZCB46ExtgUq7JjaPkK5IIK0k85P2XvRYKfCYO6Y
oChqzwrc0nJiAei79xne2y+GpBIukR0F6HD0srELaa8E+sE643RHYhkETv1k
zbougeb2CsceuboMN0b4Ll38JIH89i8e0SxfhttXngYVs0ii0vvO4uKXV4DP
NvLiYpokErR7qDIZtwrDW2lE0QZJpPnwQKfH2CrM7jCRcpmXROnbl/fwa66B
gL9s0cddUqjeKui/moI1MPsjjoI+SiElAZHXJ7+uww5D0Ved36QY88FtZvfE
Otx7XPzpRb0U2gixHrJU3IB99UG+egtSqJPD6p3I8w1IuifOt5tDGj37aSRa
93MDigSLV7+ISyMmjd2xeG4DBMwLlyV2SqNTZT4f1bcyobZPldlie6VRjWbv
FyYjJqTi5SAbZy6Nrutf/kY9xoQO7OzFRdbSCH6wq3NcZELDTOkcl+ykUWq/
23mDu0zIPc3YKNNBGnGcj88KDWVCz4/fC3/tJI3+Cws7vfaBof9xnaKkszT6
OueR8SqDCT3kPj5p4iKNCHIqvealTMi2OdNZmYG3UZPTlP8wIbPRkqO9Z6VR
AFHsFupgQhlFdytvMPTpN2w++2GICRXyXyGMMuwFk/Y90Z1jQr9SjqsZ2Usj
ewE6C98yEyo/2zR6+4g0SoxQmlFkY0YPxRbL31hIoxN/9U7c4WdGnqVzoR9B
Gn0oe3qYW4IZkSoiKW/1pFGkz6v+LnlmlKZGT3qgLo2GDqlJTKkwIx8PykEH
RWl0QLp3yVCNGeVHfr21hcHnuXqhF1U7mVFts27eBKc0al8/2R6xmxm9vdD7
NOWfFEqcTGuPM2RGCb69185NSiH2yY8vx42YkRHvD6J0lxTa6vxj7TowI77K
Rq2WaimkYvZOycCEGX2/ld0SViiFJC5orRibMjP4Sd9s+0kK2XmIPglkYFdJ
fTe5MClkk/v1BzsDN5++QCffk0ILyoGJVYjx/8IByWZXKfSE7qBdvY8ZCdJd
uX5ZSyHzuDB3ToZ9hQUZzt+6Uii61sriiQEzUtUQsOqQlUK1RcV/TXSZ0Rbd
EE5mFilUnnFkzUiLGRVbjHqaMt6PJ2dWO+9sZ0bhLvOfYhn3lRaX38U5JWaU
q3isU+yrJNqSHJiWLMuMWjBRM/21JGIb5siKEWVGD/bp1uvbS6LV05u272dm
Rkn8ug66upIojX8Tpi8yIa0S3+CTopKosJxuPzHFhE5lhFvJNEigjQWO4ZAW
JiSyVSW6zkgC/RcRo1H+jpFfq+iHhhISyPhy3cEbIUzIyTqDpW9WHC3ctIl3
YdTj+1Vjh/ZYcWS6p4S2bseEVgZJrYR5MbT5gUHiIRYmVDdNm95aKYbka/3v
sndugJBAPW/7WzH0jph3ZyVtA+Jf/HSVMhJD2oab4vwObsDGjZEBLx9RZJCR
qjh/Zx3ys61e3+4URtT4/M2k56uw2fRe4HiMMOoXvaT+ymwVqg/p/Mt1EUaV
zUJGCUsroCbnHOU0KoQIsTsL5s6sgLWZFrGpVRC1cKjkfhFfBpm+1ldpObzI
GjcJahvTweZuYHZeLwtis5+80BJJBn4DnXiJwyzooIPVtduKZDhi8PPE6VJm
FC3Fw/v81BxUjzpTf7xn9EWLA9O+JzOgOR7a8CN7FZQ+tavM/WHMS0uOo5RK
KlC0NBaUNAfhZlXZwp0Tf0Au9X7V2UPf4cxckmzL6i+YoJpyDljkgmTANtXt
94ugx0bV/FlmMqScp3x32RaBH9oObzZ8E4hjnyh0b+j+xXmWhdNTn0pxkCWL
YwLfEP636fUbSZEW/LjN5EGPwzDmPPF2aPOVVrzlwYJ53fsRzJdmfufJjzZ8
h1lpdtvGGH5UODN4d38nlgmhJ5H3T+Ny+Y6UtqEe/Ap7hFmdouDTAUmN45KD
+Gfnq0X5FArOKAwW7745iPlZnD0kZyn4tvYxEck/g7iB5xPfw8vzWHx67AJc
HMKEQ2eDFuLnMUhQqFLpQzhvl3bMu4Z5vBJzLV9iYgibHFJxfSpPxdbSdbc8
jg/j8JWUM4N7qZjz5MDDosBh/Pai1/1QeyrmHyB2yaYP4+dSViXP3KhYki24
9E3tMN5z095u/hYV7xYo7dk+NoxbmMhVtX5UbFxl5da5OoyrxFDb1gdUHLCk
tpzMN4Jb7ox6iDLk9jvqEj5IjOBXGepxiTepOKUxqf6HzAi2XH2fPnqRipOH
+B0lpEewQhtX37wtFZvnHbv+VXgEny3QjujeQ8W2NxTfRrKN4Aj2ri2FDP+f
vXGLb6YM46XMsLG3K/OYVnor2ps4jDvtRcQ+tM7jIo2sP+Elw1g+pXfs7F2G
XE9u9uq1YSztc1HDzmweO+7J2m1vMozPLTsz13HP40N+zjZL/MM4UHXC/lsI
BU/vUFBvih7CgGXH3jiQ8aGQcdUD1wfxP9fcMylcZMzZ1V3+UGEQ91aRlXQ8
5/BDm+rrDXUkzOt4nZ+LfxaflNH+8E+ahI2rdcy9BaawQaiEmIxIP85UpRLW
dIdx2/3o1sy4DuyTUtSQlFWGPRQ+bY10K8C218PaDyqV4FTe656et7MxjaOu
Z/NILj4IPKsdS8mYZvmCs/vgI1zTYLJk98IbH3Qezyu5+RP+prayZhFyYSDi
tIR+XgeEbFE2Ksn5C5dkRIYWr06C3BNLlvuKJLjUu4lAtJmCHv8nroM/SdC8
IHG8bec0xPy3s8/z1CD0mVwR+T44Ay7JI68Sng1BxjEj2+EQMpSn75192DoC
1hG9Yh3WVPjQ0WEZRJ6AIrS0a/d7KkQFXPiX4zYJ6PnhLxwjVEhdv7U00T0J
8lZ7OUdv0GDNfogblUzBnW6H2qarCyATGaXQZjcDy975T9hSFmCv4fGM3JwZ
+NRtJHirZwG4Hiy+VOKbBTO30GOUfYsQaZySfL9wFuyHyxfLSIvw/Lkte3j/
HNz5mRmiz0qHeYPvebuFyODrFxBcqkgHTT9SZ44mGVy5i/71H6fDcsxT5dKL
ZHD7/sTwlicd6CZKSkb3yWC1L8Wb9T4dmspazb8y5g3z1s+/nr6gw6tJCx+B
NDJIONnobbyjw9bof19tS8iwyLd1+dwnOnwblG+6VUuGX9aRkJFGh+un/Cu8
iGQ4r3oBETPoEEM+dl1vhAxdZULGwwycf1X2a9UsGXqltvlWM/7/oRTgILNI
hinpZLOHDH2n7kvs3bZCBvcXziTu93RgcdojN7ZGBjFfx/gzDH8G33UW2q4z
/IvQqvL2p4NwoX7x+VUy7N9xK97uMh0OiJVWCy6RQc5e6PK0HR1KwlLu2FLI
QIxNPG+8hw5RSy2WyuNkyJntLjWRp0OWhHueTw8ZAri6Emmri8BfFSRlU0+G
IJ7KANvcRTD8WLN0Op0MnsdEXlKDF6Hr8XRTAIOfRux7ROvUIgyJVZxl9yOD
n9cOx/O0BbDbm3KA34wM+g7H5xU3aBAZx6ni4jIHngsGNjU/aMD26GViq8Ac
XM9e8Dl+jwZiT6O80LdZOD2hW8s1RoVYv6aOXysz8Lj4RNjhmHkgMgsWVJlN
Q+qpD3mTzbOwJ9ZJPaRmDL4fJTLvvUcErz2dhz2tW4GzcIfd3o4l7LIRk7VP
cgGneGkcrNy6jI+NP3mvAIv46XNrbx7/FewSWnKnx4uO076ffOu+bx3rsb7x
ejvwD7OdZa6s52MhmGSnVr1T2MBFlqK6lBwuwhXOGfXSeHbC5R9mquta4oTa
iXydj4qihEONd84bD4gTylfeu9z7I0pw4efbOhwlQVhJXj/TeVeMwGoXkJAl
IkUYvUI+eGNMnDDhOFLMfEaWoP3+265BCWmC+qWN06XdjH3JXCTwdoICQefa
+qfHD5QIm97sXjpnokhI1S+oPqWuTKjkVRE7O6VIeNgjmP4iSYXwcvuRhMaz
yoTIpzDdZKpK8NAkSkbObSUwa9Vpd5/eTni0v25lnU2V4ArZGRde7SAYF1zL
f757O8Eu96jX3EUNwjWvFzs9mNUJhLRymySNXQSLmy+Dx911CNO/JhTBcjfh
lE6IRfldXYLCH06VEX8Dwn/uWiwJH/QJttkO61sfAsGeyTha9+o+wv1LYeFm
y/sI5W/2TdWsGBOIJ1iOcZoZEHp2BbdpPNUnFJrl2L2T3E34z8NglCVAl/DF
MSBH0EuboPJB07eeWZtw/MQG2y3JrYQaDpOrMVNbCExdenvV2aQIPp60w10f
pQi1CoNqvGgNm45T9l3kZCJ4Up04n/CuYvdNn1yma9exacas7FjvMtaheOY5
h61hllSF86lvlvCFuycKI1VX8FRvR567HQ2rK8dFCCUsYs83ikW/cyew7Xq/
JeafwTtTufRZOApwBtvXw/eefMNnHUecLPhTcOSHpYV35HQ8oJm2um3uIf48
bpDPzPQE29eXo51uX0H2xM14jdu5IHChXk7hbTVIxyio+Cv/BckGFq6i5i7Q
GSQYiagMQPS1zmcbcuPwfk7plBx1BvonP39VyByHret7/lEZ8+tVVwj7LYMJ
eDEWmhh7ew6GAm9fXUOTwBkpItv0Hxk2HVke+CA7DeKHpIrXyygwwL2N3zZ4
GoopHG7LgvPw66zJ+5rZaZDpN/V5c3oezhfH2e1jzE0FsXNcNVPzcCqbdWGJ
fQ4U2pypZWQqDI9f37hjMwdvTT4OeKrT4JXvtKPOO0Yfdle3jlykwW9ajfxf
ATKM8r7/49xMA39m9xdEfzI4HhOTZg5fgO9F8T3HosjwRLpdoKx0AZbGZG3k
v5BhsElu1mdkAZJdNQUamshwVU12Y27nIiguDzQSBsnwVW5La77dIlhMnc5S
mCcDCzW6K+jWIoS6CVSY8lHg8UlrxYvZi/BySLZZSJICzUfzw31qF+FWL068
oECBA9tn3n4dXgTX6y8pZqoUEL/nlMnFmFPctxXd8jUp4Mc5YBwqTAeq1Pv3
JbsoYFBxONNgCx38XTeJOOtTQEWHbCelT4eBBluzz4YUuOy48UDDgg5ymxsj
Xu2hwOFAiTt+jHvB/UmU43YG1ipM/o/7PB2+23l33zRg2DO8lNR5hQ45RqE2
t3dToEXox97Z23SItns2oqNNgfhCzZNHGHP4EMk8L0eNAtW8ZSJrgXRoUSNX
L6pQIP+LS+B6EB0cD0Zu45SnQFS2ad6JEDrUS53/PSZKgVYW8wzuUDrc9uZ/
HMtNAUeLA1dlGfKwP8r7NRhz/tjDUFoY43zuvHP7B8Yc9/bh3u3J0K/yc2Vl
ZogMd9j+KOT40SF8Zv2qahsZdqrs/nyR4V9b37PeoxVkUDJwT3nO8D9ubvuU
ez4ZFLY/EdjBiM8rjV/7biIZjuYzFZucoMNo1dl9gWFkYO+dDeqwpEOHqt/b
Z75kQBGHj84Z0uGava501jEy4Kp36vmSdHh2Wn/Paca9W7C9XWS9bBF+JA5d
OvllDrJZubKC0hYBqKqTKYy6bj0vf6M0bBFEdRrbLzLqsXj9VZ2xwyJkP7nn
qy0yCz8zlzavEhcgcOwyJ2FsCl7M0ViffaIBxWdrnGHhKDipq2MHdwqs2K1d
tz09Cid1WYVD1Cmwev3LsbSNETj9XP5b9xwZEqa5RNQPjEDQj+cX6TcZce97
y4Jqh0DwUKf3xPAsNAyddD5TMgDUJ/9dmI9mvINGtOZKcCtEupWcM5clgddD
ZlNgagVljV/5wUED4LzG8qsetUCe1d2sU4P9sC10F4/BryY46R7HcTekFy4/
uhh14+VfiDYTEHeu7QTt9dph8u8y8Js/Xi1+vB7innpM1Jt9wv2nzT138+Tg
QrVxm1NpqTj6V96mvJ4CnB3BJUZmz8J8Wv2pZRnFWEpBRDHZJh9fnjYxs1H6
hVmbpjJ25f/E05a8ineTa3FaYtD17j01mGOzzNsNpQ68jRpW036kDXMlSKet
7R/Gep2Jpy60teH1ww9Db7UMY77G6+s/HNvxufjvPY+cR/BnfWl1wukO/OCy
0h6rm6N4us3b7ZY5ERNJBZ9jn45j71d1mk2fe3CLxvfvaa7T2P1HncYqey/+
SU07z9UxjfddEN2fe6EX8072xTy1nMEtXxaaCmT6sHZYJkvrlllc6u9+sd+9
HyPapccT1XNYcUQ7BVUO4LrOmEy+ExT89SxHRO3gAE45crnZ4wEFSyRe4RBd
H8ClFDvtDMZeo6l6L7BzJwlbSYpbd9IoOM4Xm5+0JOE388bCP6Xn8cErb5kj
z5Kww99ryg+N53FUkEHPwWASvrIzVeHtw3ncGvLKs/wdCQey9BaNf5zHCT4H
OjfSSTgg6QtNsGwe27ypVv5RQ8Ldd+0/9DD2BIWjOVtNOkj4Z7vfyQeSVHz1
TPmR0CESXulfOkPVpuJTzTfN/1siYfzZtO2QKwMnzZKEmQdxbPlxpO7D2Huq
6838uQZxVezhya4wKo4WymcvEBjEd8lzbCc+U3FWqVdHseggblrg7YgpouID
Q9l+rxh7nL/9zdKsGip++LyuTl9mEFdokbc866LimODTubmyg/iHo8E77Ukq
zuSk7WCVG8RSyb3ZH5eomKjQdkCNIRe+sleum52G+bXCVTWkB7Gc7rn4XmEa
djUqZeOVGMRlMcsiaXI0vONBiGKV8CBWfqx7wXgrDYss+bS78jH034iPfK9J
w1WHmZ4PsQ/i+6cFiwm7adieLl1iuc7YW77dXf+6l4YPV/ybjlog4V6O2nh3
RMMtzHtV/KdJ+Ff31eJvZjSs0CvZfWuQhIcMj9cv76dhUZmh/Q8YfL6w3WOk
ZUHDjbslP8fVkjB79OObJxiYLiOA2n6S8MEyxfnrB2j4qMi3q1tySHjU5rz5
A3MaFuSyDXudSMIDb1rYAk1oOHK7LK9cBAlnGkr13DOmYdVF7uNVgSTccwUH
uBnQ8PXfARNR/5GwVL5MkZUODSvXMx8JdSZh7TMiNtvUaHjTwKBQijUJH/26
pLGiRMN/o5lqZg1IOL3z9J5qaUZ8bv+JX1Bh6Pvafi1MkIYr3OgCg0sD+I/n
ez8hBt/XDyYqkEkD2JAjPqiOkY+ZUzvD9P4MYL/Quk3BPVQ84CT21vvtANZ3
1htZLaViK+FMU2n1AZy0a3OV4A0qXrjOTzMQHMAWF40mhp2o+OUnr8dHh/rx
KPfPt78PUHGqQ+7IKqNf9Owipj8x6u8R9ByuvNCHM7IEUzZlzeMs/k0oVoGB
xzl2XH09j+PTz4uadvdi0wNeda03GfW/9jWC/zCjHyO0Bmd3z+NTVdxyJ5R7
8OyWTTuff6Xgq51tu1kSiDgxuvmXtg8Z31AdfsvH1ooNnhk18/6bxJLoZJVr
bAumv8yJff14Enc6l1J36bVgT7mFzPcCk1isaPrx6UvN2PjYIfOjmyZwp3uj
VGhZIzZWUj88pz6GixzeLz9v/oOHvHx4bvEN4bA96PZkcjFWuzYq82m9Bdc3
Fb9PW/6GxdYP+OrXN+O4rZcJtkeL8EKZtbh9TBNWChTq/bqSh7PYZF8muddj
/9t/1/ZUpOO9xZOtemnl2O1JF99ehbM456qigvucN+Yyt6H2NBWBosZvu7PS
rUCo2VXQvOc7CLPyW6adbYMbB5dtt34shvtN0WJan9uh9tbWo78u/oDMHGOZ
Oi0iWJgOvpq+VAY6ah8tvS374Az9yX67kEq4caOjJNZoGGYUJfxbtlbBwHPm
Puf+YdA6oxZS+asKnlunv+QIHAGe067z/xaqobyOskyrHIWNwDHfwwdrgWdP
oijT0QmoP2FxN/9jA6QMKO8zPz4LUloFJz+JNIKx+fEHU7RZoB48IxVl1wh9
e3JqD0bOQf6jE2NzzY1gtBFWJ+RBBpXu4Nc3qprA8t60y9pnCghayI0eCm6B
uOO3k9TFaKBA9Z50LWkBW3a9RY1zNJg7G30jfrYFPJtYVf9l0iC260Wpv20r
1Bplu00cWABNFpaCdsE2IKzZdkjeWYQlVY5AgXPt0BvHqTxbvQQJ9Ca12sft
8Dkm7LIx/z+4tdusozqlHTr//idva/MPdutvcng61Q6Ni68Dazr/gaK06IrC
5Q54lmEvSBpeht+Dg6GzwR0wVi7har1tBTrnddo3PneApMulwbseK9CXX3Vw
rqcDvJvZbovOrIA6nV9BwLwTjln/N2NCWYVfEsem2J06YXTT/Ms07TU48shi
6/6bndD8Ef+o/28NvhUd5YyJ74Sye6kKxyhrkNd64Xd+fic80BcM+bJzHbZ/
EpOVrOkEc8dDY7+urcPimW1TxXOdIBtXx64ysw6Zzu2v15iJ0FqfwuultgGZ
3W92PhclQkvl9fDrHhtwqYHYFKZLBFemlPKk4Q1YoxOlOMyJ8N8vFtcpISbk
dLtq4I8tEabZRX1ctJjQW+H4t6ZXibC8n7Wu35MJ/aUAadGHCIVb336fCGFC
zbPyTqtBRJAbIic2pDCh/pNXS+zCiVA+Vej6uoIJKWZ8yluLIcIt6r1OzSEm
1BDgvLKcTISYVxl9KUzMaDj+gpV1NhE4xxLsV+WZUZBUOmWGQARV/XP8+g7M
yFAw5jdUE4H8UlhY/jYz0kEKUeP1RPgzsJ+j7zUzUo5rV51oJcI6za/hXhYz
SvDUNjPtIoJ0FvMx8h9mtLfePZ3WRwSXkTFPkzFm9Dr86lbmISL0WnNzebGy
oGmVwQD3USKMOLLw3NzMgraVsD1RmyDCFj0tB7u9LOhPdubGoSkiKH1LJfKf
ZEFM4oyn4DQR3FxN7iTeYEGe7u8jEmeIoHgtUEL4JQsqfCZ+pIeB9VpTPzmm
saD7fdfKbjMw+Xwip185CyI8ryq7xjgv38+jcbefBf3jDVOpnSTCvPL2jcPL
LOhpZSDh6TgRmI9Oe6yJsSJ+WpxX2ggRblDGHYO0WNG3BHF2zUEihB88UTp+
kBWZD5ifk2TE9yyQ94HKBVZkpJl55hKRgVf8XhneZ0Wx/8baZRn8fIz63r/t
LSva5RSXbsDgr4jL3WkuhxUdXXtQ9KOKCCVQvhhWy4rUN+3p/cLgn68kJp57
hBW9IJAUHL4RIXmO6YIfExs6Y0VTPf6VYV9FaF+ZLBui1GhJfE4igohkglyn
Hhs6H/WA58AHIkR4mM4RbNhQpTpZ1egVEZxmUbLvFTYka/0pKvgxI7+r73S4
gtnQxzd+c0qeRNBcqAh/U8KGvpaMb799hggvfq5YvW1jQwam/IcVjzLs/z6U
5DnHhjw5uijPdjLyHyTME6zEjpJe5VdZKxBhdJiFqWEvO1pui9a8IkgEIufy
5XF7dvSic8y5dqoTsg5d8w0LYkfzslqP+YmdsO+0iJB8PDs6l6Y4k1vRCVIZ
63TfInZEuqtmoR7bCZ8fUZIyx9iRRmjsG5annfB06pxzwAY7Wsx2HkM3OqF+
34StiiQH0i99cGSZ0d9Hp/xb+/dzIOVrXyq9NTphNa7Tke7EgYiReaznxRnn
t/VzDtzkQIE/oyIeDnWAk5d3k8pHDuTxO+WZwL0OKNRj7vb9x4GYcy6kiZ7p
gFVJfF5OkBOF8TgphKEOcKitZXupwonO9u0cm2HvgNnVtujhI5yIRPW/eyW0
HYY8svicP3KiJFP9jf2X28Fo1c77aQEnMiDG+cQfbAeHyDq2RzUMfHFWroOj
HU7HaodPkTnR9/ulqT6+bTBfe7k21JgLcao6X719sg3iXpvEGx/jQisaNYR/
Om3gedMnu+w8FwoI2Nb2abwVmuVwjHEwF3Jq7NoZf6QVPvA4K7PXcyFh+7Hn
xhwtUByqkNNhy41Szjns3dvXDMLvLHa8OceNxq/HawwWNIP56y+a6te5UfXd
0HytC80Q9d50ru85N9pC7ZIbLm2C719EZ53LuZHb07rSA+FN4DX972x3Ezda
KtxjccqtCfjKxp9q9nMj642QiWihJrhpWrLZ6R83Eov0Wwh2boTyt6IsbWo8
6GNaj99znUagPf07JGDAg9wfcT06yN4I5D6urwrmPGi9+1YCya4BroTGytSd
5kFa/vfvyg/8hdclOfOmITyofnLgbe7AHyixbWcr7OFBqWm6hzLu/4FySvHZ
/0Z5UIf3gXZduT8Q3hDNyk7mQWQl4sC/4zXgp1e6v4CFF/F88j4SXF4FzOHV
h/ds5UVHUpLd1ZyrQI1U/fGbJi+ympwT8fpXCS60F1cF9XmRQcMPt0b1Spho
s3x6wIIXDb+1Vz4UVg4HPLfbdl/kRYUZti3828qBT/cMyyYvXlR2/0SS/8/f
YNd08bjhLV4UUhE26z79C4ZWEun/HvKiAnO3/ATzMtjjKpX76QMv+vulQmKJ
SICn+Nf6l4+8SN6OiZ/nGgE47e6LvkjhRbuaPv6p2YmBfadKMjGXF3Gz124c
aywBjtxWUkwVL5qLv/bHdqUYCI90xO3reNHAi+MJk1uKIW3jYMFIIy9KbDs+
OHHvGxzw+Gn5lsiL5mmCnA6fioBeedn0ey8viv1on+pRVwgrytcK8km8yE5H
sfaxfAEkBfKL7p1gxPc2gilqfz60L2myVk7zon9frsmc8MqDtP5CbzUyLxL8
5nNmqSQHahRm6E8WeVHSkwC9gcFsMPW24/L9x4vcNqfaBXFnA2oOSz60yovW
9rlc3p2RAW5dbZH3mPmQ/PSC1ealdBj6WTbeycqHim+9dEswS4N/vy2aRTj4
kLpppRt+mQKOI2J227j40LnAyMVAYhJoxxZfkeDhQ1PyJ35QlD+D/u8shQFe
PpRd0nlB5GoiWF21uv6Ynw89brwYNVWUADKd9U6sgnxo880PM5yscbDH7PSY
kxAfel0x4lIe9R4GhhaFXgvzIc3xtGZp1Wgw+fOsK16ED1kKGLwSL46AtYYx
8xBRPvSxzmK03OoVbAouPXZYjA/xmcqbXi4OgXq1+PUpBr7Gmyk11hMIAW+5
jl4U50Mdu23rd697g4DRcdPvDHxWa1Xw4eMLsFOkonOMgRuT1L4M1VvhkDhf
EQoD+7j0r03t/g+/mXgw18rAv7KcR75R7mOxgNJrEQzcdzp3I+hEEGa5vRGu
zsB3TY4Jdu96gV9eXHZIYNgPe7aN3ZkrHHM+MC2bZfj7o9sxI/ROFGZ/eqxW
koGPv/iz03X4LRacCrgjy4gv+r33/m6bGNz/W/TXPwYfNivFMSM/43HZrHpm
LoMvU2mZW8VRH3G2TKveAQE+ZEd1mP5h9Qnv7qWdyefjQ/er+MPuMCfhmuqz
imuMfBi+z8zrLUzG4kEVDxS4+ZCLWWVvjEI6XlL9y0lnY+SPyzpsrPULDq09
pJnOwoc6SwgylU8zsdPK/Ql9Jj7EEcLJFe6djcvMoyWGlnkR8aqKUO2xHOxV
6/+YaYnRX0YvvxC25+JTAgoPlmiM+lVZMW7tysM2HneE787yomDfjMdTufl4
efjk541JXpRXvbqWE1qAvx86VnxujBepDpsqgWERjlv/daGgnxfZ6r04sPq6
GFe/azj/vp4Xdci63Ta5V4Jf/knYFlbDi77wvXnH6VKKQzKUck6WM/phS8tz
dvWf+LaqD9OF77zI+cbgT11hjOdpm3+k5PGi3Rf2ZrQsYEZ8kuo4kxf1xfz6
ntJHwBp5+/k9GP2tQRFqFT5Who9p2t9eec+LgnzTtqqVlWHCh0u+5yJ50c2T
u2rOJ/7Cicqc1qlBvIiQUaKd5lKOD5YanlfwYPRfkyM61lCOYavhpqPneNEp
+lWFKOMK/N3M5ZCNIy8S3v4wak6qEidsc+xqsORFO+7SyWl/qvC5tPtbC7bw
otNWLzRY9KqxdjQ5574cLxJ1qkofTajG/7WV35MV5UUseodeW92uwabLpp/q
N3jQJ8ftfBZStZjr/uh7mQ4eVJsSeuz3g1qco2xs4V/Hg5hMfSWKR2vxB+EW
em4ZD1IoljEUyKvDtRllltFfeFDIo1vqIvvr8VreRo+pP+O8bGObcmo9PjS7
0Gf0Hw+y+/lVKI6nAZeyPUjnvsiDCsa26P7+24Cn/ZMCZK15UOLtPZ6WyY34
sc+Y42Ypxrw/u9Jl19aIeXw1iFk8POh+TlggD1sT9m6jjAqtcaO0+SsTt1ya
sEle4ytrEjfie/laZJN4M3bqM7b/mMKNhlz2BRGutOCLQrfvF6txo6zP2scM
IlrwL1n31GA5btRbqnTkxPcW3DnqO6DOz40iHfU3P2Tsq+Pzd902ZrhQxWza
e+83rVi4svhweSbjftbNDuUobsVzuzgu2sRyIe84LKvb24qzyjUvFT7nQlu8
xu3clNqwQYSlBJcnFyIsK90VTW3DmTqsVTVbuFDdM9+/ftVtOPxKUYW4GBdK
+je9xX+8DROHX4UbsnChxKY2AdjWjh+fXXrG1ceJnjs+YM2Mb8dl9hw/fkdw
IrirWpBX2o41ZjdP/Q3gRN0fcysOEtvxQf+V9q9enOjFZM5OBeEOXPOldmj5
ACeyH466ctq3A/cIjZZl0jmQmEOy3a/IDqwfEFd3e4gDkdI0FrIzO7AAq0KE
eAMHMsqmvFHs68AXSwNP9iRxILdKza8fFzrw6RubHFhfc6C9ztM5SXydWGJo
RZrFjwPt21WfutuwE4fcM5sMsuFArxYvF+Ijnfgl6lnjM+JAbVKPSDWunVij
R7L38laGve0NFaeed+I/Gr58Wcvs6EbPyaP2HZ1Ysr38s+1HdvS6KbWhfLwT
l3stP40OZUeaeWakzH+dOKcEzubfZEfe4VH/RqSJ+O4ifeH2fnYUFC6ltGs7
EeueuVEpo8mO/jqGbl7QJ+KX7YKfoyXYkZpS6GCLHRFf8fFPkR5jQ5d4tepn
XYg4kbmpb1MDG6p9uN7l48U4T7E9sFrIhu69DZf3vkfEziyzYzlxbKh5TPvL
4GMifrLKWQ9BbEiGr+NdaRgRf5Z5zJrsxYZ6Dxowsb0n4qI7FRHD9myo2pkU
3pFBxGmuubRJJTb01DnlnEghEe8/170YwcmGlt5vLon5ScTSx7Z+FphmRReG
c31vVxKx55sggdONrMisUeThh79E7HanwPJePiv6RDyQzt9KxN8Wd1/yYOwP
EnXfO/4QiZilw8FXzY8V5d+0mGrqI+K/YSgWO7MigchD1YpDRMx9doS0xYwV
bd36xe77KBGHOEq7nN3KikQHpm9GTxDxSvRzLQ9uVhTBvk+4ZIqIeU83uR+Y
ZkFSj4LElWeI+Pwhly2L9Syo1s77Sj0DK32PeXA3hwVF675nLWXgWXpn+N8I
FvQ58dyfyWmG/pxTvgu3WZDODsNcR4Y+vePOJ8iMfe0O85ssToa9f6EKpj8N
GfvdAmcBdYSIjQo6zzjLsqCuz4d+yA0S8Yh/VU3LKjPyET5Z9rCXiPuv6aXI
9jGjOb/bPxQ7iXjgg7+UPmZG6bFHs1eaiDjrIJfJ1gRmpL2N9YNALRELFTru
nwhgRirJug8dfxNxebewVcA5ZsSdp+TRXUzEqgfn706ZMCMm3++nI3KI2JV5
aHGHEjNq+ph8ISCFiDsv02f2sTAjJx+v8I8xRLzN8ubTbYNM6N0738WFV0Ss
+bOBMlzGhG7/Nk7yY9TDj4uEE94fmdClvfzm8h6MeLOu1cm6MKHYwzlXdp8i
4q2840aawJAfc7XxO0TEXk9vuEtsYkI+w9oj4apEXFh42r+pcAM2RG3GXSSI
WOT0vZTkmxsgVpl79BQrg+9uS4rqzg1QkTwjV9fVieUcLTP0UtehIIWbZlrR
iXc4dXD9dl2HKVaq2GBWJ6Z9nj69vmkdziunmr950IlPfFfpfRS5Bt2TPE2/
JDqxfO6FH52+q+C78sDKfbkDLwfzqk3prkIIVTBtZ28HPvF1uSF7ZgWQDalg
W0IHjk7V3uRwdgUGdds642U7sH2Qt7Kq0TI4x3pSjzHm1UGSt+eFSTpcaMuT
z/3ZhhXlorsdE+iQtOV1in5kG+7ZFcUkdIIOcIIs9tWoDa/77nheRlgEJofT
/1k9asWU/CjfYxELsP0ErU9nrBn3P/H4RtKggi7p54+mr834zObPi5YD88Bn
/NsoyrsZB7s02z0In4fDuVssnrE147XUy3FnFimw4XK51FisCe/c2Da4XkKG
I6OcWqck6rHYtayyrAfT8Ft0wu3d87+4/OYh+vX+KTie/ZhDl/kv/p3Y40Hf
NwXJO8P7A0dqMff19+On1yZA6MA/FsL7GtwaX9vW5D0GTHzFtIbv5Zhq6/WY
+9Ig8AwWDfcQ8nDJeubt//wbwW3oKZ+key4uCf8V0x9fD77Uzeq7+HPw37b+
5sf762DL2Rxh98QMvNOmO2Y9vAqunDvjmRH4ETfMJ+i4XC8Fz9DWxJPpTyCi
Yvj+v80f8YJw7sEbWcVgSzuXusTaiu1tBPut9UohOrnu+mepNhx34mHbn58/
4IzYgTA29Xb84Jjlm+/uBDDlSZ/4yZi7jqd+p/T4/4bNJh47tjzqwSTRjzW/
0muARbDdZPboIHaxP+KTNNYMwZk5wrr5E9gj41GRwZEWMHGPtVXZMYlr1Vt6
rPNbYEpPv/xT3CSOa6RY9txvhYfcIUcMHk3h5x7fqlv42kFX7tt54T0zuHhr
Kt8gOxFeJFtdyVYnY/bsP3d3niPClwTBD4RTZOwXFBn5vIQIsTUJIxPBZAyP
hhaPenXBTMrjRr9+MjbU339Yu7wbsh77PXN4RMG1Mn+Kqwz6oJtHkpb0YR6r
npf55vmwDwSudSzxF8/j3n0fTJKq+6D0UELjpY557PpowbrEth/CvnqaDQpQ
8QcTwRTbHQNge15upuI6FesEVVZFWA7A3vqT8/eCqFjdwvcOy6UBGDL0SxX4
QMUl77mtT8UNwHqqkVQLgYoJRt89jb4PQLw227WNJio2vDHLu69lAB53fclh
H6RiPo9/EuFsJOiPiOh9t07FruyXSntlSZChqz6gwkvDWttcHfbqkKC4Z4r5
sQQN53cZJaRYkGC4PG2pQIGGoTbebrMTCZJ36T37vp2Gn9tyGsdfIwFXb/zr
F9o0LKqupqMSSIKQR94LOw1o2OjbFbEvESQo+yOcm2hMw9N5Zk07P5OAQ6Wq
lWRCw6VH0s/n5pHgXrm2/4w5DYeHPG1Q/0UC7kiP3vIDNEys3qQe20CCJxz7
9rhZ0HC2/7X3TD0kqKjymmphyBuaUw7Zj5Hgj2bPaZ79NLxuGewbRSGBrmc5
N48pDW/eUulTtkwC7+OTQc0M+91xPkltLIPAUHzXleEfUSbjxjnuQdgsMvBM
X4eGUyXYNy0IDIKGu8SPlR00/C74eepL0UGwPCg4/1WJhncFiSqoSw5CNL1n
s700DXsNecfXSg/CfL6U1bgADXu8HjniKTsIUor/gq+w0nBet8QFbrlBuFF/
aXlgkYq1nCOUPjPk86yC7fsnqFi0cKbbUGYQWFNunf3QRcUb1Rtz1Qz9wvs3
Rkl/qPjTry1/j4oNgr0pV4t0MRV3vfAm1wkOgrfsaJRZKhVnkJhG9/EMgkTl
Qq5zFBWTK+iWn1kH4bti4o+rD6n4QCjl98oKCRx9PBz/u0LFl1UlhM2pJIiS
Jxm6n6DiTay2y74TJHBdKVSyByoeZQpyTOwjwVPHnLHd26i4Xme3TmEFCXbX
vUnqo87jy28HKf1BJBDNFmskBcxje0NewvVbJLB3XuB8d24ey6QNb5lwIcGP
OMryEZN5rClu++KlHglI/ru+lq5RsMM8/UZCK6M+I2TY/lym4JrBrxrnGfWq
8YbX8aMZBVcfrqVxxQ7AGc9dux/LUvCb4xGF7OcGQM0wi/tWNRmXNBXXBRT1
wxeaIoeuJBkHqPi91zHsBfGjyeX7xWZw+oaFvkRSO3x9fOh9+tcRnD78pYpT
ox1K1rO8pHaOYN+3z0Pk8tog4UhKjN3XYXz/hfQtwvdWyDh638kqfQgHnD+v
fjWnGbbf1CmlhZPw5pBPleaxdaBiXWL3z6MLr9eep/Im5MDcE/aiE64Y17+Q
fxpAy4RjhHFJkdhifMvepqslPhWCx/gOq7UWYPbFOU3rbx/Aod+g+vedVHxw
0MB+XPYVTuxQifirGQMcp8yWbT8U49iCUnHoqwTdTca19ueasaJCjAjz4z6Y
5Mkf+anVgsvCvXd+qeqH8JCDW8zWW/AXXQHV1ccD8FJi6vXlD204DM1LyzDy
9OkXWWCktRM/ubbd4uPeYchbv2fRZtiPb//+EWy4PA52WacaAr+P4M6T53vV
y8ig8cL/+0GJUUwHx46+dTKcubt4y+bGKA474+2St5cC16cezXGqjuEctReP
83MpsHvupNrRkHH8ZGdaRnrUPJhfdfgiLz+Fa/ir2QTVadDp/KIk7fIUvnN1
2Vz+FA3OLnLKsBdN4VO5N42Eg2lQu/+2Ep/1NDbOeBnwoZcGW+z345BLM9ip
8qpks98CrLUcdXl9Yg5v37siFR6wCNnBzSukkDl8af3iy0fvFuGvyAvNnyVz
eN/wwlXrnEXwa2z0eMBPxjc9WSIcehchhGRN3aFCxly0tyNRlEUo7CkdF9hD
xi2pemVxbHSglmXeueFKxk5zLNs4t9Hht46G1tQdMo6Z+1zkokeHQrajES9D
yDid2N17z5wObPG/lRw/kLHPdN3bozZ0KCVcPmGRwbgHFlNG+pzosLRNNeF4
KRnv3++NVdzokLteeDmgloy1Q2c3bbpOh3I2P+lyIkPfZ4PlKm86VF49wSU/
Rsb37crNN9+ng8j1a8+CqWTMSxCcU3hEhzeXuOY21sk4t+fGaE0QQx5v4R3I
TcH45biYZAgdpJJZXXhFKdjyXbsLeygdTsu96HnD6BNZk9aM1wy5Gou3pKIy
BbPFX+v4FsyI5+oZneTtFOz3hlLs/ZgONcnp+5W0KJjjkoJG7QM61D455fJ6
FwVfrWDa+HqPDmnqpcFzehSsGhy1qnSDDqFj2kUGhhQs8zV2WsGDDg1Gc/3u
eyjYgnrsVfJZOiSKF4z7MnBhtMynbFvG+4n8LNOL8b/5W9uuvfvpMMzvt2Go
T8EdQgvD5gx+4x+Zfe5h2HvcdtKzegsjH6o8J2wY/jhs7xP4LUqHHHPR3xEM
f/sfpXtoMzHinb7yIl6Jggm2RwSEphahZy3m0HUZCr6b7B18unURdnyyesQs
TMHt+TEnhUoXwclkKvcIBwVnbEpa2pG4CESN6ASeGTI2n5Jzf+SxCM9NjIWu
95HxD5GLq98PLYLKYXPi/XoyDo99NG2xYxHMVS7pP0knY6ucI6unhhcgPE5+
LN2GjGPf/NhBNVsALn0VqyZ9Mq4qbNrlI7kAT/Y+77krR8bzr90TDCdoYNob
anLl1xzOmPDRsWHUO0dAr0Dc11ls912beCWTCsR/snt+j0/h+PpI1SuxFPho
lqTTc2cKU5QbVdisKfAu7LRKGNMUjki8+k1jiQzG33nL/DgmsX9CRbDMQTIM
VRbtvts1hsVN/grseDcDHtyjfUWvBzGH2oxpbvIoPH1tMqHZXIqvvJL8+G6N
AKLCFyC05x/8LD6Y/zRgFRfEdF6J51wBckdJg17JGtbIP5zy3nAVDMD03e7V
dbx7oLKEJ28dHm5sX5ysZiJwlPWvjzCxoB9qdPd7T1kJMQayjboqXOjKwegY
mRpuAldTNNON12Loz6+A3sFD4oQ2ymkuSxBH9/88D+mmihMcp5YVuKniKKBw
KQolShC2b/cc+OYlidKGz7z/JCRFMH2qs7m/RAapXNhlIw6yhJs6R3khRRF1
pz4IeVyoSNB7J6XFaquEklunZL86KBHqwnUyaRzKiHlGzt6ZTZng+LPg6O1I
FbSXc2/0Fn8VgtGnQEnem6pI4s7nv6StqoTn94+WvP68HblODsvwWm4nWBeo
5/xY3IGCq0pYNJ7uIOT5xpl926SJNBd4tiY90SAUHSn7LXRRFx3QbHB737aL
0OOYGnt0WA+ZCXAunTPQIwQ7ZlW7Su9FdR0KJ1fQHkI41mpVcLNAaa+yE5Q+
HiDMTHMb4by9aMVBfY9Z6R4CH6seLXqfPhpMWGaad9UjmBUd3n0hUxdVCCoU
KpF2Ecp50v7K3dVGx2w9fsqW7CSU8imf3M29DcWqfkngL95C+NTXXBxnIoP+
1sSyTbJKEUruruve3GBCalTJ4J69a9heScvKYhcTaspjFS37u4LZ7iXGKXes
g43o7foa9+X/VWzl4VB/X3gG2ckymGEoUcoWbba4H6GyZU9oI0lCEWWprIlK
oezJGlnahLLeW/JNouxSdsMY6zAYu5/fn+e595zzPOc55z3v+zz3Ql8SbUW0
dRWE/5y6q1nOhMyDrHtH9y4Cjqv+gZNVczAwIP+Mg+MYSF4szLY1oECCt/dL
510NsPbcqpUlvg44vsr3idBpho/Ds1se8DeAxXnQNHamDTq8jeOkMH8Brg4R
40abbviYyjlYotIOzP+UP5HWGoJffezux/7uAT2EekZ5zQQciCr/JhU9ArKN
CRTphkn4rFLL/pn5KOjIDhN72jQFrYjTceu8VGDYKhkPq2bg16BX34W9xgCh
VJEukz4LN14Z3/01Ng6MJio6/D3moV9aibts/jT4wV72b3/xPIxSRabauBnw
4UDSnmbGPDzxykLZxnIGmLhIqQ55LMAY7QJyJXUGFAo1cp/LXYBrqW/T4kTo
AJ2Svdj+bwE6k3dhw4fo4ARpvO2H9iJ0cLDX9Xang+nMIC9zt0XYvSQ6Xh1O
B6PGsY8ozxbhv/28VTCFDtYeaEcb9C1C/Rt34zYhHdx6YRgivrkIJy7dMDD6
TQeXG0X4+CSZULIsMti5hw6u/k0gS6szodzEPW9rKh24/Wf3zN6cCW8+i9Xa
Sd/yHykwrb7MhI38PtNNi3QQK1wpberHhG8OaMReWqWDv2a1A3yRTLhHVFPq
/+/b7YTlzrDGM+Ff/eXw81v7O/xtvKVqOhM+TWAp/L1GBy5L8smpuUwoTP3u
ji3Twa+Ep/MGhUz4fTTgZRmDDlj2kJQPvWFCY00Kr/okHQSFjQu4FTGhnqT6
vYYhOpC8S7g28ZoJs8rHim920cG23Z/4q7KY0PTSLReNBjqQ55Bt609mwnSK
trn0ln69dBefYP+ECWkcBrKqBXRQY3/9qEowc0vHbHvumUgHO6W/zq86MOGu
iudsUVv1XdbIw60YMOGO0HwnL2s6aNG5OeqkxIRNdTHEl5p00KvXUH1/fhE2
DSCzf3g6UPdovxPhvAgTA7/85lqeBpcLJL5c+z0P8V2Qx8RsEsy3Hfe7MjkD
Xa+ZXnLfpICwcNrROKkZaFPaqivgTgHr8Uq9F0ymodZUnkJg5zCAyi2uWqmT
kHzrGetczhD4ZyujFMRJg6O5O/Y82NJh0lm151bUBuF7wYNiw+0dwLKK09/j
sT/Y6IlQ7Dp4Hd7yCmBZP/gKsEsOPnjekQwp5hFXn6Z+BFdEs4KCO/JgmcpI
w4fGr+DMqla3a00ZvEbbp3bFuhUUxPnhVZl10Er8KX7vFm+TcFuJOkxph3gO
wSLlxiGQxn0zpJunEx5tbvqR+3sYEJIKb/QodcG05VNJtIYRkLKmHT1/oRvG
h+99HfeIBl4HvKcq+PbClRyLatfVGeATdGUwXGQIqsSUsPywooOVf1K/g68N
wXl6Sr1CLh0IrV3u7K8agvVg+sIlMAuaO6bmLlgMw8NRPizr92eBkauGodnz
YShUtxHiWT8LhiparHRah2E1yyk5V2wOhH07bPVFhwIt2Bnm5b5z4G2zYJS8
BwV+FGz188nd4oXxa7w6CRRodNyuM6h1Dvhn5vDTyikwveuVy9flOSCgQv5D
+kOB8XBsSYbMAG03X/yBdAq0akrUjNZgAEfBgbc/WUfgHsr5WqoFA7zJ4zy4
X3AEjp6s2yl1mQHyn7EG9xJHYNTfgEGJmwzQYOe01iA+Avv262Y0BTKAfnCq
05ToCCT/duaXDmIAE5n8ei2+EWg1XbHOdpcBRrlWc9+uU2BaEtHtqi8DiBQX
94ExCmT1Uw8FrgyQeWMnHG+kwEHhbe/9bRggItafu6iQAhPHtDN4tBlAUQMt
h4RT4LKnp+G4FAO8/dgJ3G0p0J+qPMezOgdUOz7zuMtS4O+PZnxLmXMgmj/G
+XPRMLy3ybzXlz8L1rcd+qZ4ewiebWIdOnJudqtfWCwdJYagsZNiYSn3LNCy
CtcYLx+Eko3qsQe25uJuyp3Zg6MDkH/+u1Si3hTYR+6MlFzthdZTppGljhQg
sDwfct63HfLra/Re6f0KjTxeLLfvKwbiVC3Z0M8/4D72O9KiJZ+BtlbswWc2
zbCCnCGcYgLBj6tKKYyrXXB+8HzcZcst/UGqPKXPMQzzemNalBZbQEqlrp63
1pYu08A5TA71g02LwuXtDTj0ccjtvnnrFHC7VLtRdwqPQjy9ZXK38Hh2u9NP
3zY82rnIklcVNAPyw65lpvSwIC1DuwHGMzqw1/TTp02yoUx9yyy1g3OAnS2r
6sU6J3p2HTtSc2IBcGmc3EiwEkDR4k7sOhkrwF8woZMUJ4BSfcIux86ugEE+
ysi2ZgHUuFhoZKe7CspkIsR4jATRjgSfQvWeVVB1ndvsyhEhdPbQkGrvxhp4
1Ewfb74uhAqMpakBeuvAVbdRIfK1ECrV3WvjG7EOotwce1rFhJFqeLjObY4N
oNEuoR86JYyexpQ/v7WwAd6Ofl/ASxOQaeSqE1LcBMfGlMfLrAhIqNG829Zp
E8zX06VKywgIBrKZuNVvgiRGG+2jtwhqrzimuAFwWGtDS86TdBHkNvCrt94a
h3H83W8b+VMEqS0B0TJXHFbA1tPftFMUqQXWFi9G4zC3oLSe00gUJXPggzh/
4bDXR2ei+0ZEEWNxiLv/Hw5zCV+avc4thgjJhQKdYzjsX3i53itzMeTDr70h
i8NjS3p7xvS8xVDG229Fd7jx2FhzTuFgnBjaoE06zgvjMU6f4rHtLWLo9f6u
F3qyeEyyTp8jdVoM3XrdxCWhgMd2uXVFi/MQUWumsLGQKh4TOcNV92gPEZ3g
CHTYdwSPVZHC6RMYEQmVENQvauKxNTW3U+r2RDTn1dlfpo3HbqXVinp6E5Hf
c10rJQyP4WupAQ+jiCiVwP28VhePoRsjOQ/TiUhYoCbH/xgeW+2hll0rIaIX
TzwizbbsW9NJDfL1W/k9LY8ZbN2XdQmmf/tLRKcc/DrsAR4z/XBhv9okEU3k
OevHHMVjcTsfht1bI6L/FqpjRtTxWKGORl8iDwmVBTIq7P//H3m9RzaYREKj
v4e/zChv5b96ReXQHhIK4gvLytmLxzRSnzW+VyWhNJVgW39pPJYfJPdpTouE
KoNpfzxIeEz7gEr6oj4JhQ/8lggV2Kqnn7psuQkJ2f0ZEyxjx2MPt/l3HLEi
IVfl/flcazgML8Ci6n6GhET7Qn7eoeMwvu7eLJuzJNSmrXt+OwWHJbxUCJ85
T0IJO8Z1v3TisK9Kh1gULpJQ179TLg9/4LD+S2FFWlt2XX2Y99NKHDZ97byd
1AUSsrEMAM1FOKzXtKnp91a8L3YHM03ScNgHve4qEzsScg7xdGHb6p9TvbX/
xVqTkI+67Rlm4BYvDDvil3qKhJbO7Nfc7YbDlqhXDV1OkFDfXmZ9tC0O2+zT
T5vWIaGmR0KVKvo4zFbeG6kcJqEklQnIp4LDItPcx/bKkxBX6NMgWQkcZsQX
cqBNkoQe7ziV4rMNhx24WpelIEBC+7RTzVd7N4HgaTYZZTwJHczCvO+92wTX
/K1u7OwnIo8iJrXNdBNsxpPCOBqJSFHKi5wjvgkKu5Dyg09EpBzuKTI4sgEC
t6kHaz8koh3X0hVe3N4AXecHklckiSho18u7Uw/WQSC/wB+JTTFEmSxaWTmx
DiK8fukX9Ykhhdd1Zq7s60ClXLuLJVkMyTOiB+3urYFRaj6xY1kUtfi8CbC2
XwUNvVOqsEkU1d174SjJtwqWayjuw+mi6KsZgVe1ZgWoHLh4vFJHFHXmf5uW
l1gB37oOXYeXRZB21bzSOlwCzkLRpSXmwsgGH6c2834BrIYN6c6yCqO1CzXW
RscXQAzPsdavJUKofppuk9o9DypeyalO8Ash3R3umevLDOBWNS6fkC2AQnRy
9Kt3zgHC99N7QwK5UX/QhcetzAkg9XDHp4JILvTqwTz/u55xsFjw4kPRE05U
zd0+xV1FA0ros8nJcHbEbqgelXaVCqxOtnXc4GdBDjCnRjRwCHxuf8T+13gK
epW7sGdzNgGvX9HPPKWo8H1eq4p7y38gtKqAM6RyACaFZK95eCNwrpoHFJhX
wJMRg2o6ecnge+gCozprHCga8g2IRP2APRVn1OKKuTCPuJgXHb+okP/Pz5CG
RF6MEbavdsfFcSh/Vg4ws7ZjoRjbNyv+KRhYp0CTkhTGCj7vfP3OZRbqdipE
Vm2IY0GCk5Q82SXIrrTv/QELSSww41gUEF+BT4cjJpVbd2DfnkzUWx1ag/TD
+z43wV2Yh1AMrvc2Dn2wGw44FimPPf5ns2E5yI4WdzRuN1RXwuYy2tb+I3Ch
2I2wTM4jKtj+tuRzFh950Ll3qbSq74cwjRKo8jxBEJGeu7l2PlDHWLmSVeQL
CGiZumTxxA1g/JI5Aty24uise8Whu5kGWOm7N+rveHchFc0PcrQ1LexWR4G4
jI4YcpAf8NJsP4IpKQbjyX1C6IvQZ2Jz9kHM8scV1rNyAqgK/1k+iXU/liq6
wC+nx4W4Ii7SLE13YwJyUT22rHhk9tamY/KKDCaSrxr5vH0D/jSXbw/5KI0d
uRHHo7O0Cu+Xhtak+klip00YyVUcTPhc4HtPxnYC9pKtIZi1YBpSx6O/ZWGr
YJb3kMkApQ0yLPk0DRYWwHb/wx/+9v2Gscha4/wWT5/zrjycebYeHt07+1zL
vhd4Oa8YtkyWwHf8bVnrF4ahj9rSzluLFeDpdIQX+T0LSlo9vpRV+Qfg9eLu
9yqxIfnZpJiZyL/gdPvsifH0bYhhuiJ6G+sBMYPSvSVOnKhg2OwR9OoHL93y
JLg8+dDptqtLQf5D4FfuQUfnZH70sD8wUZUwDBoC5PPnK7ejkBNjDFruMHCN
9Tg3wBBAdT5XoiJKKWC6s6P0GF0I8b58z2d1bxTcMeHeRnARRk08SbVaA6NA
ul+u79wfYTT22+AFx1EqmCtgkX5bTEBU8aNTbENUMCv7Zs8/cRHE68Lu+VRx
DGRdOS30K0gE5YnNOb/b0ovZ+7nfncBEkVviH+lTk2Ogb65faSpVFHlkWx8i
7qIBbNuRkwnzoqj+gWwEvxUNJMBkR3MjMeT2jkvbKogGHqS7yuxNE0OiGi+0
OfJooPpvYsS+KTG0WtykbdRAA1azNT0XNInIi0u6U5NGAzF1Pn86womIdONj
7CLrOBBQ44uP38I3w4v715PFx0GGY8rJHXwkpGzmWLZTcRy8UpbcddaYhOR1
u9z1NcfB30IoZPWAhOzNitXFDcaBePFQIfcXElLvcU0oMxkHfg0ju6KWSIhM
c/dUshgHfSeLrNuVxNHjlovkOMtx4LEyXD97URxJhgz5Ms3HAcsVwdLRWHGk
EjfffH3Lf5/R5c1PSBydk+fl5tuK75d4XtdtShx97P8RNbCVf4ZwtAFPlEDU
m5eMVpXGgbollhmKSaA/sLbHQ2ocuIc3PKC7SKAzXy57nOQdB3nxx1dPPZJA
fudn6lOYNNAUungk840EopBiLvoM0MDMbMLh8SYJVJwjd4ryHw04VQ8UK05K
ILFZtTPLBTTwlJ2meI2TjKrlche+PN7Cs6OOI3m7yEgu29TCxJ0GZM9+HqJo
ktGr3iumuYY04B0vNStjQUaAuzGiV5YGAszcs10uk5HxMOeZzfUxEHx3yurt
bTIi8Dr0EDvGgDmn0O61B2TErh06d6RgDPxaZWWxSCAja5PbwOXuGNDkk01/
k0VGtqzbVD+eGgMs8+4BQm/ISC3OACcvNQauMqv/BZWS0Rtb9pLOCSroW+Ht
WKgko8wEYZm6T1QwohV8zAeRkXyaxyIulAou9FxvWPlKRhd+uBbGG1HBLh2z
3shaMkqrLY9/IkgFm+R7pZJb5z0Hrw8udo6CWm287ecaMqrb8/d5d8ooOOu1
66ltORndP+4Sp3tuFEQ+YzKWP5BR0ZpTiobUKOAnNA+nvSYjsYgak8beEUAJ
jgzXTSMjo8WP8mwvRoCXR+3Xoadk9ETcI2nizAjAltgtgoLJCL87ue8xYQTc
INTkEq6TUcvGksLcLwqwfEneTHcgI16xoYTdkRSQJzNiK3WcjOzvfZZSxSgg
fM/2G4+VyUiW5PhGijkMtgWZ/DdKICPdwiLiUtEwKLBzT9y3LIGs71TJfHcc
Br8/3DI8UymB+jx9m93rhwD1MJeRVrIEuuF8IO90wBDg9o/ALfhIoEMGYQ/P
KgyB2MQrSV27JVDicp/V0MNBoLaeeGRhRRzNHVji99UYBOFqURutTeKoTtgu
zJA6ADStkzpK3MXRtz2E6R5sAITpzQ4WqIsjPRw7+7nufiDH6OQ2YBFHT+w2
pX/t7wfks4oOBk9IKKva2de5uxdkTsRQAyKJqHvf0MRV6X9gfrjopffW/F74
Pf6s0ukv8PYfuWVIE0OF0wXvT2d3gzoPHfPT2mLIMCUn6seuP0Cr6P6625Ao
auM8XdXi2AU6DztyksNFUYdIk314RifgUUtK3FYtgoJs934wluwA3PqpfgRr
EVSY9+xCnEM7AAvBhu5UAsKF9XlTk9sATxVmFM9CQE3PvTJkxFpBNpegaiOH
EFLzXPsvWukX2H5pRF/+niCy/RmfXvu+ERz3NbwzNCOAbKhtInWHf4LAD9Yc
96O2o+HuWD7C8XqQL2sI9prxo/Fj4xrdW/vdSziHuZubD9UZWUfbXawD+lbw
ROx5blQQefn7w4ivwL3J7LcEkxPV8zR4QakvYNSfekgjjANVskzu9vSFgB7h
64rzYUNnWDomiBvloCElr/d2Fwvilq0/tW72CRxrjuaUUMSj0p1xKhWFJSBo
ndjYZLwKY+lm0Yns7wCfHI3wM44JVWvyZei4AtDvzCJ0vZQBPxbyJNoTXgEL
tuZfhpdmoPTciJ7NsQzA5dX31ICbCrVU678MEhMBt5Ov0KPSHphW/ynFsOUR
aA/5VNN6tA5+EmBvz++9CdR7ago0J/6BkNPBeyx0ImGRvpjFPe0xcKHktXjY
0edQ8/19/dtBs8DjrtWTZu4XULs3ZfCfNBNk50Y5vPuaCa9nXOAP4FkH6vJs
WrFWr2C3L1HDKhOPhen3VtiUvoYZThlqllQ2TMbhPuIeKYT9ltxvJxw4sbiB
Az6B/W9h9NL3pzg2XuyKpMPPuOb3cEpG/IrhyHbMdfyBpqhwMTy+ouhnwCqE
mSq6OMke/ghXs8SpU2oELMyhXc3+UAncdijnaEi8KFaHF/Xj5C+Fuz3qZFel
SVhJU4SsDCyFku9PmDVQJDDAd+Kfgn4ZHIu0bbOkSmHufK8GCcll0GVOpKxL
XBpzP2QTQiovgxVVT2iTM7uw9Gljo4iXZfCumDj567osxrXqR3Q9VgZdcfcV
UqzkMBb5uE+CL0pheqeFwBiHPEb/KVRhl1ECb71s8n2jrYQZfzO/a4l9hLva
TqtsS1LBWsYV+eguH2AYgTKh8+sIttebHirrlAcFJ++lYLNHsJzBBfysXB7M
bLOsayGoYfwZJYOKU7nQ9GHzzdJzahh8ZH+a5psLtWWzTxGYaphfQFGCcvAr
WOynN1VnqoEFu92/4eKbDTft9ux/fkcDg/vMzXpVsqFefvBR5yIN7A5J8mjc
RBbUPSDarLZdEzNM51F6dT4L9h4X95Qa1sS+ceq+ntTMhJ/z5cxB21Hs7WXX
EMUnaXBfGK9/J0kbyyWcXv5DfQGPJj+yqnHaskU3yRrgBcwrFiTvXtPGDmfm
PPw2mgJZU4ynKJYAu6eTdDZcNAnasNTfiPgAsFJvZ3MLh0SoXZPzUJkbw2In
+8S3pSVAof70UlkfDAuxmnaLFo2H9SfFeTTddbHMj2rPD/fGwsOGE8krH3Ux
V3++BXu2WDjoU7n8FncMM94oeQT3xMCwBT9NYatj2MvAB0+IkU9gh3VjjkDR
MWxnbbd5+afHsCqtIqiJVw8zHsv9duvfQ5ijJXvx2y09TDNJI0hrLhLSL+z+
SZ3Qwx40KdhVrETAP5/4J/966mNn3w18cmCEwwZY7WDOaoBpK1Edpf+Gwr5w
n1vFbw2wRKtQfEBRMNTsEIpx8T+OxapFjUw23YF/HKdd73qdwDTi7Z+EcfnB
jINryjYfTmIKKi2CxHVvmDxFMd7pY4RFdWm2FO64BvuE956svWWK2ezYtb/9
8HmoGBg6fGTWC0snn/uS2iBT/T+bJCZk
      "]]}}, {{{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], LineBox[CompressedData["
1:eJw12Hk4VP37B3BtluKxhXr0oEgblSUheSNrKSVFlpIlovBk6ZGUpY2ikCxJ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       "]], LineBox[CompressedData["
1:eJw12Hc8lf3/B3Ato7iFULdCkRbKSEheyEgphSKjZEQU7oxuSSmNm6KQjErI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       "]], LineBox[CompressedData["
1:eJw12Hk4lF0bAHAG80xJZclS3rIUbQq9ZEn3qayRijYvSSJSlix5o4WyJ1I+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       "]], LineBox[CompressedData["
1:eJw12Hc4le//AHAjezxGRh+FIi2UkZC8b7LTkiKjZEQIn4w+khKpKArJqCQZ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       "]], 
      LineBox[CompressedData["
1:eJw12Hk4ldv3AHCSeTq8iZCkEpcmuaZi7UpFJN1cSpkzKxm6lKQylCJjinQN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       "]], LineBox[CompressedData["
1:eJw12Hk8VOv/AHApTEl2h3IrFG0KXbKkz6OskYo2t9JGStlJ0YKrLIkW15p9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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHASkmSIY9jmWRlL3VS37yJjXGVoQCmipAF1dU0XJfOYzFOS
JCWzlHmWMoZShxAyc0hkfNe+7/Pb/+z9efbznOesddZ3OmLWDsa2W+jo6Hjp
6ejI+/9fguh/TzZXPd5tbhII5QiPq6deA5sMmhRpNu9TBeqp7vDvmws8G9i3
nmoyqJTch56Mhtg17MJ6ZSpKDYZDf0tnr2B3atVLymo+ADE5r1PL2IN5B+KU
SqLgeWt7xCK2geXK2wPycZDkQFyYx37AkOL1Z2oiXOG7UDWDnWSR8/kY9yOQ
/JRYOIFNx2lJldR8DFGlHYdHsTm2ywXKbKSB2Ce604PYb102J+VK0qHviBwD
Fbv7T9mNPbcy4B69/rEe7DuHJ0oU5DOhfIs7XiCBTjmcYlNOfQE8ToHONdjN
jiHxyubZ0P34AX0p9iV1lwJl7hwwqQrvzMK+vlb3llczD7imfXnTsO2owtt4
xfJBy/zObBy20vrATspGPuj4aZ/1xc4e2XN4V0khXHggPe6GHZy2asYZXQRu
zvRsjtjxQdWS7LeKIeB2JpsZtnZXeS6LfAn4nKial8JWvmSuufKoFBJEPAg+
bF2/cptFjzK4oaf6iQV7bXwvZc6sHHYHJTBPbRBoLHFIeHhXJYwd1jJ4gW0d
naT6/Vg1HDo+sSMBW3R42xfL/GqQSA69GIA99DDk0BfRGkiXaq+6hP1MT0y6
fb0G3uYa2PJgG+bfcil5XQeujZPldNg8GSGNKtL1UPdP8PPJdQI99zSoy4qq
h5WZFrUq7M8HGKsSnRogOcHuqA32oIvhA9c9TbB2Xetz7Bper/uQuMSj96Aa
VLDDDXuteog6QPkAE0/Zqi2wL+w7TUkJ+wBFjAHPhbDPvGDapHi2AK/YU9fE
VQIFbHl0bcv5NpgSZOL1WiGQN4vIuGVoB9SIuR03w65TN1BXe9cBskPf1/di
72nepbuLsRPYTiUOD/8mUJXc7vMNHp0gWJmdp4EtvsPLX/b6R1hiZNIfXSLQ
oxKp6a/Hu+HhjLxnCfZvlZhXuX7d0Bx/SiUIO2m3D5tvTTeMBubwymPPXwh+
JH+oByZCk4ev/iLQepb1rztyn6AgXMa75SeBblo+9lpi7oXrIzF1qjQCbaO7
fj+1jgqtj1d5VucIRIyrf3Jco0LGl+9LVdjSEo7FSLUPNq01buhjJzeZU749
6YPyOCNhi1kC2fxk06T49MPHlJAE22kCrV5hay4WHYBaV8ctMuM4Hl6dXqb2
D8LtYpnL38YI5DOZzF6+Mggp7+6Zx2IPy8h+S6IMweq87CIjdkCF7lMLwyEQ
VT413zdKILegiOru8iFgX1Zhcx0mUF7K7OfSpO/wY96jxeIbgVz9Ol0MzEfg
4qrvL2bsEKXOpRjnEdBkf1lY0E8g7s++koMRI+BwxXSOBdsu4LLv340jUBKt
ZptHxd/PONEsVnUU7He6ak/1EoiVXXvuw84fwBmrNsfZRSCuau+VnzVjcE7E
uTL3I4E8g0xsVfvHYEH5t8QJbKfuRsfbv8dgunngZVAngcpX56/MKY3DkNKZ
irV2Ah1XGH0/kjQO01nKgx9aCKS4/cvOijsTsD/nqopQI4FO3OfJENs9BQJP
KvWeNhDIQXncNU1nCpqyy4flsbf2C7eK207BD7+3aYfqCeRfmrgoljoFZbBw
9GQt3i9Hg70ClGl40aizcqmSQKEdfDM0+hlQWpYNUXiNP8/T6MOh3lkQpbvy
WO8pgSyp/wZur6UB01OriLJ0HA8zElIV7TTYFljEpYQ9dKTOzamfBj5VTh1c
TwjULi1o8uk3Dahyrn90p+Lzn6OV/0h5Hn5qFDzTSiJQEPuVVfGUeWBYzJDt
jsTn96QZmndZADreGOUcTwLt9nLueqawCK5dkTFqfxGo9pjqobivyyDKtnme
nodAsiptedZOa1B1SfdEQ68AKhfd3Gddswk3mS/+sT9SAAk0ikdKPadHLWoB
kZG6Auj7C/p5HUMGtOGpaMK+wo9eVPa/9BjdimJ+mX/7lsyPaiM+Xa9MZELN
lgmcF9X50czPJPbtituQCffRc1I9fIhpL3HhxlcWJF0RU0Cz5UN7VB8WVrqy
otTmFreDS7xonnHs8onFHWhDayI/2YUXuf/u/JM/cCcq+2jveXuNgpCMVfre
FXbkcrbQ5L4DBb21T6VPqeJAUSvnYrv6eVDe1k4xqjsncs+9NXPWmAc96Z39
U0qaC5mxffBTLuRGsj03Td71cqFUF1NnJYIb0U7csM302IWGFYRFTb13oam1
fxhTeblRie9xPo6PXIhLz7vgr7fcKBme98TIcyHeQlmhrwY8KIgw0pK4zYnm
hE2qm0d4UPrKfUalEg6U7ye40OJMQXw7du9+xMiB4turvH1+URBvqebBQ147
EcOJMWqnOy8S1K3qeMvIhtgEjZrRPC8KTTKn5YWwIiZVWkP8RT50U0loj8IU
C3LgehjR2MGH6Aq2naG32oYkrdRNhPbzIx/mLaKT2Uwo7j1b7Nd4flT313Jd
PScjyhAbnD1B40d9dKExcS4MaGdcf14tEkDDXEUf/31Nj/Kv89A6wgUQ5Wzk
+3Z2OjRYeC26p1MAlTSPPf7Xew00GmjqDNz4nC54Pj88sQy7Mwu5bQwIdPJE
RvDF4EXY+pdKk5gbgdTtDdiLPRZhd0Tx/V7s6XMMKqw3F4HZcq02wp1AQvty
ThSeXATj8LLmdQ8ChY8a0m+hLMK8W+FyhxeBtisccAxO/QlNlgUfrX0J9JP7
sNHZogXY3j7uIB1BoFd1ys1jfTSQi7wVp4rjQn9JLU8cx4lVl9rHGuz0FC+j
czU0eMCknHoSxxW7cmJFawYN9BxS5+wzCPStl90o14EGGaKm1xIyCaRT3ON3
mZ4GjuwSDcMvCfQx/a+iVMk5iGWN3yJThOu0AZ1iJ2UOuCcIr2fYPg+aLjOw
zMHlpKBQmWKch6sm9jZ/mQWLYImL0jiu14y8ufSvz4Ki+Q6q8BsCGa0f8d0f
PgMvHzIqrJYRqHHssVpu1xQsLBlKW9URyGx88Xj4myno4DNN6sBuDkyZuZEy
Bd+QaaY6zivam8EzcnZTsL589J4ozjs51+WpSauT0JEW/mcvzlNBHIrvbopP
guiXnPYD7wnUU0atrHcYh7edrefTOnAen304HGs6Di+eUyIYcR78dDU686ra
OFiLyJy1w9Y2oHDsYBgHya1Jz+Vx3kxqvWpnEDMG3T0vjXJxnpX3l48vLfsB
1HnZoiefCBTWtrPzNMsoNLxvrzzURyA+j4NPWiZHYL6/fDYWm4m5n1OzdQTW
CxzSfmJ7F+a8U3o4Ap4SRMRLnOed8ufztgiNAD2XTQhlAPdJP6R7Y5SH4f3e
88wfhwhk8UtA0uPMEBxWOLs2/YNAAq2cGT/UhuAobeDuYVyHFrxEeowFcd15
thEYgK168KGG7OAgRNxdEBPDdY2n8LJFm/0gOD1KdjSYIJDmAT56dk9c9yTa
/YOnCFSR4eGVo9sHxoLM0S9w3Vz0fMdjz9kHV39zGoxgB/88fUjyCxWQS0O0
MK7Dtt+jVGKvUUGGKjsYjl1vrTX3T9hX2CdWeubGPIGyNmquSXX1gj6Y1+7C
dVxe31u/N6kXDN/Hp2tjWz5laAyx7YWeCmc+V2xV3oqo+V+f4XrT5msqtsbJ
7LQ3/J+B5Q+dnpRFnJdHurQOXOiB0MDNsJ24b4BbtjrDMj2wmPUy/hB2NeOx
+Qdz3VD8dOLAZfK9ko7O1N1uUPekyJVhd1mIMSWndwGOxSnrZQJ9Lw2Pmh3v
hHh2w6lE3MfIGNyIiMvvBAGHMpFq7F5F0WPq7p1A15A3MoJtIGvX/mBHJ/AI
Kskp4r7IvVU5TUmpA+J5bMPeYHPOGFaVj7VCtZBeRynus/ai1IPljq0QuGdr
IRXb8tymZNlyC5Ts46OsYz9u9LUu2Yb7siHds0dwnxZQy5qdJfsePm+WdRVi
z2VLbMnIbYYMfuX8DmzKcX9q6sFmCGxc2jmDPVvcLhet+w60Pt/TlsJ9IkNR
g7WLXSMoCLplh2KPOMQIO841wAb3fd8MbA2jOccrLg3g1NZPrcA+/WNw0DSg
Hmbf32eZwT5ymU9lT2Yt+Pzhb66N+9Rsg+g+EeVauHOXVcEC21/nqwp3SQ3c
NezzdMAW57T+stpYDX4bV1JjsAdaHNvC2irhKAfH137stNxiodvfKuBN2a9n
s9j91mz9p2fL4ZW67M9N7LIy+QZB9jJ4/MJ+uwjuw6cVon9tCJdCIb17lwJ2
LL1h1oDiW7Dn6hY6gp3qMfcyzbAELC7YKp7Bdt903epj+RqkRRIXL2EnJj6c
s75ZDKWp/EfIucBuqjhWLKwQuljmtP2x6UMuWtClFMBVfx3WSOwQgS91/dn5
MD4/apiE/WrKIyGhJRf+6F0zycE+fjJEeO5tDkSt3eIpIees+0fvZH3JhlVL
5dNV2BJ/52rarLwA1y+qlCbsddF7kUICWeCg732qDft8mIldj1omBERwcZNz
03R1XWuYWQbUB00akXPVqVrnVm3XdLgtxMo+hC2QxOS4EZcGyopO+j/IOekM
b1lRSSpMpAsxT2FzbY2405ubDP3XODTmsHlNnaa05+IhwUFvbQE7oZxrskAp
BlZSmvYvYdtbFfqIOkSCwmTozG/si3Xy4fznQyFbJ16anDOVmmjhtK++oJs1
0beOvWuv49nIIg8QYL3HTc6p4qY+nGUaHvBJo40gffyNS/NImzt82r4pTvqD
8Y4jahNukKLPpEKaOe+70ICwK2hGFOiTVjei9LC8dIFdx3mMSdttUwrbp+YC
ElFmZ0lfuce94WfyD2zvDbQhHbZYRlUIcIZpqUB30jF6ClFneJyh2WrTm/QF
N3/9u2l/w7jCWT/Swmqrb7rKbsP0nbwI0sXu09HuNCdg/rAlnbR8/huDp55O
MB8YmklaLfg2QxurE4h8XnlJenUyz1Fc2hEOS/1bRJrfqSUqsug6BNwTrSct
R2dOP9p2DbxqKptIs158d0Ntwh5KItU/kBYUNdUeEL4K09+nOkkfuOSUv0/N
DsZtKD2kl444C/ubXAHZO+K9/+2HhuovhQBbsNMb6if9+iTN6m6aDdizxgyS
ziiNa+kquwSvzssPk25RzUp3p1nBcj7dOOmZfRSONlYroCs+Ovnffug4uotL
XwRdvQvT/+1/w/CTyKJz8EhUl0Zas+Sgm9qEObyw4Vgg3aTheHJA2Ax+Hyz9
SdrLO1Ta3+QMBCTr/iJtfDByTSHgFJhFliyR3qPi3dlVZgL2vKy/SS/6mmW6
04ygXB6tkI5fF/EUlz4Jxp1nVklvrch6FllkADLbjNdI7zdeMh4Q1oOjrYrr
pGOL5DYUArQgRnLmP9Pd0XruTlMHJdaIDdL+GkmZkUVHYDt5/Mh4rPiMLQ8+
5M+BvePxpd6aoYoj//uf5f8AtE1S4w==
       "]], LineBox[CompressedData["
1:eJw12Hc8Vf//AHBURsgeRfco0kIZCeH1JiOlJUVGH6GIwscqodCkUkiiksyM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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHDVSYakY57ZLoW4RUoR34VISokKxb2IJheRIZSha0hJSSTk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       "]], LineBox[CompressedData["
1:eJw12HlYTO37APBCaaOFtGqZQ+qtLOlto+4HoUTy8hbRinaSeIukaCGiVZRo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       "]], LineBox[CompressedData["
1:eJw12Hc8lf/7B3C7kmSUEdl34tMy0kfF9dagJGVUyEoRkRmlbBnZZZSQLUKl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       "]]}}, {{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.832885283134289`, 1.9101299543362336`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.336618828644992`, 3.762221576582356}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {9.526279441628825, 5.5}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {8.42648887430876, 7.070663706551931}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {7.070663706551931, 8.42648887430876}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {5.5, 9.526279441628825}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {3.762221576582356, 10.336618828644992`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {1.9101299543362336`, 10.832885283134289`}}]}}}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox["\"Array Gain for drive [-1,1,1,1]\"", TraditionalForm],
  PlotRange->{{0, 11}, {0, 11}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.414754396000914*^9, 3.414754431976625*^9, 
  3.4147584954423447`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"drive", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"PolarPlot", "[", 
    RowBox[{
     RowBox[{"ArrayGain", "[", 
      RowBox[{"drive", ",", "height", ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "maxGain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Array Gain for drive [1,1,-1,1]\>\""}]}], 
    "]"}], ",", "grid"}], "]"}]}], "Input",
 CellChangeTimes->{{3.41474668457058*^9, 3.414746777265751*^9}, {
  3.4147469053450403`*^9, 3.414746922105953*^9}, {3.4147469894986362`*^9, 
  3.414746993168701*^9}, {3.414747050886303*^9, 3.41474706589158*^9}, {
  3.4147471546560783`*^9, 3.4147471595428*^9}, {3.414747204281204*^9, 
  3.414747234472851*^9}, {3.414747269739746*^9, 3.414747311131422*^9}, {
  3.414747685657402*^9, 3.414747686847406*^9}, {3.414748362509151*^9, 
  3.414748424965287*^9}, {3.414748494209344*^9, 3.414748556929154*^9}, {
  3.414748654622649*^9, 3.414748717422875*^9}, {3.414748764785789*^9, 
  3.414748765135943*^9}, {3.414748796898699*^9, 3.414748798321002*^9}, {
  3.4147488770687103`*^9, 3.4147488993898697`*^9}, {3.414748942727558*^9, 
  3.414748945605701*^9}, {3.414749260250078*^9, 3.4147492638159313`*^9}, {
  3.414749310563262*^9, 3.4147493534354143`*^9}, {3.414749532205264*^9, 
  3.414749536508419*^9}, {3.414749577779962*^9, 3.4147495785222273`*^9}, {
  3.41474961160553*^9, 3.4147497316875677`*^9}, {3.414749788667225*^9, 
  3.414749812563993*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwUW3k4VN8fti8zZox9m5lkSaIkW9nOh1TSoo0s7YWilISUpZKtIkoo+xIq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      "]]}}, {{{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], LineBox[CompressedData["
1:eJw12Hk4VP37B3BtluKxhXr0oEgblSUheSNrKSVFlpIlovBk6ZGUpY2ikCxJ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       "]], LineBox[CompressedData["
1:eJw12Hc8lf3/B3Ato7iFULdCkRbKSEheyEgphSKjZEQU7oxuSSmNm6KQjErI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       "]], LineBox[CompressedData["
1:eJw12Hk4lF0bAHAG80xJZclS3rIUbQq9ZEn3qayRijYvSSJSlix5o4WyJ1I+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       "]], LineBox[CompressedData["
1:eJw12Hc4le//AHAjezxGRh+FIi2UkZC8b7LTkiKjZEQIn4w+khKpKArJqCQZ
kUNkbyJ7Ze+RvbKyx+8+/a7v+eec1/U81znnvq/7vZ69pvY6FlQUFBRclBQU
5Pf/f7Gh/30KKU4t3t4mkB270H+vA6/DObpqWrLduxLkXwfaw2aTRv0mdtzA
ob4Z0l0wFRXl28B+TFulEhT4EPh5nCdWsbkG80Le5npB1juhU8vYIp6KaJr0
FN6Xn+BcxL7f8fyFYuRzEIxOsZ3FftSndvtl4EtwQQGaU9hRP56N25cEQG5i
a/wodteMWltIbhDMrz3yG8SeGRH/rzAtGCghaLEb+3lSQOkIKQS++TP2tWIn
qBWlscSFQTblmHYD9pcUJiXpyLewmd2CF0igJ+ynCI/AD8ArO5KQjR3qMxj5
sywSTp0xFknBrqZoWzEv+QjymQ/jIrAjbzm2PMv9BFz6R0ivsd/dstX5Jysa
aPkVZXyxKzYyH3xJiwH6grCfjuT9oh1vqSHFgcbvwWFLbIlggVWjhM+wuhB0
3xDbd1Qrbyo2HobkxaWVsI/w7ONkivwC/z7UrKHF9shRDlEOTIbn261rS1sE
upOjHmep/hV+MNYljmB31Pl+J5V9BdeS1fBSbJ6rsjJyJSkwJHA+8h72mfpb
ddq536BF99jETezAXPHVV3Jp0KfqnqmDfWBesqU5Mw1yQw27D2JffK8VZpiW
DvycUufrNwlUXj3LZ0HKhD1ibmmZ2DcGx8Njj2TBHZLE+w/YjEJluaPxWaBs
MLlyG9s80bHLKjYbrPnfdezA7lmeNLr5IRc29M4jvg0CJVsdyNEOKIQ6XW6p
1XUC7aM0LudgKYLR8+5BrdjTShJjDy4WwY18sfcvsUt532hc6SyCJbvDzWtr
BDqXxW5KOVUMZf5HGtNXCUSh2zmsTpRCtr1yhC82DRWrSPKlUhB32NFxDVvi
2EkG7tBScF94EUKDHTjy/tugYBmoBPyQ1V4hUC+LhstdyR9gdiSMuWCJQLeT
zn/0u1wBc1FlaT7YSp6mD2bCKmB0JaFKF1uQuW/iXG8FXGCKhvE/BJILlLjN
alkJlyetzzFhv2Sm/vP0vyrwkhGjkF7A57cjaNvsbQ2UHv4nj+c3gQ5pmmYb
OjQAG9V6fcsMPh88lG7oVQM48d8xD8L+LOuzJvy1AQK0DxAs2J/u6EtM/26A
b8tVNmtTBLq2Sudwz74RuDvHlfMnCNTqol/y1O4nHHzu4fBrmEAcbGbI2rYZ
uP9cDAvA7ruXVqH6ohnU3/cqA/YhHYZtwcRm8KsR5w0bIlBRR5Fj62Qz2HHU
V6v9IpByhIf9KZsWeMgnp+/bT6DfHexK67daQUzemkjtxPtRINckadkOmWvn
FXWwJaeNzc2etMO5CpaFuQ4CxZs7hQTFtMOnizwzR7HvFoUNzP9qB7Toezi2
jUCGnikriSYdwHRcqcCtmUD3PjlVshp0AuezZMPqWhxv+4O+emt3Q2qnt4YR
dprr9dB4m26onbHInaohkOwTMc5a325wZ9aSYsb+JjBXyFHZDdqGjTaqVQQ6
RtCNh6r2ACFhRPnxB4Gkj62yvVLshfqp4qqNAgKJOVyW5+Tth5bg7WJHbHMf
nr2/D/bDsP7moYl8HA/s0wVVcv1w8ZeydksegXbsi+J/ZNgPGwHyndE5OP58
Bi0mIvpBYoie/1AGgX4VSTYm7R8AGcSo9yORQHzbDHSbkoNgFygqohuKz7f/
5qUI7SFwdhSZSQ0hkP1UH4260RDoMC7KsWOf+ZZr+dtmCHI0dxrXBON8duGW
PDwfAlWm5EaFIAItTQ3s7KocAoUcLxdafwJFVDhbUasPQ19dQZGCF4G0K5u6
diqNgJ2Z6cxxWwJdDuD1FpMeg5WTXk+TpQj071mTVZLVFOzX71SzX2BFdT6F
SVVoFuzO3mUvSGZF6RzCqzP75+EBPQVpwZgVWYb3GtMeXYSJFTGuGgZWdNZN
RE6HbQnUO6O82L+yoLGArci2wWVIbODPyFBjQWeNliIDWlfhmBD/TooeZjTJ
szdaN2odrpvsa3M0ZUZhOwU0CL9NEH2lWCs7yIQkTObmA25ug+Zl6dNJZkzo
JrXJdbEXFGhfWMm1zZ+MaPPW0c7xO5RI9fFldW5VRkRxMqa6SZUKoaT5uR3R
DOh5hGaP2n5qpNDi3xi/RY+MaWazVNap0ekZuQe7r9GjPiVDm4H8Hcj3Yymd
UTwdEm8olz/6nAYJ7/a+8XCNFlXJEPk6qrTo3ORmxmNNWiRpzZd/e4kWLQ+U
8Hl40aDqYeFa/a90aK/w0UTFsh2I9Fi8vUWPHjGrPBrQnqNG0ek1QRG0DCj3
K43TJz5qVHPB30v6CwNavlKiG3CeCinF2O0/q8iIWNKo2lRvU6I3U0Ntca2M
qPys5qWXwRSIEJQdpbjGhKRUWzjl7m/DhfkY5z3dTOhBxUaEVOQmTFdzGbkY
MyM7L/HGoO51uKNlP7dRx4ze0Dt0XZ5chd2lxDMBZRZ0x90n7/zOFXASyZLh
iGVBe7UmTJPQErCh9Ng+ClYUwsV70gYWgUvqCaecIStaXNpZesJwHuwVShMa
4liRIK23ka3mLDiExfZoz7Mim8/pxVauU3CsyMQ7VxLHacWRUs0PY3BuwoiB
ypJAlBHjU0/8x2B02pSmGVv/W07Md/cxKNxUuRNjRSBr+YqKk0ZjEGfgH6Fm
TSAZ56lukV1jcO10HfK8TSDdiVMeY4Gj8G6r5nOvI4EUEl5U8T0ZASaP99NH
PHCc5p04dgnHwX+ecT48OC6uPGs2CjYcgqz5Fa4c7P6OANm2M0PAKVopbITj
alrGauuq6BCMTHVVRoQRSEjZsMpw+heEZT6W4H+H43JxV/gF+19QaZDjRPOR
QNyHpespHAdh6V5TtnMCgQzGha/KmQ2CgqtKAP0XnCerGML/vTQIR/xHJ8Kx
5zISlAakBsFqLEe4AMf1vmLho/mLA/BAWS91K4lAl9I7si1dBuA+t5OU1TcC
neV5pOrj2g/X+dgLunNxX1PHn09v3Q+PLOZVjHEeOe/IvvTUoB8y7OJ1erBz
NAYTvU/2w8vdAVTdOO980tO7tbHWB7G97GlNhQRyPXG1uJyqD/Z/lTFK/E6g
hjbBQFqOHrDkMkijqsZ5qZI7b2m+G1iYzDicsBuPPrk70tQNvUL0y0PYg6Vf
okuDuyF3h6BuGc6TqseZht12dcNCg56xRx2BWAvHLVoFu2Bj9m5CXyOBpgym
YhWPdkDYFSPh0+0EWm79qe3O0gFx6WrRJOwjF/d55k62g9o8ezAPzut2PIbv
ZT63g/qb05Xj2LFyNbEH9rZD0M5+t6ddBCoLd/b9w9EGEl7W9J97CXT66Ytc
lSVcdyZIqe647lhGxTq5NOO6JKt1phV7bluoIS61GaYLXumK4zqlgD47MNg3
w4wWd3Y3Nq+Js1XFaBPIZrRXSo4SKO8LX9bxjp+Q0zdNXzpOoIC5tO3G3AaQ
a3NeuIfr5guNvAiFdw3AuEduPA/bafX7Ruz9BugypzPdwuaqLlm+d6oBwteL
uh/iupx/gHYGHtSDfNaLpfuzBGIW+pcl/3EtXNH4mnN9Hq+H2e6Dr2otlH9P
7g/Dtg3tK9CjrQVFoS8+TdgmjZvxs09rIJIh0FwV132HSintPc+rYUSRXlFo
EX/f+YVQ04BK0B/pfFCO+4SM6sMuh3Qq4QmzVPMqdk+o9uxvjkr4M+CaeAT3
GRoVooVurytA61XDsB+2iYr9oH9IOfTs8XPTXibQwdSHPNHvy2DFIEoyFfcx
9Hr6JyyulUHzcf+MbuzkB4HUIgJlEOhknE+L+55IHYaY2MhSqPf7dOkqtsBx
zgPRn77DSkJe1Ar2pX/EKALii0Er7V2VAO67koU9bm2ZFwNj6Q4TVWwZti5P
G8FisKg1N7XGjnkTXKUSgvsyEcakVGyGHZIfRxkK4ed2m4kC7vM4rp7Nzvco
ANHmaWNj7D8joqpBy/kwEr5U7o4t8w9nicJwHtAm9Q7mYR+84RzsU5QDP1RW
paRx3xg6/eWV4YkcsFl4E3oB+3WVIadYUjbIyghZ22L/EaXKrnubBQZuNLpR
2IJ0FlXMdzPgIOmXMh3uY6Xu31Drmk6HxaAxVgFs+qEXxvHm6ZB1tV1dBlv7
0RlLFZ00KOhwoTDDnqGzEHMRS4WO6OgX6dhVfK3lStEpsHLrT2EF9kNZUXYW
vhSYpBQ36cLeSjPNiaL/CvZXLo9uYRNXbyh2biVBvP3pOgL37aQsd1e7KRIw
c/HuE8TWVJ3RCy7/AimdjmyAfTpjD83B9AQosF1LOIvtJ/D4RE5UPPjZ3Uwl
zwXDbonQ4x4HPCXTdC7YQaWaAnY2sVAcTn/FkzyHfG0O2dKPAcY5OnZ/bDYp
a0t+6U9gpvSt9hP2gNiFCtLeKPBuu1ZPwi543dmiQHwEK6GZU5nYb07OHApZ
/QDJqya7irD3Uh7gSmt+D58kMm9UYLdPyt9tSH4L4jGz3OS5acKexmDKNwwG
jrHItWHXU5uW090MgblvzBU92PyCopX7lILhBNvv77+w9QBundodBMcOp4mO
Yxf3uKToLb+CrTFDqhlss3kjvV/RfmApM6Iyj9281+s7t6EPtGzpLP7BLtHi
ydVk9wZ9iSg28hx5wqHh4v1yD/hY2BS2jj0tVi1jvP4fMESMviTPobq+fHrF
lg7w/HvP/Ba2rKvIpX0iDgDUMutklzShCNpKeyBF2FKT59jx2VI/3xI7SB9z
4iQ73OisTWC6LdypnJMgmzLW1FRX0hbmRhTkyC7SMbjKnWwDB01uIrLFeufV
wj9bQ4mF7jmy2RbbBKPeWsHH/HdWZD89SvCY81rBaFanHdlC/GIsIsGWMEIs
O5GdtltgNd7/JhCNVR5/72+dqE95ZA70kb1vyL7vebPMccsMuFyJd2TflKjN
Oe5mBp0k/o9kr30wjsl2MgW/w+0Jf+9fDnMttjSBdw6ZeWQXC69201Zeh9sH
uorIZqF4/8O35Bosy/WUkr2R8TgsMN0IpO7cr/n7+zlVntzJhjASsquBbLNv
Czbhnw1AZ1dwE9k9r+dPRb3VB52jBzr/Xo+pEhEJ1oPR76d6yKZb9yES/K+A
dJpk/9/nBN4l/SmPdGE5LnOY7OPzpyqPu10Cuy/qY2R3/opOyXbSgXeMGRNk
5wbLeRZbXgChbrHff83X1Oxbcg7unTsxR/bdYI6YwHRt8N0tsEB2AIW0c/hn
LdBRG14ke9ZcTjXqrQY0VfsskX2vSpgrwV8NmEnMK2Tzhq0MpTxSgc3x26tk
J7dnpGU7KUOcJ2mN7AMBNx4XWyKgv1u9TjaJl0k96q0s/LkTtfn3/wRN4uvH
oIR8vLAbhVi9iy0F4V/ydpPXb7RTSiQ2ReF/z1H+DyG4TJA=
       "]], 
      LineBox[CompressedData["
1:eJw12Hk4ldv3AHCSeTq8iZCkEpcmuaZi7UpFJN1cSpkzKxm6lKQylCJjinQN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       "]], LineBox[CompressedData["
1:eJw12Hk8VOv/AHApTEl2h3IrFG0KXbKkz6OskYo2t9JGStlJ0YKrLIkW15p9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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHASkmSIY9jmWRlL3VS37yJjXGVoQCmipAF1dU0XJfOYzFOS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       "]], LineBox[CompressedData["
1:eJw12Hc8Vf//AHBURsgeRfco0kIZCeH1JiOlJUVGH6GIwscqodCkUkiiksyM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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHDVSYakY57ZLoW4RUoR34VISokKxb2IJheRIZSha0hJSSTk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       "]], LineBox[CompressedData["
1:eJw12HlYTO37APBCaaOFtGqZQ+qtLOlto+4HoUTy8hbRinaSeIukaCGiVZRo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       "]], LineBox[CompressedData["
1:eJw12Hc8lf/7B3C7kmSUEdl34tMy0kfF9dagJGVUyEoRkRmlbBnZZZSQLUKl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       "]]}}, {{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.832885283134289`, 1.9101299543362336`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.336618828644992`, 3.762221576582356}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {9.526279441628825, 5.5}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {8.42648887430876, 7.070663706551931}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {7.070663706551931, 8.42648887430876}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {5.5, 9.526279441628825}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {3.762221576582356, 10.336618828644992`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {1.9101299543362336`, 10.832885283134289`}}]}}}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox["\"Array Gain for drive [1,1,-1,1]\"", TraditionalForm],
  PlotRange->{{0, 11}, {0, 11}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.414749791039632*^9, 3.4147498143771963`*^9}, 
   3.414754396316298*^9, 3.414754432297371*^9, {3.414758500710495*^9, 
   3.4147585116039248`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"drive", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"PolarPlot", "[", 
    RowBox[{
     RowBox[{"ArrayGain", "[", 
      RowBox[{"drive", ",", "height", ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "maxGain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Array Gain for drive [1,1,-1,1]\>\""}]}], 
    "]"}], ",", "grid"}], "]"}]}], "Input",
 CellChangeTimes->{{3.41474668457058*^9, 3.414746777265751*^9}, {
  3.4147469053450403`*^9, 3.414746922105953*^9}, {3.4147469894986362`*^9, 
  3.414746993168701*^9}, {3.414747050886303*^9, 3.41474706589158*^9}, {
  3.4147471546560783`*^9, 3.4147471595428*^9}, {3.414747204281204*^9, 
  3.414747234472851*^9}, {3.414747269739746*^9, 3.414747311131422*^9}, {
  3.414747685657402*^9, 3.414747686847406*^9}, {3.414748362509151*^9, 
  3.414748424965287*^9}, {3.414748494209344*^9, 3.414748556929154*^9}, {
  3.414748654622649*^9, 3.414748717422875*^9}, {3.414748764785789*^9, 
  3.414748765135943*^9}, {3.414748796898699*^9, 3.414748798321002*^9}, {
  3.4147488770687103`*^9, 3.4147488993898697`*^9}, {3.414748942727558*^9, 
  3.414748945605701*^9}, {3.414749260250078*^9, 3.4147492638159313`*^9}, {
  3.414749310563262*^9, 3.4147493534354143`*^9}, {3.414749532205264*^9, 
  3.414749536508419*^9}, {3.414749577779962*^9, 3.4147495785222273`*^9}, {
  3.41474961160553*^9, 3.4147497316875677`*^9}, {3.4147497994918823`*^9, 
  3.414749805937935*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwUmHc81e8XwO097sUdrpEkMyWjkvScBiqRSmREMhqiJKIllaZZohCRlJER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      "]]}}, {{{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], LineBox[CompressedData["
1:eJw12Hk4VP37B3BtluKxhXr0oEgblSUheSNrKSVFlpIlovBk6ZGUpY2ikCxJ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       "]], LineBox[CompressedData["
1:eJw12Hc8lf3/B3Ato7iFULdCkRbKSEheyEgphSKjZEQU7oxuSSmNm6KQjErI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       "]], LineBox[CompressedData["
1:eJw12Hk4lF0bAHAG80xJZclS3rIUbQq9ZEn3qayRijYvSSJSlix5o4WyJ1I+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       "]], LineBox[CompressedData["
1:eJw12Hc4le//AHAjezxGRh+FIi2UkZC8b7LTkiKjZEQIn4w+khKpKArJqCQZ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       "]], 
      LineBox[CompressedData["
1:eJw12Hk4ldv3AHCSeTq8iZCkEpcmuaZi7UpFJN1cSpkzKxm6lKQylCJjinQN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       "]], LineBox[CompressedData["
1:eJw12Hk8VOv/AHApTEl2h3IrFG0KXbKkz6OskYo2t9JGStlJ0YKrLIkW15p9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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHASkmSIY9jmWRlL3VS37yJjXGVoQCmipAF1dU0XJfOYzFOS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       "]], LineBox[CompressedData["
1:eJw12Hc8Vf//AHBURsgeRfco0kIZCeH1JiOlJUVGH6GIwscqodCkUkiiksyM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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHDVSYakY57ZLoW4RUoR34VISokKxb2IJheRIZSha0hJSSTk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       "]], LineBox[CompressedData["
1:eJw12HlYTO37APBCaaOFtGqZQ+qtLOlto+4HoUTy8hbRinaSeIukaCGiVZRo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       "]], LineBox[CompressedData["
1:eJw12Hc8lf/7B3C7kmSUEdl34tMy0kfF9dagJGVUyEoRkRmlbBnZZZSQLUKl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       "]]}}, {{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.832885283134289`, 1.9101299543362336`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.336618828644992`, 3.762221576582356}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {9.526279441628825, 5.5}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {8.42648887430876, 7.070663706551931}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {7.070663706551931, 8.42648887430876}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {5.5, 9.526279441628825}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {3.762221576582356, 10.336618828644992`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {1.9101299543362336`, 10.832885283134289`}}]}}}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox["\"Array Gain for drive [1,1,-1,1]\"", TraditionalForm],
  PlotRange->{{0, 11}, {0, 11}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.414749807329309*^9, 3.4147543966724157`*^9, 
  3.4147544326677732`*^9, 3.414758517240027*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"drive", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"medium", " ", "=", " ", 
   RowBox[{"PolarPlot", "[", 
    RowBox[{
     RowBox[{"ArrayGain", "[", 
      RowBox[{"drive", ",", "height", ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "maxGain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Array Gain for drive [-1,-1,1,1]\>\""}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"medium", ",", "grid"}], "]"}]}], "Input",
 CellChangeTimes->{{3.41474668457058*^9, 3.414746777265751*^9}, {
  3.4147469053450403`*^9, 3.414746922105953*^9}, {3.4147469894986362`*^9, 
  3.414746993168701*^9}, {3.414747050886303*^9, 3.41474706589158*^9}, {
  3.4147471546560783`*^9, 3.4147471595428*^9}, {3.414747204281204*^9, 
  3.414747234472851*^9}, {3.414747269739746*^9, 3.414747311131422*^9}, {
  3.414747685657402*^9, 3.414747686847406*^9}, {3.414748362509151*^9, 
  3.414748424965287*^9}, {3.414748494209344*^9, 3.414748556929154*^9}, {
  3.414748654622649*^9, 3.414748717422875*^9}, {3.414748764785789*^9, 
  3.414748765135943*^9}, {3.414748796898699*^9, 3.414748798321002*^9}, {
  3.4147488770687103`*^9, 3.4147488993898697`*^9}, {3.414748942727558*^9, 
  3.414748945605701*^9}, {3.414749260250078*^9, 3.4147492638159313`*^9}, {
  3.414749310563262*^9, 3.4147493534354143`*^9}, {3.414749532205264*^9, 
  3.414749536508419*^9}, {3.414749577779962*^9, 3.4147495785222273`*^9}, {
  3.41474961160553*^9, 3.4147497316875677`*^9}, {3.4147498374927597`*^9, 
  3.41474984554729*^9}, {3.414758338025276*^9, 3.414758365184702*^9}, {
  3.414758531450761*^9, 3.414758572473538*^9}, {3.414759279210463*^9, 
  3.4147593054098797`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 0, 0], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwVV3c41t8bNt73lczsPV4rCtkNOgeRMrIplRFaolIqvjKjzCR7JWREQhmh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      "]]}}, {{{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], LineBox[CompressedData["
1:eJw12Hk4VP37B3BtluKxhXr0oEgblSUheSNrKSVFlpIlovBk6ZGUpY2ikCxJ
yB6Rxr6EpqxJ2bIlZGdOKEtFv8/0u77zz8zrmnOdmXOuz33f789Zb+VsaLuU
hYWFewkLC/P9/19f8b9PERU5Fb9/U3DiFf/vfihwiK2OlWnvznTl+6EGWGjS
fbdAnNK7pYeRaQwrKSnhX8TXWGs1w0JPQUTIfXSeWKCvJOJhsTUKYsT3zhJL
+qmqTWTa4VHVbv5vxJfbb99RjXOEWOLzc1+JfXu0z98NdYaHWojeOHHCm1sj
zpX/ojijNW2IuJOh3RZR7IqpH75BfcSMwe3/vaS5YwnCvnUR334WQh/MvIgX
wSt7WonTtctpXCmeKFwyrN9I/PT5KnX5OC8sFLaQC6Rwg3cvt0/oVaxRHEwv
JI4M6Iv78NoHew9YSD4nrmNpm7Op9IVy/tWUWOK4s64tt4r9IWCyLfM+cczZ
c4Z/F1wDq4iqQiBx9a/8K09p18FeFvXBlXm/WEda6jNvQpfqG7AjlgkXnTdP
v4X56bDLZsSBQ/tLxpMD8EV5u7w68TahDfyr4m7j36t69azEPkUaERqhd3H7
d+uPmUUKF4p0Uux07uHNyoaMQeL2hsBXma/vwbNyPppOLHRCUUGpMgRfRA3i
LhEfeHe2Qb84DC1GO0fPEIcWb5+/p3QfPVre+YbEm6ZkW5rz76M40qxrM/GR
R/ujzGjhEOGXM3i3QKGq7quwbWYE/pH2ouUTn+4biU7eFokLmTKPHhOvFH9d
PJQWCQ3TsbnzxDYZrp32yVFwEIlpX07cPTtmfubxQ/wyNlAT/kUhy35TkX7I
YzQYCcrN/6SwYYlFFR9XHIYMvMNaiSfUZYavHInD6VLpR3eJ6Wse6B7viMOM
09bmHz8oHCrgtVoyHo/Xwdve585TYDHqGNDhTkShs0ZsIPGKpX9JZh1NxHaX
5e0niWV27uEQjEyE9/SdiBXEoYOPXvSJJUEz5I2i/hyFT1y6Hhdlk2G9LYqz
bIbC+WcG8UHHUjGZ8JoWQKzuZ3WFEZWKobn0WiNiMc6e0UOfUnF4VSJGvlNQ
CpU5/5ddGo6NORxaRXyXc9n3m/+lw19BmkV+mqzf9rDf1g8zQN/6d4kQRWGL
nlWhmUs2eJb+fNfCIOtDaImX2r1suIlcsAkjTlUM+CGRnY0Q/U3cXMRPLpjI
TFDZeDFb6/hjnMLJeTaXS87PIdgxolE6SqHVw6TyplMONt/2cekfoMDHY63m
cI4Gwe9HokKIey7RqrXu0KDz6JMGiLcYcvwWy6AhqH77mqgvFMrby11bx2hw
4ntXp91PQSPWx3mvYy6uCiuZBH6mQLXzqv88mwdpZQfunA5yP8qUmmTtCpD/
w0DVkFh2wsLG+kYBDlVzTU+2U0izcYsISyrAkyNCjB3EF8ujeqf6C6D2LXBr
chsFM7/ncxmWhVi1S73Mq5nCpSduNX+ZFoH/VpZZ3VtSbxvDsq/rlyCn47qu
OTHN81RkmmMJ3jJsi8frKSjekOZ/G1gCb879cpzEL0QnX/LVlEDf7L2jVi2F
ndxsI5FapeCWMV8S/4aC/M55nnuqZXg3XlH7q4yCtMsxZf415WgJ/13hSmwT
ILSe2lyOAZOFLaOlpB54J8pqlcpxpF9Dv6WEwvINCSK+ZuX4FaLckVhE6i+g
z3Y0thwyX9hFtuRR6C+Xff9sYwUU1FYav8mgIPybg21BthJOoVKSRpFkfQcv
HI3Vp8PdVZKRE0HBebxnhY45HYYrvynxEh94UWxHOdJRpLfaoj6c9LPDZ5Vx
mw6tVVnvVcIozIz3ru6soUOlyN+DNZhCbLW7/TKd1+hpKCtX8aegX9PUuVr9
DZysrRi7zlE4FrLmurR8Neb2+N/MkqPw70HL+Uz7emw06dB2nmagIeDls1q1
RjgdvMhblsVALp/EPGPjB1xhZ8mctmDALvqTBeuOZozOSQvUczBw0EtSyZCn
FTodCf682RMYDlmMa+trQ0ajSF6e9gQOms/EhbS2Y6e4yGqW7nGMCa1PNEro
xCnLDW2uVuOIWi2qyx3UDal7qm8V+8YgYzk5FXKmB3rH5Pc9sx7DmWWWp6Tv
fMaGqMqTCx9GsXB2R8fIhV5oXTumI6g1CpY9SXVNWn1QezY1uTxxBLdj9bq1
N/ZDpSX4fdriMCxWfC3Q/NmPfQylK+tODqNH3cyxt/QLAuPpbOZpQ9jeWKW8
4/YAJNZdP331xyBqFbhLDbUGcWhsIe+a3iBkHYRLz88MYra3UtjHfwB1AxJv
TbKHsF5iR4bq6y/IvLb9Y4vxMDg1fXv1J/uRmFsfFss6guLsFW5PhPtRfzjY
X/7pCGaPVxqFGPRBPclp40HVUXDRlrZpne/Fg/EvbSmto6g6qHf0bvhncIsp
DrGcHIOcVgu/0uUeHJ5Kcv+nawxXqn/FysV1Y6JOwNzDYhxO/tvfh3V14sJ+
58lfDeN4wO7SeWysHevo3LdENSZwwTugxGD1R7hJFijwJU9g/f5Rq2dqreBR
y03uYWEgQmDNHkc0Q0DuBr+SGQPfZlbTd5t9gLMKPb0xhQEx1uvm5/Qa4RKV
3K0/xYBjam6FvWc9dpZbXi+WJXVavY2u97gah0bNOZbaUVgSOzJ+I7gaQxNW
K5qJTV4UJb3yrsbLBc0LSfYUHJSrq/eYVyPFNDhW24GCgvt4l+Taapzc16Dm
d56C0ehen+HQKsQs1qd+cqWgkn6nVvjGG6zyeTSxzYfUacnunUdJHfznlxIg
ROri+K1m83AzOgqm5gSKiD+3hyi2HaCDX6pGwpzU1YSC/eIJKToGxztrYqMo
iGuY1ZpNvEJU/jUZkRhSl9/WRh92foUa0yK3FfEUBLfKv2NxrcTMpaZC93QK
piMSJ5SsK6HiqRnC/pT0yVqO6H+PVmJb8NBoNPFkXrp6r1wl7IeLJMpIXW+o
kNhR+q0CVzSMcxafUTia215o51GBy4JucvYvKBwU8tUK8CzHKWHesq5ikmsa
RErZHcrhazulaUH6iIEr78xN03LkOaUZdhMX6fZlXN9TjrvrQpZ2kb7zxNj4
7K8fL5H8iZfW9JKC5+4TFVVLX2JjtoJ5xisKjW1ioax8pbATMKUtrSN9qUaw
ZGaqBFyrrPnciN/vuHFxsKkEn8TZZ78Q99GfJtLDS1C8XMzoNemTWrtWDXit
LcF0o7GFTwOFv16O2LaKFePX14vpPe8pjJuOJ6vuKETUcXOJfR8pzLZ+0Pfm
KkRKrnZiJvG2Ixv8iscKoD3FGy5E+rqTkNkjhdQC6DzYVzNCnKxUn7xpfQHC
Vn/2utlJ4XW0e+B3vnzI+Duwp36isO/mnWLNGTJ3RjNzvMncsUtIdvNoJnNJ
cf+BVuLJ3+KNKTk0TJTdM9pO5pSKWqoLhzMNjP2ChV3Eayzd7auHXkAx72ON
7BCFkqfCBbvac1DUM8FOH6EQMkn7/b44G0pt7tOXyNy8o1sSqxKTjZX/KI2U
ELvNv/qVfDkbnTZsVovEAnWVs5f2ZiP6Z3nXVTKXSzexMnAlC8oFd2Yuf6XA
Kf4vV+m1TBzXzS46NUWuh9PpcaBWJqpeZX2OIj4X2VNmzJoJVfGnAU3Elu8X
0r7ezEAcR6iNFpn7LjVy+v/cfopBVXZV8W/kfAbTkVYhaTAZ7LhSRXJCXt1W
jy2GabjBKdc8T9wdqf+V4kvD917PjG0kZ+hWS730up+K/fcaB4KILTWd+4Ij
UtD9T5CX/iyFzTlXhRIfJWHONEE2h+QYdmOT3bYnk9C8KzivizjrSugySdEk
hLpZlLKS3BNnyJGUHJeId0FPjp4gFt3FvynxyRPMpZckzBEf/VuaJSQtHvtp
MbWiJHdlSficXbSJx0r6ckstYgWeTj9HsXjYvrWxciBOehBeqxlBcpnkymc5
xBzLZeOHOB7jw+82SxWS8/hOHCws9YmFVPOEhQXx90EprbDZRxiMnqnyJlb4
m79SZSAGrM8+9ZUQbz7tHh5QHo03mvNy8iQ3Rk48vWe2OxqO0w8iDxPfrzXj
l34WBUUFcYdzxN+llhY2PIyEqdcKowRiMTbbWs6LD7A5s1+DjeRYucuntTsn
wvEtbPgvUWL2L3cs0mzCUXDio44Csb7vATtNw/soa/dgsSZmsNlKe0iHoj0x
8U4uca1wa5V6Ygjmzn5/WU18VVGKl0s4BGNLtlt2Ei/SrIoS2O/B+fixoUVi
7hOnVTsWg5HmvK+Bm+T2zAJvT6fxIHAKrNkgRqynxTAOr7qN5x2uPCDel/fP
is25gSg79yP9IHGQ6LXdRQkBCHI6k8PcFwx4ZaDb+yaEKifYPIjD6HqiTo43
UBHNftyPuQ/Jbo5YNLmOlZNsvMHEPHIOdiLy/rBWf/H2CXGv9OHqzPV+uN52
8l0mcdn9jhYVbl/YizP25hM/2MPYEjF/FVnzlmvLidcv2SRAa/bGE5n809XE
H8eULzZmeWF70ldB5r5p1HmF6XigJ3p3cim1Eb9bZlXFduYiJl9wVncTi4hJ
1WxQd8duHupVP7ExcHbvOlfs3EqTGiGu6PZ4bjzrgsVhs6UMYuspc+P+xPOw
UxjUnCJuXu//StDsLFoWDb99J67cL1Ssx2sLE5kEHuY+crdL45HLVZaIf9kU
9ZN4QrpOweKnCThih+4y96FGgcLGFXaHcftV99QisaKn5NENkoeBZQo/ma5s
UotlrTFAZuy5Zcx97MhXelBg5SHkDrvxMx1tftAxNFcfF2omZZhekmxlZSSr
j8lBFSWmyw1NTwhmHcBmyzNqTEt/mtKOTt2PSlujQ0zzfGsTS3ioi/jSGHum
b+7gFrJZo4uhgg4npsVFpLkkw3UwyD3rxjRtneh8WrA2uN/X+vw5vnX03XNf
TbDHfXrA9GW/M69dF/dBwJM7hukzMm+LdnntQ0emSDzTPx5bJBW6aSBo68f0
P8fPRnlW2KkhxiW/hOkKifku1hrg/KbOcqa5WB69CaxUxaxSN53pX3nXokJz
VSB34XL9n98vqvUTzNqDwYi1jUxbv5h2jE5VhuHa8Camu+9P7U14qAjDHZs6
/nyfVCspGb4bQ6/2djPN9jOAOz1YAfI02c9/nhNcr/z83Fcesyn5A0zvmtpb
s8tLDk5PdYaZ7uhPfF7oJouYlXmjTBeHK/lV2O2EeJc0xfTFcL6k0FwpBK4T
nWb6q42SVsLDzWiqC5hhek3U3JfnvhJYGDk/z/SmkNPXKuzEwH6x7uef84WN
EfOgkrkcmP/PfLWcZHKIyv+ec/wf6Sr1GQ==
       "]], LineBox[CompressedData["
1:eJw12Hc8lf3/B3Ato7iFULdCkRbKSEheyEgphSKjZEQU7oxuSSmNm6KQjErI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       "]], LineBox[CompressedData["
1:eJw12Hk4lF0bAHAG80xJZclS3rIUbQq9ZEn3qayRijYvSSJSlix5o4WyJ1I+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       "]], LineBox[CompressedData["
1:eJw12Hc4le//AHAjezxGRh+FIi2UkZC8b7LTkiKjZEQIn4w+khKpKArJqCQZ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       "]], 
      LineBox[CompressedData["
1:eJw12Hk4ldv3AHCSeTq8iZCkEpcmuaZi7UpFJN1cSpkzKxm6lKQylCJjinQN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       "]], LineBox[CompressedData["
1:eJw12Hk8VOv/AHApTEl2h3IrFG0KXbKkz6OskYo2t9JGStlJ0YKrLIkW15p9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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHASkmSIY9jmWRlL3VS37yJjXGVoQCmipAF1dU0XJfOYzFOS
JCWzlHmWMoZShxAyc0hkfNe+7/Pb/+z9efbznOesddZ3OmLWDsa2W+jo6Hjp
6ejI+/9fguh/TzZXPd5tbhII5QiPq6deA5sMmhRpNu9TBeqp7vDvmws8G9i3
nmoyqJTch56Mhtg17MJ6ZSpKDYZDf0tnr2B3atVLymo+ADE5r1PL2IN5B+KU
SqLgeWt7xCK2geXK2wPycZDkQFyYx37AkOL1Z2oiXOG7UDWDnWSR8/kY9yOQ
/JRYOIFNx2lJldR8DFGlHYdHsTm2ywXKbKSB2Ce604PYb102J+VK0qHviBwD
Fbv7T9mNPbcy4B69/rEe7DuHJ0oU5DOhfIs7XiCBTjmcYlNOfQE8ToHONdjN
jiHxyubZ0P34AX0p9iV1lwJl7hwwqQrvzMK+vlb3llczD7imfXnTsO2owtt4
xfJBy/zObBy20vrATspGPuj4aZ/1xc4e2XN4V0khXHggPe6GHZy2asYZXQRu
zvRsjtjxQdWS7LeKIeB2JpsZtnZXeS6LfAn4nKial8JWvmSuufKoFBJEPAg+
bF2/cptFjzK4oaf6iQV7bXwvZc6sHHYHJTBPbRBoLHFIeHhXJYwd1jJ4gW0d
naT6/Vg1HDo+sSMBW3R42xfL/GqQSA69GIA99DDk0BfRGkiXaq+6hP1MT0y6
fb0G3uYa2PJgG+bfcil5XQeujZPldNg8GSGNKtL1UPdP8PPJdQI99zSoy4qq
h5WZFrUq7M8HGKsSnRogOcHuqA32oIvhA9c9TbB2Xetz7Bper/uQuMSj96Aa
VLDDDXuteog6QPkAE0/Zqi2wL+w7TUkJ+wBFjAHPhbDPvGDapHi2AK/YU9fE
VQIFbHl0bcv5NpgSZOL1WiGQN4vIuGVoB9SIuR03w65TN1BXe9cBskPf1/di
72nepbuLsRPYTiUOD/8mUJXc7vMNHp0gWJmdp4EtvsPLX/b6R1hiZNIfXSLQ
oxKp6a/Hu+HhjLxnCfZvlZhXuX7d0Bx/SiUIO2m3D5tvTTeMBubwymPPXwh+
JH+oByZCk4ev/iLQepb1rztyn6AgXMa75SeBblo+9lpi7oXrIzF1qjQCbaO7
fj+1jgqtj1d5VucIRIyrf3Jco0LGl+9LVdjSEo7FSLUPNq01buhjJzeZU749
6YPyOCNhi1kC2fxk06T49MPHlJAE22kCrV5hay4WHYBaV8ctMuM4Hl6dXqb2
D8LtYpnL38YI5DOZzF6+Mggp7+6Zx2IPy8h+S6IMweq87CIjdkCF7lMLwyEQ
VT413zdKILegiOru8iFgX1Zhcx0mUF7K7OfSpO/wY96jxeIbgVz9Ol0MzEfg
4qrvL2bsEKXOpRjnEdBkf1lY0E8g7s++koMRI+BwxXSOBdsu4LLv340jUBKt
ZptHxd/PONEsVnUU7He6ak/1EoiVXXvuw84fwBmrNsfZRSCuau+VnzVjcE7E
uTL3I4E8g0xsVfvHYEH5t8QJbKfuRsfbv8dgunngZVAngcpX56/MKY3DkNKZ
irV2Ah1XGH0/kjQO01nKgx9aCKS4/cvOijsTsD/nqopQI4FO3OfJENs9BQJP
KvWeNhDIQXncNU1nCpqyy4flsbf2C7eK207BD7+3aYfqCeRfmrgoljoFZbBw
9GQt3i9Hg70ClGl40aizcqmSQKEdfDM0+hlQWpYNUXiNP8/T6MOh3lkQpbvy
WO8pgSyp/wZur6UB01OriLJ0HA8zElIV7TTYFljEpYQ9dKTOzamfBj5VTh1c
TwjULi1o8uk3Dahyrn90p+Lzn6OV/0h5Hn5qFDzTSiJQEPuVVfGUeWBYzJDt
jsTn96QZmndZADreGOUcTwLt9nLueqawCK5dkTFqfxGo9pjqobivyyDKtnme
nodAsiptedZOa1B1SfdEQ68AKhfd3Gddswk3mS/+sT9SAAk0ikdKPadHLWoB
kZG6Auj7C/p5HUMGtOGpaMK+wo9eVPa/9BjdimJ+mX/7lsyPaiM+Xa9MZELN
lgmcF9X50czPJPbtituQCffRc1I9fIhpL3HhxlcWJF0RU0Cz5UN7VB8WVrqy
otTmFreDS7xonnHs8onFHWhDayI/2YUXuf/u/JM/cCcq+2jveXuNgpCMVfre
FXbkcrbQ5L4DBb21T6VPqeJAUSvnYrv6eVDe1k4xqjsncs+9NXPWmAc96Z39
U0qaC5mxffBTLuRGsj03Td71cqFUF1NnJYIb0U7csM302IWGFYRFTb13oam1
fxhTeblRie9xPo6PXIhLz7vgr7fcKBme98TIcyHeQlmhrwY8KIgw0pK4zYnm
hE2qm0d4UPrKfUalEg6U7ye40OJMQXw7du9+xMiB4turvH1+URBvqebBQ147
EcOJMWqnOy8S1K3qeMvIhtgEjZrRPC8KTTKn5YWwIiZVWkP8RT50U0loj8IU
C3LgehjR2MGH6Aq2naG32oYkrdRNhPbzIx/mLaKT2Uwo7j1b7Nd4flT313Jd
PScjyhAbnD1B40d9dKExcS4MaGdcf14tEkDDXEUf/31Nj/Kv89A6wgUQ5Wzk
+3Z2OjRYeC26p1MAlTSPPf7Xew00GmjqDNz4nC54Pj88sQy7Mwu5bQwIdPJE
RvDF4EXY+pdKk5gbgdTtDdiLPRZhd0Tx/V7s6XMMKqw3F4HZcq02wp1AQvty
ThSeXATj8LLmdQ8ChY8a0m+hLMK8W+FyhxeBtisccAxO/QlNlgUfrX0J9JP7
sNHZogXY3j7uIB1BoFd1ys1jfTSQi7wVp4rjQn9JLU8cx4lVl9rHGuz0FC+j
czU0eMCknHoSxxW7cmJFawYN9BxS5+wzCPStl90o14EGGaKm1xIyCaRT3ON3
mZ4GjuwSDcMvCfQx/a+iVMk5iGWN3yJThOu0AZ1iJ2UOuCcIr2fYPg+aLjOw
zMHlpKBQmWKch6sm9jZ/mQWLYImL0jiu14y8ufSvz4Ki+Q6q8BsCGa0f8d0f
PgMvHzIqrJYRqHHssVpu1xQsLBlKW9URyGx88Xj4myno4DNN6sBuDkyZuZEy
Bd+QaaY6zivam8EzcnZTsL589J4ozjs51+WpSauT0JEW/mcvzlNBHIrvbopP
guiXnPYD7wnUU0atrHcYh7edrefTOnAen304HGs6Di+eUyIYcR78dDU686ra
OFiLyJy1w9Y2oHDsYBgHya1Jz+Vx3kxqvWpnEDMG3T0vjXJxnpX3l48vLfsB
1HnZoiefCBTWtrPzNMsoNLxvrzzURyA+j4NPWiZHYL6/fDYWm4m5n1OzdQTW
CxzSfmJ7F+a8U3o4Ap4SRMRLnOed8ufztgiNAD2XTQhlAPdJP6R7Y5SH4f3e
88wfhwhk8UtA0uPMEBxWOLs2/YNAAq2cGT/UhuAobeDuYVyHFrxEeowFcd15
thEYgK168KGG7OAgRNxdEBPDdY2n8LJFm/0gOD1KdjSYIJDmAT56dk9c9yTa
/YOnCFSR4eGVo9sHxoLM0S9w3Vz0fMdjz9kHV39zGoxgB/88fUjyCxWQS0O0
MK7Dtt+jVGKvUUGGKjsYjl1vrTX3T9hX2CdWeubGPIGyNmquSXX1gj6Y1+7C
dVxe31u/N6kXDN/Hp2tjWz5laAyx7YWeCmc+V2xV3oqo+V+f4XrT5msqtsbJ
7LQ3/J+B5Q+dnpRFnJdHurQOXOiB0MDNsJ24b4BbtjrDMj2wmPUy/hB2NeOx
+Qdz3VD8dOLAZfK9ko7O1N1uUPekyJVhd1mIMSWndwGOxSnrZQJ9Lw2Pmh3v
hHh2w6lE3MfIGNyIiMvvBAGHMpFq7F5F0WPq7p1A15A3MoJtIGvX/mBHJ/AI
Kskp4r7IvVU5TUmpA+J5bMPeYHPOGFaVj7VCtZBeRynus/ai1IPljq0QuGdr
IRXb8tymZNlyC5Ts46OsYz9u9LUu2Yb7siHds0dwnxZQy5qdJfsePm+WdRVi
z2VLbMnIbYYMfuX8DmzKcX9q6sFmCGxc2jmDPVvcLhet+w60Pt/TlsJ9IkNR
g7WLXSMoCLplh2KPOMQIO841wAb3fd8MbA2jOccrLg3g1NZPrcA+/WNw0DSg
Hmbf32eZwT5ymU9lT2Yt+Pzhb66N+9Rsg+g+EeVauHOXVcEC21/nqwp3SQ3c
NezzdMAW57T+stpYDX4bV1JjsAdaHNvC2irhKAfH137stNxiodvfKuBN2a9n
s9j91mz9p2fL4ZW67M9N7LIy+QZB9jJ4/MJ+uwjuw6cVon9tCJdCIb17lwJ2
LL1h1oDiW7Dn6hY6gp3qMfcyzbAELC7YKp7Bdt903epj+RqkRRIXL2EnJj6c
s75ZDKWp/EfIucBuqjhWLKwQuljmtP2x6UMuWtClFMBVfx3WSOwQgS91/dn5
MD4/apiE/WrKIyGhJRf+6F0zycE+fjJEeO5tDkSt3eIpIees+0fvZH3JhlVL
5dNV2BJ/52rarLwA1y+qlCbsddF7kUICWeCg732qDft8mIldj1omBERwcZNz
03R1XWuYWQbUB00akXPVqVrnVm3XdLgtxMo+hC2QxOS4EZcGyopO+j/IOekM
b1lRSSpMpAsxT2FzbY2405ubDP3XODTmsHlNnaa05+IhwUFvbQE7oZxrskAp
BlZSmvYvYdtbFfqIOkSCwmTozG/si3Xy4fznQyFbJ16anDOVmmjhtK++oJs1
0beOvWuv49nIIg8QYL3HTc6p4qY+nGUaHvBJo40gffyNS/NImzt82r4pTvqD
8Y4jahNukKLPpEKaOe+70ICwK2hGFOiTVjei9LC8dIFdx3mMSdttUwrbp+YC
ElFmZ0lfuce94WfyD2zvDbQhHbZYRlUIcIZpqUB30jF6ClFneJyh2WrTm/QF
N3/9u2l/w7jCWT/Swmqrb7rKbsP0nbwI0sXu09HuNCdg/rAlnbR8/huDp55O
MB8YmklaLfg2QxurE4h8XnlJenUyz1Fc2hEOS/1bRJrfqSUqsug6BNwTrSct
R2dOP9p2DbxqKptIs158d0Ntwh5KItU/kBYUNdUeEL4K09+nOkkfuOSUv0/N
DsZtKD2kl444C/ubXAHZO+K9/+2HhuovhQBbsNMb6if9+iTN6m6aDdizxgyS
ziiNa+kquwSvzssPk25RzUp3p1nBcj7dOOmZfRSONlYroCs+Ovnffug4uotL
XwRdvQvT/+1/w/CTyKJz8EhUl0Zas+Sgm9qEObyw4Vgg3aTheHJA2Ax+Hyz9
SdrLO1Ta3+QMBCTr/iJtfDByTSHgFJhFliyR3qPi3dlVZgL2vKy/SS/6mmW6
04ygXB6tkI5fF/EUlz4Jxp1nVklvrch6FllkADLbjNdI7zdeMh4Q1oOjrYrr
pGOL5DYUArQgRnLmP9Pd0XruTlMHJdaIDdL+GkmZkUVHYDt5/Mh4rPiMLQ8+
5M+BvePxpd6aoYoj//uf5f8AtE1S4w==
       "]], LineBox[CompressedData["
1:eJw12Hc8Vf//AHBURsgeRfco0kIZCeH1JiOlJUVGH6GIwscqodCkUkiiksyM
S/YWIjPjY2WPbNe6ttDvffs9vvefe5+Pe+6597zv+7XOLnN7vWsMdHR0AvR0
dLTn/3+IoP+9CilJK/nzh0B2XKJ3XgfawxmmGkaaPTsTlF4H3of1phP169hx
/ft7p8hPwFxCQmgN+yFjtUZQ4EsgCbiMr2DzDRSEvMsPgpz3oipL2OI+qmiS
HAIfKo7yzGN7tD97rhrxDkSiU2/OYHv3at16GfgRXFGADgU78vvTMfvST5Cf
1Bo/gt05pdUWkh8F1FXvFwPYU8NSd75mxAA9BM13YT9LDigbJsdBuv/W3lbs
BK3iDPa4eMilH9VtwE5MZVWTi0iE9dwWfIEEesylwuEVmAKCCsMJudhvfQci
/iv/AiqnTMVTsWvo2pYtS1NBKft+XDh2xA2nlqf56cBneJD8Gvv9jZt6O3Iy
gJGkKu+HXbmWfS8xIxOYi0L/c6KtF+NYSy05G05MDwxZYUsHEysmCTmwMhfk
YYztN3KygBKbC4NKUnJq2AcFdvOwRuTDv/d1ahmxvfLUQ9QDv8KzP62rixsE
cszTjrPSLobvW+uShrHb6/y+kcuLwa10JawMW+CygrxiaQkMEmcj7mKfqr9R
p5v/DVr0D49fxw7Ml1p5pVgGvZqe2XrYe6kyLc3ZZZD/1rhrH/b5DydDjTPK
gcQje7Z+nUAVNTNC18gVsFPSPSMb++rAWFjswUpwJEt/+Ii9VbQ8fyS+EtSN
JpZvYVsmOXVax1aBDel9+2bs7qUJk+sfa2DN4CwSWiNQivXePN2AeqjT55dd
+U2g3fSmFdzsDTBy1jOoFXtSTXr03vkGuFoo+eEldpngmxOXOhpg0e5A8+oq
gc7kcJnTUxqh3P9gY+YKgej0O4a0OZoh11493A97C8M28ZQLzSDlsLn9Crb0
4WMs/G+bwXPuecgW7MDhD+kDIi2gEfBdQXeZQD3sJ1xvy7SCxcFQtqJFAt1K
PvvpxcWfMBtZnuGLreZjfm8q9CeMLCdU62OLsPWOn+n5CedYo2FsgUCKgdK3
tlm1w8UJmzOs2C/ZNi08udMBD+Ql6eTm8P5tD/pj8a4Lyg7sKBCYJtB+HfNc
Y4c+4GT4Xd8yhfeHAL07etUHziRHyyDszwq+q2Jf+iBAdy8HO3aUo6H05HQf
pC9V265SCHRlhcnhrn0/8HeMqReOE6jV1bD0id0A7Hvm5fBriEDcnBbI5uYg
8C+cDw3A7r2bUan5fBC0P/SoA/Z+PZY/IkmD8KJWSjB0kEDF7cVOrRODYMdd
X6P1i0Dq4V72KrZDcF9I0dCvj0DT7Vxqv28Mg6SSDUdaB16PIsUmGatRyF49
q6qHLTNpamnxeBTOVLLPzbYTKN7SOSQoZhSizgtMHcK+XRzaT/01Cmje70Bs
G4GMfVKXk8zGgPWIWpF7M4HuRjlXbTMaB56nKcY1P3C87Qn68kiXAmkdj06Y
YGe4/fM23pYCP6au5VNqCaTwWJLnhx8FPNlOyrJhpxOzX7mrKKBr3GirWU2g
wxxMY281J4FD2oT+03cCyR1e4XylOgX1lJLqtSICSTpcVOIRnIGW4D8lTtiW
vgK7pvfNwJDh+v7xQhwPXJNF1YozcP6Xum5LAYE2744keRvPwFqAUkd0Ho4/
34Fr4+EzID3ITNqfRaBfxTKNyXtmQR5tNfieRCChPyxM6zJUsAuUENd/i/e3
//qFcN15cHESn0oLIZA9pXeLtsk86G2dV+TCPpWebzVtOw95OrymtcE4n527
oQTP5kGTNaVROYhAi5R+3s6qeVDOe+DK6E+g8EoX603aC9BbV1Ss/IBAulVN
nbxqi2BnYT515CaBLgYIPpKUW4blYw+epMgS6N/TZitk6zXYY9ihZT9HQnW+
X5OrER2yO32bqyiFhDK5xVam9jCge8x05DlTErIK6zFlPLQZjS9L8tWykNBp
d3FFPU5GpN0R+YDry040GrAR0TbAhJIaSFlZWjvRaZPFiIBWFnRYlMRL1y2M
JgR2RetHsqJ/zHa3OZkLo1Be4gTHC3Yk8Ur1h8KAEJI2m6UGXOdAOhfljidb
CKHrm8z+kXzOiXaHll5Z/28HWr9xqGPMkQtpPryoza+5A9Edi6lp0uRGKJk6
uzl6O3oWrtOttYcHKbf4N8ZvCCLTLTM5Gr950PEpxXvCVwRRr5qxbX8hL/L7
VMZkEi+ApBoqlA4940Niwo+u3l/lR9XyHIV6mvzozMR61kMdfiRjI1R4a5Ef
LfWXCnk94EM1Q2I/DL8IoF1ih5JUy3kR+aHUzxYDQcSm4d2vO8uDojNrg8IZ
t6P8L1uco4R4UO05/wdyidvR0qVS/YCz3Egtxm7PadUdiD2DoU3zFhd6Qxls
i2vdgSpO61x4GcyJOEQURuiuCCFZzRYeRQ8OdI4a47KzSwjdq1wLl41gR5M1
fCaupsLI7oFUY1AXK3I8aT+7VieM3jA7dF6cYEHCZRxPCfWdyNHTt+AsLzNy
Fs+R547diXadHDdPRoyIE2XG9tKRUAif4DFb2Iz4ZB/zKBqT0Pwib9lRYwZk
r1yW0BBHQiKMj0xu6tAhh9DYbl0qCdl+ziyxdluDw8Vmj/JlcJxWHizT+bgM
Z8ZNWBisCEQfPkZ57L8MI5PmW5qxDdPzYr55LsPXdQ3HGGsC2ShVVh4zWYY4
I/9wLRsCybtQusS3L8OV43XI5xaB9MdVvEYDl+D9Ru3nHicCKSc8rxZ6vAis
Xh8mD3rhOC04evgCjoM7PnG+AjguLj1tNgk2nocc6jJfHnZfe4BC26l54JGo
EjPBcTUpb71xWWIehimdVeGhBBJVN642npyD0OyH0qT3OC7nt4eds5+DKqM8
5y2fCMR/QK6ezokKi3ebcl0SCGQ0JnZZ0YIKym4aAcyJOE9Ws4T9e4EKB/1H
xsOwZ7MS1PplqWA9midWhON6d4nYocL5WbinbpC2kUygC5ntuVaus+DB7yxr
nU6g0wLemr5uM/CPEFdRVz7ua+pIhcw2M+B9japhivPIWSeuxSdGM5BlF6/X
jZ13YiDp0bEZeCkcwNCF806UgcGNtdVpiO3hymj6SiC3o5dLKhimYc8XeZOk
bwRqaBMJZOSeBCs+owyGGpyXqvgLFqkUYGe14HbGbjz0+PZwEwV6RJmXBrEH
yhKjy4IpkL9ZRL8c50nNI6xD7tspMNdgYOpVR6BtX8eutYpMwNrM7YTeRgJR
jCixqofGIPSSidjxnwRaav1P15N9DOIytaLJ2AfP7/bJnxgFLSpXsADO63YC
xh/kP4+C9pvjVWPYsYq1sXt3jUIQb5/7k04ClYe5+C1wj4D0Axvmzz0EOv7k
eb7GIq474+Q0T1x3rCJjnV2bcV1SOHmqFXv2j2hDXNogTBa90pfCdUoZfXZg
sR+EqZP8uV3YgmYu1pUjv0Ah62eVzAiBChKFco60D0Be7yRz2RiBAmYz/jTm
94Fim8vcXVw3n58oCFd+3wdbdyqOFWA7r3xbi/Xog05LJvMNbL6a0qW7Kn0Q
9ru46z6uy4V7GafgXi8o5Txf9JghEJvov+yFD7vh0okvef9Q8fWw2X300+yG
im8pfaHYN9/2FhkwdoOqaKJvE7ZZ43r8zJMuiGAJtNTEdd+hSlZ357NOGFZl
VhWdx+c7O/fWPKAdDIc77lXgPiGr5oDrfr12eMwm27yC3f1Wd2aaux0W+t2S
DuI+40SlxFf31z/h5KuGoRfYZhr2A/4hbdC984W77hKB9qXdF4j+0ALLRpEy
abiPYTYwPHrtSgs0H/HP6sJOuRe4SZxogUBn00JG3PdE6LHExEY0Q/2LqAuX
sYkjPHujo5pgOaEgchn7wg5JuoD4RjiZ8b6awH1XipjXjQ3LRthattlME1ue
s9PHVqQRrv2wNLfBjnkTXK0Rgvsy8a3Jadgsm2U+jbDUw39/2syUcZ/Hffl0
bqFXHUg0T5qaYi8MS2gGLf2A4bDFCk9s+R08pcpDtcCY3DNQgL3vqkuwb3E1
fNdYkZXDfePbycRXxkerwXbuzdtz2K+rjXkkk6tAQV7U5ib2ggRDbt27SjBy
36IfiS3CdK2a7fZ32Ef+pc6E+1hZj6tanZPlMB80uo3AZh58bhpvWQ45l39q
y2Prep+y0tArg6J2VzoL7Cmma5KukqXQHh39PBO7Wqi1Qi26BJZvLHytxL6v
IMHFLlQCE/RSZp3YGxnmeZHMxWB/6eLIBjbH5auqHRtFEG9/vI4D9+3kHE83
O0ohsPEJ7hbB1tGcMgiuyIfUDidOwD6etXPLvsw8KLq5mnAa+wXx8GheZC68
sLueRpsLhtyToNszGwRKJ5lcsYPKdAg72ywoCWO+5EObQ740h2wYZsLWWSYu
f2xOWRsrklw6WKil/4jC7pc8V0nelQaP2q7Uk7GLXne0KHOkgrXolEo29ptj
U/tDVlIgZcVsezH2Lvq9fBnNZIiSzr5aif1zQul2Q0oiSMXM8NPmpnH7LUYU
v3joP8yu2IZdv8m8gul6HMyms1V2Y5NEJKp2q8XAUc7pb7+wDQBuqAhHweED
GRJj2CXdrqkGSxGwMWrMMIVtQTUx+BX9AazkhzWo2M27HnzjNw6Flg29+QXs
0pMC+TpcwWAoHclJmyOPOjSc96h4BZ++NoX+xp6UrJE3/f0UWMJHXtLmUH0/
IYMSKy949q2buoGt4CZ+Ybe4F8Am+d80lzahcMaq+0AOv7mJNseOzZS98Cu9
B5mjzjw0h5mctg3M9ADHqllpmuljzc31ZTxgdlhZkeZiPaPL/CnusM/sOqJZ
soeqFfb5LpRe0z9DM+d8m0jkuzvwqfC9Nc1PDnEIWAregZGcDjuaRUmS7OLB
t2GYY8mZ5gxhYiXe3xU4Gqu9/h7fOl6f6u0MzBE9b2j28Lle7rThBHxuHO9p
vi79I++IuxN0kEmfaF79aBqT6+wILw78TPh7/FKoW4mVA7x3yC6guURspYux
yh5u7e0sppmd7sN3v1I7WFLsLqN5LethaGDmTZB19Kj9+/151T78KbYwHLK9
gWaL9DnbsM82oLc9uInm7tdUlch31qB3aG/H3/djqsXFg61g5JtKN81Mv305
Evyvg1yGTN/f+wSPSvtSvS1hKS57iOYjVJWqI+4WYJeoPUpzx6/o1Fxnc3i/
NWuc5vxgRZ8SKzMQ7ZKc/muhpma/0itw98zRWZpvB3PHBGaagJ8wMUdzAJ2c
S9hnI9DTGpqnecZSUTPynSE01fgu0ny3Wowvwf8SsJHZlmkWDF0eTPXWh/Wx
Wys0p/zMysh11oM4H/IqzXsDrj4ssToHzLdrftNcz7sYF5ipC7srKtZoJguy
ake+OwELjpHrNGerMA6nemvA/bvGG39/b9AE/jyCUtr2w24U3faoxOow/Ev7
O2jrY8IrKx5bovy/+yz/B0ijbtM=
       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHDVSYakY57ZLoW4RUoR34VISokKxb2IJheRIZSha0hJSSTk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       "]], LineBox[CompressedData["
1:eJw12HlYTO37APBCaaOFtGqZQ+qtLOlto+4HoUTy8hbRinaSeIukaCGiVZRo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       "]], LineBox[CompressedData["
1:eJw12Hc8lf/7B3C7kmSUEdl34tMy0kfF9dagJGVUyEoRkRmlbBnZZZSQLUKl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       "]]}}, {{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.832885283134289`, 1.9101299543362336`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.336618828644992`, 3.762221576582356}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {9.526279441628825, 5.5}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {8.42648887430876, 7.070663706551931}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {7.070663706551931, 8.42648887430876}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {5.5, 9.526279441628825}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {3.762221576582356, 10.336618828644992`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {1.9101299543362336`, 10.832885283134289`}}]}}}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox["\"Array Gain for drive [-1,-1,1,1]\"", TraditionalForm],
  
  PlotRange->{{0, 11}, {0, 11}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.414749848694503*^9, 3.414754396907239*^9, 3.414754432888056*^9, {
   3.414758345456736*^9, 3.414758368227688*^9}, 3.414758523717432*^9, {
   3.414758564299774*^9, 3.414758574057605*^9}, 3.414759307834119*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"drive", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nosebleed", " ", "=", " ", 
   RowBox[{"PolarPlot", "[", 
    RowBox[{
     RowBox[{"ArrayGain", "[", 
      RowBox[{"drive", ",", "height", ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "maxGain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "1", ",", "0"}], "]"}], ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Array Gain for drive [-1,1,-1,1]\>\""}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"nosebleed", ",", "grid"}], "]"}]}], "Input",
 CellChangeTimes->{{3.41474668457058*^9, 3.414746777265751*^9}, {
  3.4147469053450403`*^9, 3.414746922105953*^9}, {3.4147469894986362`*^9, 
  3.414746993168701*^9}, {3.414747050886303*^9, 3.41474706589158*^9}, {
  3.4147471546560783`*^9, 3.4147471595428*^9}, {3.414747204281204*^9, 
  3.414747234472851*^9}, {3.414747269739746*^9, 3.414747311131422*^9}, {
  3.414747685657402*^9, 3.414747686847406*^9}, {3.414748362509151*^9, 
  3.414748424965287*^9}, {3.414748494209344*^9, 3.414748556929154*^9}, {
  3.414748654622649*^9, 3.414748717422875*^9}, {3.414748764785789*^9, 
  3.414748765135943*^9}, {3.414748796898699*^9, 3.414748798321002*^9}, {
  3.4147488770687103`*^9, 3.4147488993898697`*^9}, {3.414748942727558*^9, 
  3.414748945605701*^9}, {3.414749260250078*^9, 3.4147492638159313`*^9}, {
  3.414749310563262*^9, 3.4147493534354143`*^9}, {3.414749532205264*^9, 
  3.414749536508419*^9}, {3.414749577779962*^9, 3.4147495785222273`*^9}, {
  3.41474961160553*^9, 3.4147497316875677`*^9}, {3.414749856917431*^9, 
  3.414749862764683*^9}, {3.4147586493709497`*^9, 3.41475867891716*^9}, {
  3.414759322482974*^9, 3.414759357739749*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 1, 0], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwUmnk0VV8bxyXzkPHec433mOdrjkx3lyEUwi+hVBIpSZQyRCRJyFCKSFFS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      
      "]]}}, {{{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], LineBox[CompressedData["
1:eJw12Hk4VP37B3BtluKxhXr0oEgblSUheSNrKSVFlpIlovBk6ZGUpY2ikCxJ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       "]], LineBox[CompressedData["
1:eJw12Hc8lf3/B3Ato7iFULdCkRbKSEheyEgphSKjZEQU7oxuSSmNm6KQjErI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       "]], LineBox[CompressedData["
1:eJw12Hk4lF0bAHAG80xJZclS3rIUbQq9ZEn3qayRijYvSSJSlix5o4WyJ1I+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       "]], LineBox[CompressedData["
1:eJw12Hc4le//AHAjezxGRh+FIi2UkZC8b7LTkiKjZEQIn4w+khKpKArJqCQZ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       "]], 
      LineBox[CompressedData["
1:eJw12Hk4ldv3AHCSeTq8iZCkEpcmuaZi7UpFJN1cSpkzKxm6lKQylCJjinQN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       "]], LineBox[CompressedData["
1:eJw12Hk8VOv/AHApTEl2h3IrFG0KXbKkz6OskYo2t9JGStlJ0YKrLIkW15p9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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHASkmSIY9jmWRlL3VS37yJjXGVoQCmipAF1dU0XJfOYzFOS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       "]], LineBox[CompressedData["
1:eJw12Hc8Vf//AHBURsgeRfco0kIZCeH1JiOlJUVGH6GIwscqodCkUkiiksyM
S/YWIjPjY2WPbNe6ttDvffs9vvefe5+Pe+6597zv+7XOLnN7vWsMdHR0AvR0
dLTn/3+IoP+9CilJK/nzh0B2XKJ3XgfawxmmGkaaPTsTlF4H3of1phP169hx
/ft7p8hPwFxCQmgN+yFjtUZQ4EsgCbiMr2DzDRSEvMsPgpz3oipL2OI+qmiS
HAIfKo7yzGN7tD97rhrxDkSiU2/OYHv3at16GfgRXFGADgU78vvTMfvST5Cf
1Bo/gt05pdUWkh8F1FXvFwPYU8NSd75mxAA9BM13YT9LDigbJsdBuv/W3lbs
BK3iDPa4eMilH9VtwE5MZVWTi0iE9dwWfIEEesylwuEVmAKCCsMJudhvfQci
/iv/AiqnTMVTsWvo2pYtS1NBKft+XDh2xA2nlqf56cBneJD8Gvv9jZt6O3Iy
gJGkKu+HXbmWfS8xIxOYi0L/c6KtF+NYSy05G05MDwxZYUsHEysmCTmwMhfk
YYztN3KygBKbC4NKUnJq2AcFdvOwRuTDv/d1ahmxvfLUQ9QDv8KzP62rixsE
cszTjrPSLobvW+uShrHb6/y+kcuLwa10JawMW+CygrxiaQkMEmcj7mKfqr9R
p5v/DVr0D49fxw7Ml1p5pVgGvZqe2XrYe6kyLc3ZZZD/1rhrH/b5DydDjTPK
gcQje7Z+nUAVNTNC18gVsFPSPSMb++rAWFjswUpwJEt/+Ii9VbQ8fyS+EtSN
JpZvYVsmOXVax1aBDel9+2bs7qUJk+sfa2DN4CwSWiNQivXePN2AeqjT55dd
+U2g3fSmFdzsDTBy1jOoFXtSTXr03vkGuFoo+eEldpngmxOXOhpg0e5A8+oq
gc7kcJnTUxqh3P9gY+YKgej0O4a0OZoh11493A97C8M28ZQLzSDlsLn9Crb0
4WMs/G+bwXPuecgW7MDhD+kDIi2gEfBdQXeZQD3sJ1xvy7SCxcFQtqJFAt1K
PvvpxcWfMBtZnuGLreZjfm8q9CeMLCdU62OLsPWOn+n5CedYo2FsgUCKgdK3
tlm1w8UJmzOs2C/ZNi08udMBD+Ql6eTm8P5tD/pj8a4Lyg7sKBCYJtB+HfNc
Y4c+4GT4Xd8yhfeHAL07etUHziRHyyDszwq+q2Jf+iBAdy8HO3aUo6H05HQf
pC9V265SCHRlhcnhrn0/8HeMqReOE6jV1bD0id0A7Hvm5fBriEDcnBbI5uYg
8C+cDw3A7r2bUan5fBC0P/SoA/Z+PZY/IkmD8KJWSjB0kEDF7cVOrRODYMdd
X6P1i0Dq4V72KrZDcF9I0dCvj0DT7Vxqv28Mg6SSDUdaB16PIsUmGatRyF49
q6qHLTNpamnxeBTOVLLPzbYTKN7SOSQoZhSizgtMHcK+XRzaT/01Cmje70Bs
G4GMfVKXk8zGgPWIWpF7M4HuRjlXbTMaB56nKcY1P3C87Qn68kiXAmkdj06Y
YGe4/fM23pYCP6au5VNqCaTwWJLnhx8FPNlOyrJhpxOzX7mrKKBr3GirWU2g
wxxMY281J4FD2oT+03cCyR1e4XylOgX1lJLqtSICSTpcVOIRnIGW4D8lTtiW
vgK7pvfNwJDh+v7xQhwPXJNF1YozcP6Xum5LAYE2744keRvPwFqAUkd0Ho4/
34Fr4+EzID3ITNqfRaBfxTKNyXtmQR5tNfieRCChPyxM6zJUsAuUENd/i/e3
//qFcN15cHESn0oLIZA9pXeLtsk86G2dV+TCPpWebzVtOw95OrymtcE4n527
oQTP5kGTNaVROYhAi5R+3s6qeVDOe+DK6E+g8EoX603aC9BbV1Ss/IBAulVN
nbxqi2BnYT515CaBLgYIPpKUW4blYw+epMgS6N/TZitk6zXYY9ihZT9HQnW+
X5OrER2yO32bqyiFhDK5xVam9jCge8x05DlTErIK6zFlPLQZjS9L8tWykNBp
d3FFPU5GpN0R+YDry040GrAR0TbAhJIaSFlZWjvRaZPFiIBWFnRYlMRL1y2M
JgR2RetHsqJ/zHa3OZkLo1Be4gTHC3Yk8Ur1h8KAEJI2m6UGXOdAOhfljidb
CKHrm8z+kXzOiXaHll5Z/28HWr9xqGPMkQtpPryoza+5A9Edi6lp0uRGKJk6
uzl6O3oWrtOttYcHKbf4N8ZvCCLTLTM5Gr950PEpxXvCVwRRr5qxbX8hL/L7
VMZkEi+ApBoqlA4940Niwo+u3l/lR9XyHIV6mvzozMR61kMdfiRjI1R4a5Ef
LfWXCnk94EM1Q2I/DL8IoF1ih5JUy3kR+aHUzxYDQcSm4d2vO8uDojNrg8IZ
t6P8L1uco4R4UO05/wdyidvR0qVS/YCz3Egtxm7PadUdiD2DoU3zFhd6Qxls
i2vdgSpO61x4GcyJOEQURuiuCCFZzRYeRQ8OdI4a47KzSwjdq1wLl41gR5M1
fCaupsLI7oFUY1AXK3I8aT+7VieM3jA7dF6cYEHCZRxPCfWdyNHTt+AsLzNy
Fs+R547diXadHDdPRoyIE2XG9tKRUAif4DFb2Iz4ZB/zKBqT0Pwib9lRYwZk
r1yW0BBHQiKMj0xu6tAhh9DYbl0qCdl+ziyxdluDw8Vmj/JlcJxWHizT+bgM
Z8ZNWBisCEQfPkZ57L8MI5PmW5qxDdPzYr55LsPXdQ3HGGsC2ShVVh4zWYY4
I/9wLRsCybtQusS3L8OV43XI5xaB9MdVvEYDl+D9Ru3nHicCKSc8rxZ6vAis
Xh8mD3rhOC04evgCjoM7PnG+AjguLj1tNgk2nocc6jJfHnZfe4BC26l54JGo
EjPBcTUpb71xWWIehimdVeGhBBJVN642npyD0OyH0qT3OC7nt4eds5+DKqM8
5y2fCMR/QK6ezokKi3ebcl0SCGQ0JnZZ0YIKym4aAcyJOE9Ws4T9e4EKB/1H
xsOwZ7MS1PplqWA9midWhON6d4nYocL5WbinbpC2kUygC5ntuVaus+DB7yxr
nU6g0wLemr5uM/CPEFdRVz7ua+pIhcw2M+B9japhivPIWSeuxSdGM5BlF6/X
jZ13YiDp0bEZeCkcwNCF806UgcGNtdVpiO3hymj6SiC3o5dLKhimYc8XeZOk
bwRqaBMJZOSeBCs+owyGGpyXqvgLFqkUYGe14HbGbjz0+PZwEwV6RJmXBrEH
yhKjy4IpkL9ZRL8c50nNI6xD7tspMNdgYOpVR6BtX8eutYpMwNrM7YTeRgJR
jCixqofGIPSSidjxnwRaav1P15N9DOIytaLJ2AfP7/bJnxgFLSpXsADO63YC
xh/kP4+C9pvjVWPYsYq1sXt3jUIQb5/7k04ClYe5+C1wj4D0Axvmzz0EOv7k
eb7GIq474+Q0T1x3rCJjnV2bcV1SOHmqFXv2j2hDXNogTBa90pfCdUoZfXZg
sR+EqZP8uV3YgmYu1pUjv0Ah62eVzAiBChKFco60D0Be7yRz2RiBAmYz/jTm
94Fim8vcXVw3n58oCFd+3wdbdyqOFWA7r3xbi/Xog05LJvMNbL6a0qW7Kn0Q
9ru46z6uy4V7GafgXi8o5Txf9JghEJvov+yFD7vh0okvef9Q8fWw2X300+yG
im8pfaHYN9/2FhkwdoOqaKJvE7ZZ43r8zJMuiGAJtNTEdd+hSlZ357NOGFZl
VhWdx+c7O/fWPKAdDIc77lXgPiGr5oDrfr12eMwm27yC3f1Wd2aaux0W+t2S
DuI+40SlxFf31z/h5KuGoRfYZhr2A/4hbdC984W77hKB9qXdF4j+0ALLRpEy
abiPYTYwPHrtSgs0H/HP6sJOuRe4SZxogUBn00JG3PdE6LHExEY0Q/2LqAuX
sYkjPHujo5pgOaEgchn7wg5JuoD4RjiZ8b6awH1XipjXjQ3LRthattlME1ue
s9PHVqQRrv2wNLfBjnkTXK0Rgvsy8a3Jadgsm2U+jbDUw39/2syUcZ/Hffl0
bqFXHUg0T5qaYi8MS2gGLf2A4bDFCk9s+R08pcpDtcCY3DNQgL3vqkuwb3E1
fNdYkZXDfePbycRXxkerwXbuzdtz2K+rjXkkk6tAQV7U5ib2ggRDbt27SjBy
36IfiS3CdK2a7fZ32Ef+pc6E+1hZj6tanZPlMB80uo3AZh58bhpvWQ45l39q
y2Prep+y0tArg6J2VzoL7Cmma5KukqXQHh39PBO7Wqi1Qi26BJZvLHytxL6v
IMHFLlQCE/RSZp3YGxnmeZHMxWB/6eLIBjbH5auqHRtFEG9/vI4D9+3kHE83
O0ohsPEJ7hbB1tGcMgiuyIfUDidOwD6etXPLvsw8KLq5mnAa+wXx8GheZC68
sLueRpsLhtyToNszGwRKJ5lcsYPKdAg72ywoCWO+5EObQ740h2wYZsLWWSYu
f2xOWRsrklw6WKil/4jC7pc8V0nelQaP2q7Uk7GLXne0KHOkgrXolEo29ptj
U/tDVlIgZcVsezH2Lvq9fBnNZIiSzr5aif1zQul2Q0oiSMXM8NPmpnH7LUYU
v3joP8yu2IZdv8m8gul6HMyms1V2Y5NEJKp2q8XAUc7pb7+wDQBuqAhHweED
GRJj2CXdrqkGSxGwMWrMMIVtQTUx+BX9AazkhzWo2M27HnzjNw6Flg29+QXs
0pMC+TpcwWAoHclJmyOPOjSc96h4BZ++NoX+xp6UrJE3/f0UWMJHXtLmUH0/
IYMSKy949q2buoGt4CZ+Ybe4F8Am+d80lzahcMaq+0AOv7mJNseOzZS98Cu9
B5mjzjw0h5mctg3M9ADHqllpmuljzc31ZTxgdlhZkeZiPaPL/CnusM/sOqJZ
soeqFfb5LpRe0z9DM+d8m0jkuzvwqfC9Nc1PDnEIWAregZGcDjuaRUmS7OLB
t2GYY8mZ5gxhYiXe3xU4Gqu9/h7fOl6f6u0MzBE9b2j28Lle7rThBHxuHO9p
vi79I++IuxN0kEmfaF79aBqT6+wILw78TPh7/FKoW4mVA7x3yC6guURspYux
yh5u7e0sppmd7sN3v1I7WFLsLqN5LethaGDmTZB19Kj9+/151T78KbYwHLK9
gWaL9DnbsM82oLc9uInm7tdUlch31qB3aG/H3/djqsXFg61g5JtKN81Mv305
Evyvg1yGTN/f+wSPSvtSvS1hKS57iOYjVJWqI+4WYJeoPUpzx6/o1Fxnc3i/
NWuc5vxgRZ8SKzMQ7ZKc/muhpma/0itw98zRWZpvB3PHBGaagJ8wMUdzAJ2c
S9hnI9DTGpqnecZSUTPynSE01fgu0ny3Wowvwf8SsJHZlmkWDF0eTPXWh/Wx
Wys0p/zMysh11oM4H/IqzXsDrj4ssToHzLdrftNcz7sYF5ipC7srKtZoJguy
ake+OwELjpHrNGerMA6nemvA/bvGG39/b9AE/jyCUtr2w24U3faoxOow/Ev7
O2jrY8IrKx5bovy/+yz/B0ijbtM=
       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHDVSYakY57ZLoW4RUoR34VISokKxb2IJheRIZSha0hJSSTk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       "]], LineBox[CompressedData["
1:eJw12HlYTO37APBCaaOFtGqZQ+qtLOlto+4HoUTy8hbRinaSeIukaCGiVZRo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       "]], LineBox[CompressedData["
1:eJw12Hc8lf/7B3C7kmSUEdl34tMy0kfF9dagJGVUyEoRkRmlbBnZZZSQLUKl
bDKzskdIZoqsjCN7/N735/f4nn/OeT7O4zzu+33u+/26rusWNLJSN6ahoqLi
pKaiIt///7UP/e8T1y/xr5ubBFrjecFWnW0PDOHpmqRHHK78rsr2ghJWD5cN
bOF6C9kwpRDw1H+rvo796KcyVGWHwy/XI62r2H25iTN/BaOg5NHWlWXsh8vi
vKFKcXBSW6ZxEduLiKP6ZyMBOgUKlf9ipxUIRFVkJ4Nab6jtHDY/K++Qtnkq
lEdUnpnGvutLXTsjmA7euufLJ7B9nNFZn+5MUDtB/B7Fptov8jpI6T3wnLpW
MIwdfuSMxbeELDjsPiA9gL2PMX9SeOMD9E/P4QUSiGnNkTE/OwdCFF2Sm7El
nI/FULPkQaGw4Zc6bM540U5l83xYahRl/4R9MsuF6BUsgqCGHcdysWVYr0iI
OBdDUrYy/Tvs0NWTTebdnyDlQ11cLLaDNEu7k1IZeNAxWT7HfpZ7doL/bxkU
5SX/CsI+7GpXXpFQDs61A+1O2H+sRGO2bFTAKx/bDE3sfwfXawKzq+B9s13D
eWy9OBrvQ0bVYPq6MUIe+05v/2TTzhr4mOMvLort9jDwDbN5LUwZy6jObxBo
i3Nr1BPBelA/Tl0+gj2mEHdVtLketgns6+/GXmDal/zZqQGol104i7Evvaie
W+9qBGKvnbcLNnfAUc+jSi1A926XiiV2Yr2bH82rFpAXZSvWw+b05VRrnm+B
HU2CUSewvbwHOEwTWmFMM+oKZZ1Apsd/GESst4FzgEyxOvYS52rpz49fQVWH
X+MEdvAQf9syaydM7zPxEsZOKTztymzdCVK2O4vn1gjEbNSUKHOgC84f6LMJ
wDbX6x5xT+oG0bnGzYxVvF4ppl6a8O/QnNGoEoxdc0qjg4XyHQR2SB21wT5t
lKXCp9YLJqNHuqWwt+1dzj22ow8GPLfezl4hECt74qlbXv3QcTEtNWGZQBM1
I/qthYPAMKiU4YIdWDC80D42CPz+Vy7oYF/VclTo5BqCmpqy6yzYPrvYJr45
DMEX97Gq+0sESuCyfdAn+QMe7uYvk1okUGxyTmnHm2G4va6mZjhPoBcio3wu
L0fA/OnahiS2iptgmlb1CMzcY75Cjz2a6dQtOTcCSXTmK6kUAsXFfBMeOT8K
F/x4xCfnCDS0wKhzbnkUpquo+IxmCWSSKJu+cm0MMgy09Jj+4Osl48vFtnsS
XLVMuTumCETZv0QZQJMgyLTsHIW91JKhn2kxCfEH4pAYtuk/YgOKnychQ5cv
A00SKOrbZcd7dlMweuo1r8E43o/+DxwLWv/A5pbIOzojBGr8cGx2rnoG9Nc6
/biw2UKprtzqnYFcR+5rnb8IJE0v8ODr7AwIbH1PuYytns29mss7C5M+IHfq
J/4/tq2MO9jOwoOOBrbdPwh064ib+PjeOQjM3Nr8qA/njZjxWNQ9Cugw9Noc
xs5ILH9B50eBg7s6y370EkhR5fC6RSwFIn6funkOu77q7/DJLxT4/Ie/cOd3
Atn0SAt845+HwhvT74O6CSSilr6dtn4emtSN6y+2E0j+4VHrPYILQJNnED7d
RqBxXbfGc/8uwN6D/Wsh2BGLXtUOlxbg3NrdpLZWAlX/4fNrdV4AvTNbr6q1
EGjdiVPFo2cBfvCmnDnZiPdnXbJBS+giEExd12urCVRVkjnGw7AMGUnyPQX5
BLJKdPqoPbYKhlaFtBewuX+xpw5trAJXTVfX9zx8/3AkHDLbtQbv59Zd13IJ
pNR8ecYB1qD02v4W2RwCtSXnngwMX4NtIQ9tkrII9I0S/y5JYR1kD3l+ln1D
oFrp02+dIjdAN2mY3fglXs+w24WBRCp0XFY809cOr/eobdSiDy2K5M1101XC
+ayn9J5DmwGdpKfJaOMiUEHk04j981tRF/2M9/NBEaS6i608tWw7EowKVi1O
EUF+Y2HMNleZEeuCKyOTmQi6TPdOft6cBTkcPhoTIyCC7A3S+B5XsiKJ/I4d
M13CyLas88jLTTakkDCa+M5TGInph7uvXN6F+Gh5dvj8I4yE5uivPY7YjRJW
pJp8OoRQBp3IzZIyDqRUR0gw2wihYgnqAOoNTjT9hVHNdacQEpCg/ZdWgBs1
dF01qYwTRJuyZ60VNPagSEm2sl2HBZHhFmUXF0ce1NReE/GxTACFPoyh7Pbi
RTsPXztrdUYAQUnbjGHsXvSBgXOf1Qt+dHVivlItlg/5C8c84kjmQ/Qf6H92
PuNH2Qv/7GsJ24vW9LbtkDsvgDJbyw7IBPOiY6uxdDeLBVDIJ9bcOnMeNFQc
TR8oLYio231KqRT3oIAumz3ZyYIo7Jh/x+2D3CiGtXjbV0Yh9CwvcQta4ESv
je7eCrUTQnNfHrMlN3IgxoiFV3EtQig0NkHudvJu9JzjB9IUFUZddRedhfV3
Iak1VQMFN2Gku9IcmyzKjg55rv262CSMRun7GOpbWVF7p1+m/V4RJO/9qnUh
kAVZv3zldcBIBE0RNLXTL5jR9ujoisg4EfR+r4KNVNd2xHfaQi6vXwSFtEdn
WshtQwFjJvYG7ASy+C2zOX+LATk/MeoOUyTQl+ED9A9CaZHg4w8Tg7YEKuXu
z/WYokIcQ1YmrREEio8erFgbokLBtNmVN57j3Lo+4+7QSYXsLINLZrHFUrft
MSulQhr91IEskbjuhvzIU35KhdSaAgPORxFoz1Px7k1pKrR9mmlXWizOjTvu
MiZLG7D1nK4UXyq+jxNUjJ6xr8EHscRDg3hfOJxIMphaX4X+fTzTl/C+CfOv
nVL6vQoXVZW1S7G9LzR/Wi3G30vWiMcUEGjmoZyMvskqyMpvr9AsIlD+++F2
5oIVuMOHyj6WEKi/YJRXUH8Zntwqnz5SRaDesmc9lueWQZt9YDgcm+LQKFUs
uQwlEq7uK9j+RcqFV7YsQ60rKqjA+zr4SZvA4/dLkLcetedSLc41bf/YJpol
sG82SLxWTyBGt6elvK8XoLUivUIU58b4dUa6hqcLUJdswu+GHbhxbe6hE84Z
p4793dhUInmNXWoLkFBZqeCDcwcxWfgGrv0FtvMN/kM4p4SvTmmOqf0F7khj
V+9OAhmEOTy+tUaBvD/r35/inJN6cyl+2ygFIjmTGgawB9EB27etFEh78dXs
IM7F65wyEospFFCg7UyrwY7Nvn/QS40Crw0OoCWcqzofWUxCU+Yg016y6vwg
gTxcKtgeXZ6FJ48297/FOf2F0iKiKDsLw9EzhovYTc/vj7EIzULIVScZhHOd
N+5QQDJlBtTu6xe2YCfczjhVHzEDBLM4MYXrQnP2jVeshdMgebzOi30M57rs
kPurtklQeNp1hwPXHVV+40GhpEnIYqjU0MCecJUoSbGfhNOewj3B2OpaoysZ
XJPwWANKt+C6JngrPvij/gQorn8en8MWYtrXlzY+Bi1PhKtzZwgk2vCiFNGM
wiLtDZ95XDfLhk/ptHeOwOLpa4OCuK5S3Q+MMk4fgWu7jYdVseW60nc90RyB
lYzPo6+x1U8kUepTfkFqidvYlb8E4qqVW1a48BOKJLRb4hdwX5EadbGZ/ydE
dj74Uof9JV9WQ3d+GE6kJlvOYs+59t+zjxmGVyYiOYDrvvPLmyJJ0z9APj35
eDe2lqJoHSV0CHRdZESXcZ+ww0LO3cl0CKK5hst5cB/BlSb9l05uCLTqQxnk
sT/UWbLvHhkEqZubge7YNK4ZJyT/HQRfutkwOty3LIZdiivP7wO/V80eK9jp
97kP1N/oA5oq90+cuM+RsBw708HYByLoSII0dnTrpNAv3V5wsXEzu4u93aww
h5r6O/jlDE33YEvSyRuKnu8GStGF78m4z7KRZGntG++CGkXaD6XYyjJT7aEB
XXD0YrLwN2zhd4ERG82dULeS0sWI+7Zqozb55qtfYdA1zMMM++RBYyuPpQ7o
dw894oZd2x8ER192gIufo2MENr3Q3arIvnZI4lz+Xo7d8KEsQv9WG5wzKBpm
x32klpQDhZmhDXRqRk1FsRV5Lq2XvG4FxaNLvsexf7tI8PNNtEDT58pIA+yG
MeWIrOEmYPJZW0/Crmasdtsh2gT5v0AnB9u/IH7Q9E4jvP10S60Ku7Z1CzPf
bD3um9VYfmKPjt9x8diohSsSWS28ZF9vUm3bo1ALPflLtOLY7xqjFyW8akA9
nr9Nhpxr8pXKBrZXg0U6I1zCPj71g1HmUhV81m3q08FetPSm+D/7DA+CrDlN
sBOa7TJkuCtBJ+XS9UfYqncfe/rrVkCleICxF3bWV3GGwdhyoLZIYQzGPhhe
zeO7rwys7e2IeGxlS3rzvPYSMB4notKwe20/s+jrfII8+5z0LPJ8GSSb0m4X
wvxJ85gy7N1gSVH9kw//SD91qSHnrACmFMq9PNDKD11pJM+vtn3y+WoOpKbb
snZg17T4NZ3wyAaBuYOV37BFPJbUBrZ+hBCbqp3k3DRbPOzsEZwFUayyi+Rc
9cqIXZvgeA+5Rb6Ov7HFMqI7gmUzYd/17IhJbK7FXOsOxTdA3VekOoM9Zk0b
xqX5Gg4fiY2nYCeN7FTRvZEEt8/qBy9gnxK9kxJrGQ+SO5c5yTmxngHdqFqM
hkl3qxPkHKny0mVGme05lIaWL6+Rc9a79N0tB55CyslpdXIOle6v6koL8gZr
hyVFck7NHNGUtJL2hhNCOSqkw582BEj3eAFnpo466Tjj+wqlhBesGRjqkX5z
uCqto9gTXI5ftSUt2JZI+9LIE6r7te+T/sllqWew1RN4jRSdSJcuVbOMa3jA
X/oeL9L198McNsfdwKBi4vl/x7fuaf4c4gb8BjLRpPPpdor5ybjBnx6zONIP
avxyxehcodDKP5X0ysgPZ01JJ2BgLsgjfYdicXjA+RHIJyoXkZ4U7hk0q3sI
3pxVJaSXigxPuxo6gkLMvSrSytlSW94EOYD53pJW0mfPT+RJ99gDT3pEB+lt
M/6mpYQ99HBqdZFulPOv6yi2A8+g8F7ScoYTjgZb7cDyBesAaU3/Y+LjGrZg
6u4wRFqrOsJvc9wafGdWfpHOVks/7idjDe8c9vwmLV6g91WMzgp+fhcaJx1w
f3u4pqQFPDz9Z+q/4x/MmTeruwO9Z7OmSasUnNJ0NTSDC6J6s6SHDu5kfxNk
Alo+VvOkWYXVbEsJY5in7/xLuqLaqbWj+CbE3iQWSd8qCz0yrmEEWnF6S6SN
7Z8Hb44bgmCxyzJp0wi2PjE6A1jK9V0h7d729aWmpC70hzxaJT1r9kjL1VAb
2s9fWyMdIcrA8SboKnQO8ayTVj3k2N5RrAGjWnX/eTGuK2Rz/DJsfWewQbo3
7Fy0pqQKHPvZ/58FJyrx7xXBnrz9sMGGgi0DfOTlwPbbOOF970ztyf89Z/k/
gt6LUg==
       "]]}}, {{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.832885283134289`, 1.9101299543362336`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.336618828644992`, 3.762221576582356}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {9.526279441628825, 5.5}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {8.42648887430876, 7.070663706551931}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {7.070663706551931, 8.42648887430876}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {5.5, 9.526279441628825}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {3.762221576582356, 10.336618828644992`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {1.9101299543362336`, 10.832885283134289`}}]}}}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox["\"Array Gain for drive [-1,1,-1,1]\"", TraditionalForm],
  
  PlotRange->{{0, 11}, {0, 11}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.4147498656420393`*^9, 3.4147543971919537`*^9, 3.414754433172372*^9, {
   3.414758674895446*^9, 3.414758680148198*^9}, 3.4147593597431507`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"drive", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"high", " ", "=", " ", 
   RowBox[{"PolarPlot", "[", 
    RowBox[{
     RowBox[{"ArrayGain", "[", 
      RowBox[{"drive", ",", "height", ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "maxGain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
        RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Array Gain for drive [1,-1,-1,1]\>\""}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"high", ",", "grid"}], "]"}]}], "Input",
 CellChangeTimes->{{3.41474668457058*^9, 3.414746777265751*^9}, {
  3.4147469053450403`*^9, 3.414746922105953*^9}, {3.4147469894986362`*^9, 
  3.414746993168701*^9}, {3.414747050886303*^9, 3.41474706589158*^9}, {
  3.4147471546560783`*^9, 3.4147471595428*^9}, {3.414747204281204*^9, 
  3.414747234472851*^9}, {3.414747269739746*^9, 3.414747311131422*^9}, {
  3.414747685657402*^9, 3.414747686847406*^9}, {3.414748362509151*^9, 
  3.414748424965287*^9}, {3.414748494209344*^9, 3.414748556929154*^9}, {
  3.414748654622649*^9, 3.414748717422875*^9}, {3.414748764785789*^9, 
  3.414748765135943*^9}, {3.414748796898699*^9, 3.414748798321002*^9}, {
  3.4147488770687103`*^9, 3.4147488993898697`*^9}, {3.414748942727558*^9, 
  3.414748945605701*^9}, {3.414749260250078*^9, 3.4147492638159313`*^9}, {
  3.414749310563262*^9, 3.4147493534354143`*^9}, {3.414749532205264*^9, 
  3.414749536508419*^9}, {3.414749577779962*^9, 3.4147495785222273`*^9}, {
  3.41474961160553*^9, 3.4147497316875677`*^9}, {3.414749899286767*^9, 
  3.414749904845182*^9}, {3.414758692437551*^9, 3.414758709316257*^9}, {
  3.4147593681165037`*^9, 3.4147593927800283`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0, 1, 0], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwUl3c8le8bx23H3nudc4xkbxKe2y4NI9EQskdpkDRQQomQaGgoEZKR8SWj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      "]]}}, {{{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], LineBox[CompressedData["
1:eJw12Hk4VP37B3BtluKxhXr0oEgblSUheSNrKSVFlpIlovBk6ZGUpY2ikCxJ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       "]], LineBox[CompressedData["
1:eJw12Hc8lf3/B3Ato7iFULdCkRbKSEheyEgphSKjZEQU7oxuSSmNm6KQjErI
zix7hZSZkb1SKrL35ly/z+nx+55/znk+zvW4rnN9zue9rq1m9jqWKxkYGDhW
MDDQ3///pfS/D0HFb4spioIdh9C/T/21cYKpipFu944E+af+57HccKR2mTj2
+67ukSQrmImK8i0R32WsVA3wtwc/r/PAPDF3T37Q8zxHZL8QOjRLLHJHUWk4
6Rpelh3gmiK+0fbwkWK4GwSj0i6PEd/uVr/y2P8WXJT8NIeIIz/9129fcht5
ic3xfcQdI+otQXmemFi47dNDPNIr/u/79HtYgYCpTuKHyX6lvUkP8M53bXcz
cYJ6UTpbrBdyVvzWqiN+k7ZOWTr8IZZzmug3iPsch9g9/B9jo2xvQg5xsFdP
+JePT3DomIlIGnEVQ8ucRYkf5LNuxYYRh19ybPovLwDcBnuSnhK/uHRZ5+/s
p2DkV5TxJi5fyrr5Jj0QzIUhXxzp68XY31SdFIQjoz2/rIglAgXmjROCMT8Z
cMOI2LvvaP5QTAh+yotLKxPv4d3GtS78Of65pVlNFhweuSpBKv6v8JBqXpih
UbiaqxFrpRGOT2trEnuJ22q8PyR9DIdryXxoKTHvWVkZuZII/BTQDr9OfKz2
Uo1W3ms06e0buEjsnyc+/0QuCt1q7lk6xDsmJJsas6KQF2zUuZP41MujIUbp
0eDnktImfzDKqsb4LJNisUXMLT2L+EJPf2jMnjhcTZJ4+Yp4rdDHvL74OKgY
Ds5dIbZIdOywjomHDf+LttXEXbODxhdfvcGSvrYS2SBIsd6Rq+WXgho9Hqn5
RQrbVpiUcbKlok/bPaCZeFhZ4vfNU6m4UCD28jFx6cZnR860p2LGbnfjwgKF
E9kcZiuG0vDRd099xjwFBr32Xxrs6cixVwnzJl6z8i+RFN10iDusbjtHLLHv
IAtPcDrcJx8FrSH27335rkcwA6p+n2S15ih8ZTvick0yE+Z7QlgLZyhcSdaO
8DmdjfHIj+lexMp3zG6OhGSjby6hUo9YkLV74MTXbJxcF4X+aQpy/hJX/rLK
welBmxPriB+zrpp+8G8uPGXEGKQnyf5tC6DMn+ejdPff+byjFHZpmuUYORRh
/crF2qYRsj94V7gpPSmCE/9ViwDiOFmvBeHUIvhp7WBnI3591UBieLQI72Yr
bReGKJybZ3K4bl8MnvZ+lYIBCs0uBiUP7Eqw86GHw49fFDjXmyvZXC4Fz/Sp
ED/i7uvp5WqPSqHx8qsKiHfpsFCCiaXwqRbfGPKTQlFbkWPzYCnsOGur1H9Q
UAnzsD9k+xG3+OQMvL9RGG3jUF689Ali8jbsb9vJehTKNUhalSNrQVtRh1hy
2MTC/H45TpSzTY63UYi3cAoKiC7H61O8I3uJrxWFfJ/4UQ6lKe/dMS0UjO6k
zSWaVmDdfuVCt0YK1187VfxlWAmu/1KMqj6TeNsekHpPqxpv2+8dMSZOdz0f
HG9bjc8jlnlD1RRk74txffauhjvrUSlW4ncC4+85K6qhZVRvq1ZJYR87U3+w
2mewSxiviPhEQXrf/PonijWoHSquXCqkIOZwWp5rYx2aAqliR2ILL96tozvr
8MtgeddAAYkHjuHCSrk6nPqhotWUT2H1tkj+20Z1WPKTb4/KJfHn1WM5EFYH
iZ/M/LsyKfwokqxP3l4PGaW1+p8SKfBRLEzLkl9g5y8qohdM9rfvsm6YViOc
HUVG3gZRsB/qXqNh3AidtVNyHMTH3uVZjdo2Ildzg0l1IMlnJy/J42Ej1Nal
1CsEUJgZ+r6ho6IRCrmeLoy+FMLKna1XaTShu6awSMGTglZFQ8cG5WbYmZuN
7L9M4bTfxnti0q2YO+j5IEWKwj/HTeeTrDux3aBd3X6Shhqv98mVSt9gd/wa
R2EKDRmcwvMj23twk5khadKEBqvQryaMe39iYE6Mu5qFhuNuInI663uh0R7p
yZG6jN9+tPCWnj4k1vFnZqov47jxTLhfcz/2CfFvYOhawiDv1ii9yEGcN93W
4mi2hJANAkfYfYYh+kTxs2zPIiRMxyf8Lo5C87T04WTzRVxcZXpe7NEYtoWU
nFv+soDlS3vb+6+OQ+3uaQ0etQUwHIyualCbgFLyxPjqqHk8DNPsUt8+CYUm
3/p42hxM1oxlqy5O4vCI3M3N5+bQrWxk+71gCt4RpUzG8bMQryuT3/twGsKb
7124tTCDShn2Ah21GZwYXM68qzkDSRu+giszM5j9XsLn4TmNql/Cnw1SZ7FV
eG+i4scpJN0Vb23SnwOr6u3vWuOTiMqoDghjnEde6hqn13yTqD7p6yn9Zh6z
Z0r0/LQnoBxtt/244gLY0le2qF0Zx7Ohny2xzQsoO66p+zhwDOyCsn0M5xYh
pdbEJXdjFCcnop23dC7iZvlSmFT4MIaruI1dTJZg5yleH9A5iKtH7ceXapbw
jNmh4/RgPzaXsv8noLKMq+5e+dobfsNJJFuGM2YZW48OmCUr9WK9UkZMNwMN
QdwbD9riJ7il7nPJGdEwNbOh9IBRD+wVShPqYmkQZLxnfFnzGxxCYrq0Jmiw
jcsotnbtxL4i03t5kiROy/eUar5qxYkBY5aVVhRWhPUP3fdtRd+w2ZpGYoN3
udEf3Fvxfln1arQ1BRv58vKDxq2INfQNU7ehIOM81CmyqRXnDtco3blCQW/g
kMdv/xa8oFXHfXWkoJDwqJLvfjPWebwc3uNB4jT/wD5dEgf/3on14iVxcea/
RuNAo0ZkT8xx5xJ/a/OTbTnWCC7RCmFjElfDMta0s6KN6B3qqAgLoSCkYlRp
NNyAkKy7EvwvSFxObQo9ad+ACsNcpzURFHh2S9cyOH7BzPWGHOcECob9wmfl
zL9AwVXVj/kNyZOVLKH/6H7BHt++gVDi8cwE5e9SX2D9O1e4kMT1tmLhvQVT
9bipov+WlkxBN6Mtx8qlHjd4nKSs31E4zntbzcu1Duf5OAo780hfU8NfwGxT
h9uWE6omJI9oO3LMPDCsQ6ZdvE4Xce6RnsR7B+vweLPfyk6Sd17r619aWqhF
zFeO9Ib3FFwPnC0uW1mL7akyxokfKNS1CPozcn6GFbdh+soqkpcqePJnJqrB
ts6c04m4fu/9a70N1fgqxDz7k7in9E1UaWA18lYL6n0keVJt/7pfbpuqMVmn
b+JRQ+Gv9/2WzYJVWBq7ltBdT2HIcChGcW8FQs4YCx9upTDb/EXLna0CsRnq
UUnEe05tu5M3WA71CY5AXpLX7XiNXsrElUPj2eGKfuIYueqYHVvLEbDhm9uD
DgofQ529pznLIOFpwxz3lcLhB4/yVGdI3RlIeutO6o5VZIyTSyOpS7JHjzUT
j1NCdbFvSzFc+ERPnNQpBaU4Bxb7Uowc5cnpJN5o6mxd3vcBspmtFZJ9FPLf
8GXvbytBbvcwc2k/Bb/xdKo+rwhyLc6T10ndfHQkP0zhRRHWbpHrzyd2mv+w
FHOjCB0WTGY0Yu6qktnrh4oQuljUeYvU5YIdjCO4+R7y2Y9mboxRYBX6h63g
bgHOHEnNPT9B7ofV7pW3WgHKPqR8CyG+HNxdqM9YAEWhN14NxKb1y/FjD/IR
zuJvoUbqvkOFlNaWh3noVWRWFJoi59OeDDbzy4FBb/vNMtInZFbtdtmlk4P7
rFKN88RdwVpjo5w5mP7umriH9BlHykXfuz3NxtEndb98iE1V7Xt8g7LQtcXH
TWuWws63t3ijXmZgzjBS8i3pY5j1DQ5YnstA437fzE7ilJv+q0QEMuDvZFLA
SPqecB2W6JjwdNT6vNY9Syywn2tH1Ot3mEvIj5wj1v1bjMEvPg1H019UCpC+
K0XY4xLNIg1rS1ebqhHLrO+4YyuYBsvPFmY2xNHPAitVg0hfJrI2+S0xy2rJ
iD6WFHyhWkwVSJ/HefZ4ToFHMkQbh01MiKd7RdUCZpPQGzpT5k4s8zdXicKv
RDAmf+3JJ955wTnQqygBn1TnpaRJ3xg8/OaJ0YEE2E4+Cz5J/LTSiEssOR6y
MkI2l4mnRVfm1DyPg6HbGr1IYkEmy0rWazHYmfRDhYn0sVI3Lqh3DEdjKuD3
XwLEzD8fmcRbRCP7bKuGDLHW7WNWqjpRKGxzYTAnHmGyFHMRi0RbVNSjDOJK
vuYy5agIzF2afl9OfEtWlIONLwKDK8RNO4hp6Wa5kczhsD9zuo9GzH72gmI7
LQzx9odr2EnfnpTt7mo39BKs3Bu3CRJrqo3oB5Y9R1q743oQH87csmZnRigK
Ly8kHCf2Ebh7IDcyBD52F9/S54Jfbonocg8Cb8kwkwtxQKmmgJ3tMxSHMp+5
Q59DUhuDaAaBWDvOxOFLvF7KxopfOgDmyu8+vyb+LnayPGmrP+61nKtNIi58
2t6kwO4Ha6GRQ1nEzw6O7Aqaf4yUedNNRcRbV+zgTm/0wWuJrAvlxK2D8tfq
Uh5CPHqMhz43DdivMRzy9sL3fWxyLcS1q8zKmC4+wPg71vIuYn5B0Yptyvdw
YP3ohx/E+sClQ5s9sW93umg/cXGXS5r+rAdov41WjhCbTxjr/4hyh5VMr+oE
ceNWzw88Rq5ooulMTROXHOXN0+RwhoFE5Hr6HHnAoe7UjTIHRLxvCFkkHhar
kjFZtAZLWN9j+hyq582nX2xliocfuiZoxLKuIrrbREyBVTKLdJc0KIUxVpxH
UtjlVfQ5tn+s1Me75Bwyfjtx0R1qfNzWP8MYVyvGJeheEWNmpidpjPFeBTm6
i3QMz/KkGGGn6UUlusW+TqiHxhmixFLvBN3rp1oEI58bIKLghTXdD/ay81ps
NEBfdrsd3UL8YmwigfroZZ91ojt9s8B8vO8ZsNdXevw5vnmgNu22HpjDvz6j
+8adix8dabrgdmV/QfdFic+5+9100Z7EH0H3wiuT6BwnHfjsbk34c/xsiGux
1Um8cMjKp7tYeL6TsUIbV3Z0FNHNxvDyk3fJCczKdZXSvZR5N8Q/QwtSV29U
/7l+buUdnpRj6A3aVEe3+btJ29C4o9DZFNhAd9fTiUORz49AZ++O9j/fR1eK
iARqoO/DoS66mRa92BN81SGdLvntz3OCeyXf0m6rYjY26xfd+ycOVex3Owy7
Nxq/6W7/EZWW46SCF2szB+jOC5S7U2ylBKFOsdE/5mto9C5RxPUTB8bpvhbI
Ge2foQDvzQKTdPsxSDuHxslDR/3XFN1jFnJqkc9l0VBFpjbijSFzP9NuS2O5
/8o83Tv8LtwtttoH5mtVi3/OHzBILIiSP9uF/H7jDVIiMREK/3sO8n/mVCcQ

       "]], LineBox[CompressedData["
1:eJw12Hk4lF0bAHAG80xJZclS3rIUbQq9ZEn3qayRijYvSSJSlix5o4WyJ1I+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       "]], LineBox[CompressedData["
1:eJw12Hc4le//AHAjezxGRh+FIi2UkZC8b7LTkiKjZEQIn4w+khKpKArJqCQZ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       "]], 
      LineBox[CompressedData["
1:eJw12Hk4ldv3AHCSeTq8iZCkEpcmuaZi7UpFJN1cSpkzKxm6lKQylCJjinQN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       "]], LineBox[CompressedData["
1:eJw12Hk8VOv/AHApTEl2h3IrFG0KXbKkz6OskYo2t9JGStlJ0YKrLIkW15p9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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHASkmSIY9jmWRlL3VS37yJjXGVoQCmipAF1dU0XJfOYzFOS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       "]], LineBox[CompressedData["
1:eJw12Hc8Vf//AHBURsgeRfco0kIZCeH1JiOlJUVGH6GIwscqodCkUkiiksyM
S/YWIjPjY2WPbNe6ttDvffs9vvefe5+Pe+6597zv+7XOLnN7vWsMdHR0AvR0
dLTn/3+IoP+9CilJK/nzh0B2XKJ3XgfawxmmGkaaPTsTlF4H3of1phP169hx
/ft7p8hPwFxCQmgN+yFjtUZQ4EsgCbiMr2DzDRSEvMsPgpz3oipL2OI+qmiS
HAIfKo7yzGN7tD97rhrxDkSiU2/OYHv3at16GfgRXFGADgU78vvTMfvST5Cf
1Bo/gt05pdUWkh8F1FXvFwPYU8NSd75mxAA9BM13YT9LDigbJsdBuv/W3lbs
BK3iDPa4eMilH9VtwE5MZVWTi0iE9dwWfIEEesylwuEVmAKCCsMJudhvfQci
/iv/AiqnTMVTsWvo2pYtS1NBKft+XDh2xA2nlqf56cBneJD8Gvv9jZt6O3Iy
gJGkKu+HXbmWfS8xIxOYi0L/c6KtF+NYSy05G05MDwxZYUsHEysmCTmwMhfk
YYztN3KygBKbC4NKUnJq2AcFdvOwRuTDv/d1ahmxvfLUQ9QDv8KzP62rixsE
cszTjrPSLobvW+uShrHb6/y+kcuLwa10JawMW+CygrxiaQkMEmcj7mKfqr9R
p5v/DVr0D49fxw7Ml1p5pVgGvZqe2XrYe6kyLc3ZZZD/1rhrH/b5DydDjTPK
gcQje7Z+nUAVNTNC18gVsFPSPSMb++rAWFjswUpwJEt/+Ii9VbQ8fyS+EtSN
JpZvYVsmOXVax1aBDel9+2bs7qUJk+sfa2DN4CwSWiNQivXePN2AeqjT55dd
+U2g3fSmFdzsDTBy1jOoFXtSTXr03vkGuFoo+eEldpngmxOXOhpg0e5A8+oq
gc7kcJnTUxqh3P9gY+YKgej0O4a0OZoh11493A97C8M28ZQLzSDlsLn9Crb0
4WMs/G+bwXPuecgW7MDhD+kDIi2gEfBdQXeZQD3sJ1xvy7SCxcFQtqJFAt1K
PvvpxcWfMBtZnuGLreZjfm8q9CeMLCdU62OLsPWOn+n5CedYo2FsgUCKgdK3
tlm1w8UJmzOs2C/ZNi08udMBD+Ql6eTm8P5tD/pj8a4Lyg7sKBCYJtB+HfNc
Y4c+4GT4Xd8yhfeHAL07etUHziRHyyDszwq+q2Jf+iBAdy8HO3aUo6H05HQf
pC9V265SCHRlhcnhrn0/8HeMqReOE6jV1bD0id0A7Hvm5fBriEDcnBbI5uYg
8C+cDw3A7r2bUan5fBC0P/SoA/Z+PZY/IkmD8KJWSjB0kEDF7cVOrRODYMdd
X6P1i0Dq4V72KrZDcF9I0dCvj0DT7Vxqv28Mg6SSDUdaB16PIsUmGatRyF49
q6qHLTNpamnxeBTOVLLPzbYTKN7SOSQoZhSizgtMHcK+XRzaT/01Cmje70Bs
G4GMfVKXk8zGgPWIWpF7M4HuRjlXbTMaB56nKcY1P3C87Qn68kiXAmkdj06Y
YGe4/fM23pYCP6au5VNqCaTwWJLnhx8FPNlOyrJhpxOzX7mrKKBr3GirWU2g
wxxMY281J4FD2oT+03cCyR1e4XylOgX1lJLqtSICSTpcVOIRnIGW4D8lTtiW
vgK7pvfNwJDh+v7xQhwPXJNF1YozcP6Xum5LAYE2744keRvPwFqAUkd0Ho4/
34Fr4+EzID3ITNqfRaBfxTKNyXtmQR5tNfieRCChPyxM6zJUsAuUENd/i/e3
//qFcN15cHESn0oLIZA9pXeLtsk86G2dV+TCPpWebzVtOw95OrymtcE4n527
oQTP5kGTNaVROYhAi5R+3s6qeVDOe+DK6E+g8EoX603aC9BbV1Ss/IBAulVN
nbxqi2BnYT515CaBLgYIPpKUW4blYw+epMgS6N/TZitk6zXYY9ihZT9HQnW+
X5OrER2yO32bqyiFhDK5xVam9jCge8x05DlTErIK6zFlPLQZjS9L8tWykNBp
d3FFPU5GpN0R+YDry040GrAR0TbAhJIaSFlZWjvRaZPFiIBWFnRYlMRL1y2M
JgR2RetHsqJ/zHa3OZkLo1Be4gTHC3Yk8Ur1h8KAEJI2m6UGXOdAOhfljidb
CKHrm8z+kXzOiXaHll5Z/28HWr9xqGPMkQtpPryoza+5A9Edi6lp0uRGKJk6
uzl6O3oWrtOttYcHKbf4N8ZvCCLTLTM5Gr950PEpxXvCVwRRr5qxbX8hL/L7
VMZkEi+ApBoqlA4940Niwo+u3l/lR9XyHIV6mvzozMR61kMdfiRjI1R4a5Ef
LfWXCnk94EM1Q2I/DL8IoF1ih5JUy3kR+aHUzxYDQcSm4d2vO8uDojNrg8IZ
t6P8L1uco4R4UO05/wdyidvR0qVS/YCz3Egtxm7PadUdiD2DoU3zFhd6Qxls
i2vdgSpO61x4GcyJOEQURuiuCCFZzRYeRQ8OdI4a47KzSwjdq1wLl41gR5M1
fCaupsLI7oFUY1AXK3I8aT+7VieM3jA7dF6cYEHCZRxPCfWdyNHTt+AsLzNy
Fs+R547diXadHDdPRoyIE2XG9tKRUAif4DFb2Iz4ZB/zKBqT0Pwib9lRYwZk
r1yW0BBHQiKMj0xu6tAhh9DYbl0qCdl+ziyxdluDw8Vmj/JlcJxWHizT+bgM
Z8ZNWBisCEQfPkZ57L8MI5PmW5qxDdPzYr55LsPXdQ3HGGsC2ShVVh4zWYY4
I/9wLRsCybtQusS3L8OV43XI5xaB9MdVvEYDl+D9Ru3nHicCKSc8rxZ6vAis
Xh8mD3rhOC04evgCjoM7PnG+AjguLj1tNgk2nocc6jJfHnZfe4BC26l54JGo
EjPBcTUpb71xWWIehimdVeGhBBJVN642npyD0OyH0qT3OC7nt4eds5+DKqM8
5y2fCMR/QK6ezokKi3ebcl0SCGQ0JnZZ0YIKym4aAcyJOE9Ws4T9e4EKB/1H
xsOwZ7MS1PplqWA9midWhON6d4nYocL5WbinbpC2kUygC5ntuVaus+DB7yxr
nU6g0wLemr5uM/CPEFdRVz7ua+pIhcw2M+B9japhivPIWSeuxSdGM5BlF6/X
jZ13YiDp0bEZeCkcwNCF806UgcGNtdVpiO3hymj6SiC3o5dLKhimYc8XeZOk
bwRqaBMJZOSeBCs+owyGGpyXqvgLFqkUYGe14HbGbjz0+PZwEwV6RJmXBrEH
yhKjy4IpkL9ZRL8c50nNI6xD7tspMNdgYOpVR6BtX8eutYpMwNrM7YTeRgJR
jCixqofGIPSSidjxnwRaav1P15N9DOIytaLJ2AfP7/bJnxgFLSpXsADO63YC
xh/kP4+C9pvjVWPYsYq1sXt3jUIQb5/7k04ClYe5+C1wj4D0Axvmzz0EOv7k
eb7GIq474+Q0T1x3rCJjnV2bcV1SOHmqFXv2j2hDXNogTBa90pfCdUoZfXZg
sR+EqZP8uV3YgmYu1pUjv0Ah62eVzAiBChKFco60D0Be7yRz2RiBAmYz/jTm
94Fim8vcXVw3n58oCFd+3wdbdyqOFWA7r3xbi/Xog05LJvMNbL6a0qW7Kn0Q
9ru46z6uy4V7GafgXi8o5Txf9JghEJvov+yFD7vh0okvef9Q8fWw2X300+yG
im8pfaHYN9/2FhkwdoOqaKJvE7ZZ43r8zJMuiGAJtNTEdd+hSlZ357NOGFZl
VhWdx+c7O/fWPKAdDIc77lXgPiGr5oDrfr12eMwm27yC3f1Wd2aaux0W+t2S
DuI+40SlxFf31z/h5KuGoRfYZhr2A/4hbdC984W77hKB9qXdF4j+0ALLRpEy
abiPYTYwPHrtSgs0H/HP6sJOuRe4SZxogUBn00JG3PdE6LHExEY0Q/2LqAuX
sYkjPHujo5pgOaEgchn7wg5JuoD4RjiZ8b6awH1XipjXjQ3LRthattlME1ue
s9PHVqQRrv2wNLfBjnkTXK0Rgvsy8a3Jadgsm2U+jbDUw39/2syUcZ/Hffl0
bqFXHUg0T5qaYi8MS2gGLf2A4bDFCk9s+R08pcpDtcCY3DNQgL3vqkuwb3E1
fNdYkZXDfePbycRXxkerwXbuzdtz2K+rjXkkk6tAQV7U5ib2ggRDbt27SjBy
36IfiS3CdK2a7fZ32Ef+pc6E+1hZj6tanZPlMB80uo3AZh58bhpvWQ45l39q
y2Prep+y0tArg6J2VzoL7Cmma5KukqXQHh39PBO7Wqi1Qi26BJZvLHytxL6v
IMHFLlQCE/RSZp3YGxnmeZHMxWB/6eLIBjbH5auqHRtFEG9/vI4D9+3kHE83
O0ohsPEJ7hbB1tGcMgiuyIfUDidOwD6etXPLvsw8KLq5mnAa+wXx8GheZC68
sLueRpsLhtyToNszGwRKJ5lcsYPKdAg72ywoCWO+5EObQ740h2wYZsLWWSYu
f2xOWRsrklw6WKil/4jC7pc8V0nelQaP2q7Uk7GLXne0KHOkgrXolEo29ptj
U/tDVlIgZcVsezH2Lvq9fBnNZIiSzr5aif1zQul2Q0oiSMXM8NPmpnH7LUYU
v3joP8yu2IZdv8m8gul6HMyms1V2Y5NEJKp2q8XAUc7pb7+wDQBuqAhHweED
GRJj2CXdrqkGSxGwMWrMMIVtQTUx+BX9AazkhzWo2M27HnzjNw6Flg29+QXs
0pMC+TpcwWAoHclJmyOPOjSc96h4BZ++NoX+xp6UrJE3/f0UWMJHXtLmUH0/
IYMSKy949q2buoGt4CZ+Ybe4F8Am+d80lzahcMaq+0AOv7mJNseOzZS98Cu9
B5mjzjw0h5mctg3M9ADHqllpmuljzc31ZTxgdlhZkeZiPaPL/CnusM/sOqJZ
soeqFfb5LpRe0z9DM+d8m0jkuzvwqfC9Nc1PDnEIWAregZGcDjuaRUmS7OLB
t2GYY8mZ5gxhYiXe3xU4Gqu9/h7fOl6f6u0MzBE9b2j28Lle7rThBHxuHO9p
vi79I++IuxN0kEmfaF79aBqT6+wILw78TPh7/FKoW4mVA7x3yC6guURspYux
yh5u7e0sppmd7sN3v1I7WFLsLqN5LethaGDmTZB19Kj9+/151T78KbYwHLK9
gWaL9DnbsM82oLc9uInm7tdUlch31qB3aG/H3/djqsXFg61g5JtKN81Mv305
Evyvg1yGTN/f+wSPSvtSvS1hKS57iOYjVJWqI+4WYJeoPUpzx6/o1Fxnc3i/
NWuc5vxgRZ8SKzMQ7ZKc/muhpma/0itw98zRWZpvB3PHBGaagJ8wMUdzAJ2c
S9hnI9DTGpqnecZSUTPynSE01fgu0ny3Wowvwf8SsJHZlmkWDF0eTPXWh/Wx
Wys0p/zMysh11oM4H/IqzXsDrj4ssToHzLdrftNcz7sYF5ipC7srKtZoJguy
ake+OwELjpHrNGerMA6nemvA/bvGG39/b9AE/jyCUtr2w24U3faoxOow/Ev7
O2jrY8IrKx5bovy/+yz/B0ijbtM=
       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHDVSYakY57ZLoW4RUoR34VISokKxb2IJheRIZSha0hJSSTk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       "]], LineBox[CompressedData["
1:eJw12HlYTO37APBCaaOFtGqZQ+qtLOlto+4HoUTy8hbRinaSeIukaCGiVZRo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       "]], LineBox[CompressedData["
1:eJw12Hc8lf/7B3C7kmSUEdl34tMy0kfF9dagJGVUyEoRkRmlbBnZZZSQLUKl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       "]]}}, {{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.832885283134289`, 1.9101299543362336`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.336618828644992`, 3.762221576582356}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {9.526279441628825, 5.5}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {8.42648887430876, 7.070663706551931}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {7.070663706551931, 8.42648887430876}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {5.5, 9.526279441628825}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {3.762221576582356, 10.336618828644992`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {1.9101299543362336`, 10.832885283134289`}}]}}}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox["\"Array Gain for drive [1,-1,-1,1]\"", TraditionalForm],
  
  PlotRange->{{0, 11}, {0, 11}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.41475939478372*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"drive", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"PolarPlot", "[", 
    RowBox[{
     RowBox[{"ArrayGain", "[", 
      RowBox[{"drive", ",", "height", ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "Pi"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "maxGain"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Array Gain for drive [-1,-1,-1,1]\>\""}]}], 
    "]"}], ",", "grid"}], "]"}]}], "Input",
 CellChangeTimes->{{3.41474668457058*^9, 3.414746777265751*^9}, {
  3.4147469053450403`*^9, 3.414746922105953*^9}, {3.4147469894986362`*^9, 
  3.414746993168701*^9}, {3.414747050886303*^9, 3.41474706589158*^9}, {
  3.4147471546560783`*^9, 3.4147471595428*^9}, {3.414747204281204*^9, 
  3.414747234472851*^9}, {3.414747269739746*^9, 3.414747311131422*^9}, {
  3.414747685657402*^9, 3.414747686847406*^9}, {3.414748362509151*^9, 
  3.414748424965287*^9}, {3.414748494209344*^9, 3.414748556929154*^9}, {
  3.414748654622649*^9, 3.414748717422875*^9}, {3.414748764785789*^9, 
  3.414748765135943*^9}, {3.414748796898699*^9, 3.414748798321002*^9}, {
  3.4147488770687103`*^9, 3.4147488993898697`*^9}, {3.414748942727558*^9, 
  3.414748945605701*^9}, {3.414749260250078*^9, 3.4147492638159313`*^9}, {
  3.414749310563262*^9, 3.4147493534354143`*^9}, {3.414749532205264*^9, 
  3.414749536508419*^9}, {3.414749577779962*^9, 3.4147495785222273`*^9}, {
  3.41474961160553*^9, 3.4147497316875677`*^9}, {3.414749963944892*^9, 
  3.4147499717593737`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwUWHc8ld8fx73GvZLsvVVmdoQ6pxKRkVFJIRHRkEpRaZCdlVlKyvxWVohK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      "]]}}, {{{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], LineBox[CompressedData["
1:eJw12Hk4VP37B3BtluKxhXr0oEgblSUheSNrKSVFlpIlovBk6ZGUpY2ikCxJ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       "]], LineBox[CompressedData["
1:eJw12Hc8lf3/B3Ato7iFULdCkRbKSEheyEgphSKjZEQU7oxuSSmNm6KQjErI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       "]], LineBox[CompressedData["
1:eJw12Hk4lF0bAHAG80xJZclS3rIUbQq9ZEn3qayRijYvSSJSlix5o4WyJ1I+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       "]], LineBox[CompressedData["
1:eJw12Hc4le//AHAjezxGRh+FIi2UkZC8b7LTkiKjZEQIn4w+khKpKArJqCQZ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       "]], 
      LineBox[CompressedData["
1:eJw12Hk4ldv3AHCSeTq8iZCkEpcmuaZi7UpFJN1cSpkzKxm6lKQylCJjinQN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       "]], LineBox[CompressedData["
1:eJw12Hk8VOv/AHApTEl2h3IrFG0KXbKkz6OskYo2t9JGStlJ0YKrLIkW15p9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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHASkmSIY9jmWRlL3VS37yJjXGVoQCmipAF1dU0XJfOYzFOS
JCWzlHmWMoZShxAyc0hkfNe+7/Pb/+z9efbznOesddZ3OmLWDsa2W+jo6Hjp
6ejI+/9fguh/TzZXPd5tbhII5QiPq6deA5sMmhRpNu9TBeqp7vDvmws8G9i3
nmoyqJTch56Mhtg17MJ6ZSpKDYZDf0tnr2B3atVLymo+ADE5r1PL2IN5B+KU
SqLgeWt7xCK2geXK2wPycZDkQFyYx37AkOL1Z2oiXOG7UDWDnWSR8/kY9yOQ
/JRYOIFNx2lJldR8DFGlHYdHsTm2ywXKbKSB2Ce604PYb102J+VK0qHviBwD
Fbv7T9mNPbcy4B69/rEe7DuHJ0oU5DOhfIs7XiCBTjmcYlNOfQE8ToHONdjN
jiHxyubZ0P34AX0p9iV1lwJl7hwwqQrvzMK+vlb3llczD7imfXnTsO2owtt4
xfJBy/zObBy20vrATspGPuj4aZ/1xc4e2XN4V0khXHggPe6GHZy2asYZXQRu
zvRsjtjxQdWS7LeKIeB2JpsZtnZXeS6LfAn4nKial8JWvmSuufKoFBJEPAg+
bF2/cptFjzK4oaf6iQV7bXwvZc6sHHYHJTBPbRBoLHFIeHhXJYwd1jJ4gW0d
naT6/Vg1HDo+sSMBW3R42xfL/GqQSA69GIA99DDk0BfRGkiXaq+6hP1MT0y6
fb0G3uYa2PJgG+bfcil5XQeujZPldNg8GSGNKtL1UPdP8PPJdQI99zSoy4qq
h5WZFrUq7M8HGKsSnRogOcHuqA32oIvhA9c9TbB2Xetz7Bper/uQuMSj96Aa
VLDDDXuteog6QPkAE0/Zqi2wL+w7TUkJ+wBFjAHPhbDPvGDapHi2AK/YU9fE
VQIFbHl0bcv5NpgSZOL1WiGQN4vIuGVoB9SIuR03w65TN1BXe9cBskPf1/di
72nepbuLsRPYTiUOD/8mUJXc7vMNHp0gWJmdp4EtvsPLX/b6R1hiZNIfXSLQ
oxKp6a/Hu+HhjLxnCfZvlZhXuX7d0Bx/SiUIO2m3D5tvTTeMBubwymPPXwh+
JH+oByZCk4ev/iLQepb1rztyn6AgXMa75SeBblo+9lpi7oXrIzF1qjQCbaO7
fj+1jgqtj1d5VucIRIyrf3Jco0LGl+9LVdjSEo7FSLUPNq01buhjJzeZU749
6YPyOCNhi1kC2fxk06T49MPHlJAE22kCrV5hay4WHYBaV8ctMuM4Hl6dXqb2
D8LtYpnL38YI5DOZzF6+Mggp7+6Zx2IPy8h+S6IMweq87CIjdkCF7lMLwyEQ
VT413zdKILegiOru8iFgX1Zhcx0mUF7K7OfSpO/wY96jxeIbgVz9Ol0MzEfg
4qrvL2bsEKXOpRjnEdBkf1lY0E8g7s++koMRI+BwxXSOBdsu4LLv340jUBKt
ZptHxd/PONEsVnUU7He6ak/1EoiVXXvuw84fwBmrNsfZRSCuau+VnzVjcE7E
uTL3I4E8g0xsVfvHYEH5t8QJbKfuRsfbv8dgunngZVAngcpX56/MKY3DkNKZ
irV2Ah1XGH0/kjQO01nKgx9aCKS4/cvOijsTsD/nqopQI4FO3OfJENs9BQJP
KvWeNhDIQXncNU1nCpqyy4flsbf2C7eK207BD7+3aYfqCeRfmrgoljoFZbBw
9GQt3i9Hg70ClGl40aizcqmSQKEdfDM0+hlQWpYNUXiNP8/T6MOh3lkQpbvy
WO8pgSyp/wZur6UB01OriLJ0HA8zElIV7TTYFljEpYQ9dKTOzamfBj5VTh1c
TwjULi1o8uk3Dahyrn90p+Lzn6OV/0h5Hn5qFDzTSiJQEPuVVfGUeWBYzJDt
jsTn96QZmndZADreGOUcTwLt9nLueqawCK5dkTFqfxGo9pjqobivyyDKtnme
nodAsiptedZOa1B1SfdEQ68AKhfd3Gddswk3mS/+sT9SAAk0ikdKPadHLWoB
kZG6Auj7C/p5HUMGtOGpaMK+wo9eVPa/9BjdimJ+mX/7lsyPaiM+Xa9MZELN
lgmcF9X50czPJPbtituQCffRc1I9fIhpL3HhxlcWJF0RU0Cz5UN7VB8WVrqy
otTmFreDS7xonnHs8onFHWhDayI/2YUXuf/u/JM/cCcq+2jveXuNgpCMVfre
FXbkcrbQ5L4DBb21T6VPqeJAUSvnYrv6eVDe1k4xqjsncs+9NXPWmAc96Z39
U0qaC5mxffBTLuRGsj03Td71cqFUF1NnJYIb0U7csM302IWGFYRFTb13oam1
fxhTeblRie9xPo6PXIhLz7vgr7fcKBme98TIcyHeQlmhrwY8KIgw0pK4zYnm
hE2qm0d4UPrKfUalEg6U7ye40OJMQXw7du9+xMiB4turvH1+URBvqebBQ147
EcOJMWqnOy8S1K3qeMvIhtgEjZrRPC8KTTKn5YWwIiZVWkP8RT50U0loj8IU
C3LgehjR2MGH6Aq2naG32oYkrdRNhPbzIx/mLaKT2Uwo7j1b7Nd4flT313Jd
PScjyhAbnD1B40d9dKExcS4MaGdcf14tEkDDXEUf/31Nj/Kv89A6wgUQ5Wzk
+3Z2OjRYeC26p1MAlTSPPf7Xew00GmjqDNz4nC54Pj88sQy7Mwu5bQwIdPJE
RvDF4EXY+pdKk5gbgdTtDdiLPRZhd0Tx/V7s6XMMKqw3F4HZcq02wp1AQvty
ThSeXATj8LLmdQ8ChY8a0m+hLMK8W+FyhxeBtisccAxO/QlNlgUfrX0J9JP7
sNHZogXY3j7uIB1BoFd1ys1jfTSQi7wVp4rjQn9JLU8cx4lVl9rHGuz0FC+j
czU0eMCknHoSxxW7cmJFawYN9BxS5+wzCPStl90o14EGGaKm1xIyCaRT3ON3
mZ4GjuwSDcMvCfQx/a+iVMk5iGWN3yJThOu0AZ1iJ2UOuCcIr2fYPg+aLjOw
zMHlpKBQmWKch6sm9jZ/mQWLYImL0jiu14y8ufSvz4Ki+Q6q8BsCGa0f8d0f
PgMvHzIqrJYRqHHssVpu1xQsLBlKW9URyGx88Xj4myno4DNN6sBuDkyZuZEy
Bd+QaaY6zivam8EzcnZTsL589J4ozjs51+WpSauT0JEW/mcvzlNBHIrvbopP
guiXnPYD7wnUU0atrHcYh7edrefTOnAen304HGs6Di+eUyIYcR78dDU686ra
OFiLyJy1w9Y2oHDsYBgHya1Jz+Vx3kxqvWpnEDMG3T0vjXJxnpX3l48vLfsB
1HnZoiefCBTWtrPzNMsoNLxvrzzURyA+j4NPWiZHYL6/fDYWm4m5n1OzdQTW
CxzSfmJ7F+a8U3o4Ap4SRMRLnOed8ufztgiNAD2XTQhlAPdJP6R7Y5SH4f3e
88wfhwhk8UtA0uPMEBxWOLs2/YNAAq2cGT/UhuAobeDuYVyHFrxEeowFcd15
thEYgK168KGG7OAgRNxdEBPDdY2n8LJFm/0gOD1KdjSYIJDmAT56dk9c9yTa
/YOnCFSR4eGVo9sHxoLM0S9w3Vz0fMdjz9kHV39zGoxgB/88fUjyCxWQS0O0
MK7Dtt+jVGKvUUGGKjsYjl1vrTX3T9hX2CdWeubGPIGyNmquSXX1gj6Y1+7C
dVxe31u/N6kXDN/Hp2tjWz5laAyx7YWeCmc+V2xV3oqo+V+f4XrT5msqtsbJ
7LQ3/J+B5Q+dnpRFnJdHurQOXOiB0MDNsJ24b4BbtjrDMj2wmPUy/hB2NeOx
+Qdz3VD8dOLAZfK9ko7O1N1uUPekyJVhd1mIMSWndwGOxSnrZQJ9Lw2Pmh3v
hHh2w6lE3MfIGNyIiMvvBAGHMpFq7F5F0WPq7p1A15A3MoJtIGvX/mBHJ/AI
Kskp4r7IvVU5TUmpA+J5bMPeYHPOGFaVj7VCtZBeRynus/ai1IPljq0QuGdr
IRXb8tymZNlyC5Ts46OsYz9u9LUu2Yb7siHds0dwnxZQy5qdJfsePm+WdRVi
z2VLbMnIbYYMfuX8DmzKcX9q6sFmCGxc2jmDPVvcLhet+w60Pt/TlsJ9IkNR
g7WLXSMoCLplh2KPOMQIO841wAb3fd8MbA2jOccrLg3g1NZPrcA+/WNw0DSg
Hmbf32eZwT5ymU9lT2Yt+Pzhb66N+9Rsg+g+EeVauHOXVcEC21/nqwp3SQ3c
NezzdMAW57T+stpYDX4bV1JjsAdaHNvC2irhKAfH137stNxiodvfKuBN2a9n
s9j91mz9p2fL4ZW67M9N7LIy+QZB9jJ4/MJ+uwjuw6cVon9tCJdCIb17lwJ2
LL1h1oDiW7Dn6hY6gp3qMfcyzbAELC7YKp7Bdt903epj+RqkRRIXL2EnJj6c
s75ZDKWp/EfIucBuqjhWLKwQuljmtP2x6UMuWtClFMBVfx3WSOwQgS91/dn5
MD4/apiE/WrKIyGhJRf+6F0zycE+fjJEeO5tDkSt3eIpIees+0fvZH3JhlVL
5dNV2BJ/52rarLwA1y+qlCbsddF7kUICWeCg732qDft8mIldj1omBERwcZNz
03R1XWuYWQbUB00akXPVqVrnVm3XdLgtxMo+hC2QxOS4EZcGyopO+j/IOekM
b1lRSSpMpAsxT2FzbY2405ubDP3XODTmsHlNnaa05+IhwUFvbQE7oZxrskAp
BlZSmvYvYdtbFfqIOkSCwmTozG/si3Xy4fznQyFbJ16anDOVmmjhtK++oJs1
0beOvWuv49nIIg8QYL3HTc6p4qY+nGUaHvBJo40gffyNS/NImzt82r4pTvqD
8Y4jahNukKLPpEKaOe+70ICwK2hGFOiTVjei9LC8dIFdx3mMSdttUwrbp+YC
ElFmZ0lfuce94WfyD2zvDbQhHbZYRlUIcIZpqUB30jF6ClFneJyh2WrTm/QF
N3/9u2l/w7jCWT/Swmqrb7rKbsP0nbwI0sXu09HuNCdg/rAlnbR8/huDp55O
MB8YmklaLfg2QxurE4h8XnlJenUyz1Fc2hEOS/1bRJrfqSUqsug6BNwTrSct
R2dOP9p2DbxqKptIs158d0Ntwh5KItU/kBYUNdUeEL4K09+nOkkfuOSUv0/N
DsZtKD2kl444C/ubXAHZO+K9/+2HhuovhQBbsNMb6if9+iTN6m6aDdizxgyS
ziiNa+kquwSvzssPk25RzUp3p1nBcj7dOOmZfRSONlYroCs+Ovnffug4uotL
XwRdvQvT/+1/w/CTyKJz8EhUl0Zas+Sgm9qEObyw4Vgg3aTheHJA2Ax+Hyz9
SdrLO1Ta3+QMBCTr/iJtfDByTSHgFJhFliyR3qPi3dlVZgL2vKy/SS/6mmW6
04ygXB6tkI5fF/EUlz4Jxp1nVklvrch6FllkADLbjNdI7zdeMh4Q1oOjrYrr
pGOL5DYUArQgRnLmP9Pd0XruTlMHJdaIDdL+GkmZkUVHYDt5/Mh4rPiMLQ8+
5M+BvePxpd6aoYoj//uf5f8AtE1S4w==
       "]], LineBox[CompressedData["
1:eJw12Hc8Vf//AHBURsgeRfco0kIZCeH1JiOlJUVGH6GIwscqodCkUkiiksyM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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHDVSYakY57ZLoW4RUoR34VISokKxb2IJheRIZSha0hJSSTk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       "]], LineBox[CompressedData["
1:eJw12HlYTO37APBCaaOFtGqZQ+qtLOlto+4HoUTy8hbRinaSeIukaCGiVZRo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       "]], LineBox[CompressedData["
1:eJw12Hc8lf/7B3C7kmSUEdl34tMy0kfF9dagJGVUyEoRkRmlbBnZZZSQLUKl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       "]]}}, {{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.832885283134289`, 1.9101299543362336`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.336618828644992`, 3.762221576582356}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {9.526279441628825, 5.5}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {8.42648887430876, 7.070663706551931}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {7.070663706551931, 8.42648887430876}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {5.5, 9.526279441628825}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {3.762221576582356, 10.336618828644992`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {1.9101299543362336`, 10.832885283134289`}}]}}}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox[
   "\"Array Gain for drive [-1,-1,-1,1]\"", TraditionalForm],
  PlotRange->{{0, 11}, {0, 11}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.414749973344413*^9, 3.414754397836309*^9, 
  3.414754433816051*^9}]
}, Open  ]],

Cell["\<\
KC1XX uses three transfer switches to insert 180 \[Degree] delay lines in the \
bottom three feed lines for steering the vertical angle. The four choices \
available in the control box are Low (blue) = [1, 1, 1, 1] , Medium (red) = \
[-1, -1, 1, 1], High (yellow) = [1, -1, -1, 1], and Nosebleed (high) = [-1, \
1, -1, 1]. These four combinations are plotted together below. The rather \
significant notch between the two lowest lobe is right at the typical arrival \
angle for signals from Europe when the band is open, but the foreground slope \
seen by the array pulls the second (Medium) lobe down into a more useful \
range. We also find the High choice sometimes useful in the afternoon.\
\>", "Text",
 CellChangeTimes->{{3.414759632931616*^9, 3.4147596686273727`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
  "low", ",", "medium", ",", "high", ",", "nosebleed", ",", " ", "grid"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.414758721235214*^9, 3.414758747542981*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwUV3c81e8Xly3bxb2uvbL3ns+HokE0KaWkVCQjKVEZWV8NUQghlFBEw4g8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      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwVV3c41t8bNt73lczsPV4rCtkNOgeRMrIplRFaolIqvjKjzCR7JWREQhmh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      "]]}}, {{}, {}, 
    {RGBColor[0, 1, 0], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwUl3c8le8bx23H3nudc4xkbxKe2y4NI9EQskdpkDRQQomQaGgoEZKR8SWj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      "]]}}, {{}, {}, 
    {RGBColor[1, 1, 0], AbsoluteThickness[2], LineBox[CompressedData["
1:eJwUmnk0VV8bxyXzkPHec433mOdrjkx3lyEUwi+hVBIpSZQyRCRJyFCKSFFS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      
      "]]}}, {{{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], LineBox[CompressedData["
1:eJw12Hk4VP37B3BtluKxhXr0oEgblSUheSNrKSVFlpIlovBk6ZGUpY2ikCxJ
yB6Rxr6EpqxJ2bIlZGdOKEtFv8/0u77zz8zrmnOdmXOuz33f789Zb+VsaLuU
hYWFewkLC/P9/19f8b9PERU5Fb9/U3DiFf/vfihwiK2OlWnvznTl+6EGWGjS
fbdAnNK7pYeRaQwrKSnhX8TXWGs1w0JPQUTIfXSeWKCvJOJhsTUKYsT3zhJL
+qmqTWTa4VHVbv5vxJfbb99RjXOEWOLzc1+JfXu0z98NdYaHWojeOHHCm1sj
zpX/ojijNW2IuJOh3RZR7IqpH75BfcSMwe3/vaS5YwnCvnUR334WQh/MvIgX
wSt7WonTtctpXCmeKFwyrN9I/PT5KnX5OC8sFLaQC6Rwg3cvt0/oVaxRHEwv
JI4M6Iv78NoHew9YSD4nrmNpm7Op9IVy/tWUWOK4s64tt4r9IWCyLfM+cczZ
c4Z/F1wDq4iqQiBx9a/8K09p18FeFvXBlXm/WEda6jNvQpfqG7AjlgkXnTdP
v4X56bDLZsSBQ/tLxpMD8EV5u7w68TahDfyr4m7j36t69azEPkUaERqhd3H7
d+uPmUUKF4p0Uux07uHNyoaMQeL2hsBXma/vwbNyPppOLHRCUUGpMgRfRA3i
LhEfeHe2Qb84DC1GO0fPEIcWb5+/p3QfPVre+YbEm6ZkW5rz76M40qxrM/GR
R/ujzGjhEOGXM3i3QKGq7quwbWYE/pH2ouUTn+4biU7eFokLmTKPHhOvFH9d
PJQWCQ3TsbnzxDYZrp32yVFwEIlpX07cPTtmfubxQ/wyNlAT/kUhy35TkX7I
YzQYCcrN/6SwYYlFFR9XHIYMvMNaiSfUZYavHInD6VLpR3eJ6Wse6B7viMOM
09bmHz8oHCrgtVoyHo/Xwdve585TYDHqGNDhTkShs0ZsIPGKpX9JZh1NxHaX
5e0niWV27uEQjEyE9/SdiBXEoYOPXvSJJUEz5I2i/hyFT1y6Hhdlk2G9LYqz
bIbC+WcG8UHHUjGZ8JoWQKzuZ3WFEZWKobn0WiNiMc6e0UOfUnF4VSJGvlNQ
CpU5/5ddGo6NORxaRXyXc9n3m/+lw19BmkV+mqzf9rDf1g8zQN/6d4kQRWGL
nlWhmUs2eJb+fNfCIOtDaImX2r1suIlcsAkjTlUM+CGRnY0Q/U3cXMRPLpjI
TFDZeDFb6/hjnMLJeTaXS87PIdgxolE6SqHVw6TyplMONt/2cekfoMDHY63m
cI4Gwe9HokKIey7RqrXu0KDz6JMGiLcYcvwWy6AhqH77mqgvFMrby11bx2hw
4ntXp91PQSPWx3mvYy6uCiuZBH6mQLXzqv88mwdpZQfunA5yP8qUmmTtCpD/
w0DVkFh2wsLG+kYBDlVzTU+2U0izcYsISyrAkyNCjB3EF8ujeqf6C6D2LXBr
chsFM7/ncxmWhVi1S73Mq5nCpSduNX+ZFoH/VpZZ3VtSbxvDsq/rlyCn47qu
OTHN81RkmmMJ3jJsi8frKSjekOZ/G1gCb879cpzEL0QnX/LVlEDf7L2jVi2F
ndxsI5FapeCWMV8S/4aC/M55nnuqZXg3XlH7q4yCtMsxZf415WgJ/13hSmwT
ILSe2lyOAZOFLaOlpB54J8pqlcpxpF9Dv6WEwvINCSK+ZuX4FaLckVhE6i+g
z3Y0thwyX9hFtuRR6C+Xff9sYwUU1FYav8mgIPybg21BthJOoVKSRpFkfQcv
HI3Vp8PdVZKRE0HBebxnhY45HYYrvynxEh94UWxHOdJRpLfaoj6c9LPDZ5Vx
mw6tVVnvVcIozIz3ru6soUOlyN+DNZhCbLW7/TKd1+hpKCtX8aegX9PUuVr9
DZysrRi7zlE4FrLmurR8Neb2+N/MkqPw70HL+Uz7emw06dB2nmagIeDls1q1
RjgdvMhblsVALp/EPGPjB1xhZ8mctmDALvqTBeuOZozOSQvUczBw0EtSyZCn
FTodCf682RMYDlmMa+trQ0ajSF6e9gQOms/EhbS2Y6e4yGqW7nGMCa1PNEro
xCnLDW2uVuOIWi2qyx3UDal7qm8V+8YgYzk5FXKmB3rH5Pc9sx7DmWWWp6Tv
fMaGqMqTCx9GsXB2R8fIhV5oXTumI6g1CpY9SXVNWn1QezY1uTxxBLdj9bq1
N/ZDpSX4fdriMCxWfC3Q/NmPfQylK+tODqNH3cyxt/QLAuPpbOZpQ9jeWKW8
4/YAJNZdP331xyBqFbhLDbUGcWhsIe+a3iBkHYRLz88MYra3UtjHfwB1AxJv
TbKHsF5iR4bq6y/IvLb9Y4vxMDg1fXv1J/uRmFsfFss6guLsFW5PhPtRfzjY
X/7pCGaPVxqFGPRBPclp40HVUXDRlrZpne/Fg/EvbSmto6g6qHf0bvhncIsp
DrGcHIOcVgu/0uUeHJ5Kcv+nawxXqn/FysV1Y6JOwNzDYhxO/tvfh3V14sJ+
58lfDeN4wO7SeWysHevo3LdENSZwwTugxGD1R7hJFijwJU9g/f5Rq2dqreBR
y03uYWEgQmDNHkc0Q0DuBr+SGQPfZlbTd5t9gLMKPb0xhQEx1uvm5/Qa4RKV
3K0/xYBjam6FvWc9dpZbXi+WJXVavY2u97gah0bNOZbaUVgSOzJ+I7gaQxNW
K5qJTV4UJb3yrsbLBc0LSfYUHJSrq/eYVyPFNDhW24GCgvt4l+Taapzc16Dm
d56C0ehen+HQKsQs1qd+cqWgkn6nVvjGG6zyeTSxzYfUacnunUdJHfznlxIg
ROri+K1m83AzOgqm5gSKiD+3hyi2HaCDX6pGwpzU1YSC/eIJKToGxztrYqMo
iGuY1ZpNvEJU/jUZkRhSl9/WRh92foUa0yK3FfEUBLfKv2NxrcTMpaZC93QK
piMSJ5SsK6HiqRnC/pT0yVqO6H+PVmJb8NBoNPFkXrp6r1wl7IeLJMpIXW+o
kNhR+q0CVzSMcxafUTia215o51GBy4JucvYvKBwU8tUK8CzHKWHesq5ikmsa
RErZHcrhazulaUH6iIEr78xN03LkOaUZdhMX6fZlXN9TjrvrQpZ2kb7zxNj4
7K8fL5H8iZfW9JKC5+4TFVVLX2JjtoJ5xisKjW1ioax8pbATMKUtrSN9qUaw
ZGaqBFyrrPnciN/vuHFxsKkEn8TZZ78Q99GfJtLDS1C8XMzoNemTWrtWDXit
LcF0o7GFTwOFv16O2LaKFePX14vpPe8pjJuOJ6vuKETUcXOJfR8pzLZ+0Pfm
KkRKrnZiJvG2Ixv8iscKoD3FGy5E+rqTkNkjhdQC6DzYVzNCnKxUn7xpfQHC
Vn/2utlJ4XW0e+B3vnzI+Duwp36isO/mnWLNGTJ3RjNzvMncsUtIdvNoJnNJ
cf+BVuLJ3+KNKTk0TJTdM9pO5pSKWqoLhzMNjP2ChV3Eayzd7auHXkAx72ON
7BCFkqfCBbvac1DUM8FOH6EQMkn7/b44G0pt7tOXyNy8o1sSqxKTjZX/KI2U
ELvNv/qVfDkbnTZsVovEAnWVs5f2ZiP6Z3nXVTKXSzexMnAlC8oFd2Yuf6XA
Kf4vV+m1TBzXzS46NUWuh9PpcaBWJqpeZX2OIj4X2VNmzJoJVfGnAU3Elu8X
0r7ezEAcR6iNFpn7LjVy+v/cfopBVXZV8W/kfAbTkVYhaTAZ7LhSRXJCXt1W
jy2GabjBKdc8T9wdqf+V4kvD917PjG0kZ+hWS730up+K/fcaB4KILTWd+4Ij
UtD9T5CX/iyFzTlXhRIfJWHONEE2h+QYdmOT3bYnk9C8KzivizjrSugySdEk
hLpZlLKS3BNnyJGUHJeId0FPjp4gFt3FvynxyRPMpZckzBEf/VuaJSQtHvtp
MbWiJHdlSficXbSJx0r6ckstYgWeTj9HsXjYvrWxciBOehBeqxlBcpnkymc5
xBzLZeOHOB7jw+82SxWS8/hOHCws9YmFVPOEhQXx90EprbDZRxiMnqnyJlb4
m79SZSAGrM8+9ZUQbz7tHh5QHo03mvNy8iQ3Rk48vWe2OxqO0w8iDxPfrzXj
l34WBUUFcYdzxN+llhY2PIyEqdcKowRiMTbbWs6LD7A5s1+DjeRYucuntTsn
wvEtbPgvUWL2L3cs0mzCUXDio44Csb7vATtNw/soa/dgsSZmsNlKe0iHoj0x
8U4uca1wa5V6Ygjmzn5/WU18VVGKl0s4BGNLtlt2Ei/SrIoS2O/B+fixoUVi
7hOnVTsWg5HmvK+Bm+T2zAJvT6fxIHAKrNkgRqynxTAOr7qN5x2uPCDel/fP
is25gSg79yP9IHGQ6LXdRQkBCHI6k8PcFwx4ZaDb+yaEKifYPIjD6HqiTo43
UBHNftyPuQ/Jbo5YNLmOlZNsvMHEPHIOdiLy/rBWf/H2CXGv9OHqzPV+uN52
8l0mcdn9jhYVbl/YizP25hM/2MPYEjF/FVnzlmvLidcv2SRAa/bGE5n809XE
H8eULzZmeWF70ldB5r5p1HmF6XigJ3p3cim1Eb9bZlXFduYiJl9wVncTi4hJ
1WxQd8duHupVP7ExcHbvOlfs3EqTGiGu6PZ4bjzrgsVhs6UMYuspc+P+xPOw
UxjUnCJuXu//StDsLFoWDb99J67cL1Ssx2sLE5kEHuY+crdL45HLVZaIf9kU
9ZN4QrpOweKnCThih+4y96FGgcLGFXaHcftV99QisaKn5NENkoeBZQo/ma5s
UotlrTFAZuy5Zcx97MhXelBg5SHkDrvxMx1tftAxNFcfF2omZZhekmxlZSSr
j8lBFSWmyw1NTwhmHcBmyzNqTEt/mtKOTt2PSlujQ0zzfGsTS3ioi/jSGHum
b+7gFrJZo4uhgg4npsVFpLkkw3UwyD3rxjRtneh8WrA2uN/X+vw5vnX03XNf
TbDHfXrA9GW/M69dF/dBwJM7hukzMm+LdnntQ0emSDzTPx5bJBW6aSBo68f0
P8fPRnlW2KkhxiW/hOkKifku1hrg/KbOcqa5WB69CaxUxaxSN53pX3nXokJz
VSB34XL9n98vqvUTzNqDwYi1jUxbv5h2jE5VhuHa8Camu+9P7U14qAjDHZs6
/nyfVCspGb4bQ6/2djPN9jOAOz1YAfI02c9/nhNcr/z83Fcesyn5A0zvmtpb
s8tLDk5PdYaZ7uhPfF7oJouYlXmjTBeHK/lV2O2EeJc0xfTFcL6k0FwpBK4T
nWb6q42SVsLDzWiqC5hhek3U3JfnvhJYGDk/z/SmkNPXKuzEwH6x7uef84WN
EfOgkrkcmP/PfLWcZHKIyv+ec/wf6Sr1GQ==
       "]], LineBox[CompressedData["
1:eJw12Hc8lf3/B3Ato7iFULdCkRbKSEheyEgphSKjZEQU7oxuSSmNm6KQjErI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       "]], LineBox[CompressedData["
1:eJw12Hk4lF0bAHAG80xJZclS3rIUbQq9ZEn3qayRijYvSSJSlix5o4WyJ1I+
a/YlWQcRKjKW7MvIEpoYiYhkl+0703d988/M77pm5plzznNvI25ub2BJYmNj
42dnY2M9/+9BQf9/Jcer2bq6SiC+E5v/+Zl1Htw0hDVYjt3OtvdnlhWsxN4y
XsFWu3ZJ2ol2E46LXxZYxh7wCncaz3KFc62d9ovYYobRV65F3oWAgm7bBezn
/fsmbtI8obD92vo57L8GrL/vK/ICYVXv09PYCdIzIaNZvnBhYu/BX9hTu04w
XiQFQCD75bIxbO2rI7QrkY9B8Y74yHdseRnJqGCtJ3DE3u71IPbwUVt+W1oI
kEe1pPux2RSeaB1Xewa67NnKvdioqkZWuigU7umK4QUSaHujLXdfVjjwpe9F
9dgWTYa/3uyMBLv5qt5KbFnPoy7hSVFwozZuuRDbYasMOhEZAxsf9HnmYNvE
JrpLC8SBV1h22gvssOU1cR5a8eCjP/U5DJtRaRdvREuAWwdsfjzGHszpLKm6
nwiLs3YxXthpMkqP5dSSYE+mxJADtlmIkT6lKBn+s+2giAZ2H7fjr9ysF5AG
4oeUsTPCR922XE8DAb8odhlsTcVTKV47X0LPaVVnfuxE7zOtZ5PSYfS86nzP
CoEmCmMVpiKyIB6S9zdiG4tUuxidywar6Zg1pdgq1xugjD8HAvPUU2Kxl2fm
8tS1qHBO/6q7MXZ7xPRHbloudFw2+aCDXXtt//RbsTwQPDpYcBBbu7utwfZ+
HuQ9pLrxYeuWhyU3HcqHFkGFpIplAn1boFYFvn4Fy56qDgLYD4NiHi1kvoao
slPffi8RKN+Te89z/iIYW4wZ78P+ytQxOexWBGv0mQUZ2FI7+m94ahWDUtu2
bYewXUI385OYJSCQ0WeivYjP996HrlHBUqhvy52VxqZwbCr2uVsKEmcqJAjs
4zVdPOJfSyG28KVc5W8C9Xy6wXMmtwymfoTuVsa+urYw4lPKewjoc/Rfv0Ag
Om1RaTeigYJKqNbQPIFy+2sZjk40yFJhiyjDFtaRln2TSoM7lDc/7bAzZAZb
j/NUgIdsi1vNHIGu69DmLLsrgDkszmY1i/d3IHs1wLkK+OP5G09PEajUlj/M
P60GAo8sGYthH0ryLDLrqoHOsLOPxicJtPSx0fUgpRZsb1+s98eezuCsG7Cq
hWrlrpY3vwjEM8uddlC6Dp5c2T/JM0GgI3leSfUp9WBqbRZq84NAWyJCzeIS
m6DFdVleBlu/aH2WNb0JZmakHH+OEujw4uN7cqRmsBGRpDtix2smZJVfbgb6
iR5hlxEC5d2K57fb2AJxH3fTrIYJ5HSl0eFOcwskZgQ/4vqK90P/+tarJ+iw
ZulN9rsBfL43NR/VWdBB5dzxWy7Y93XDc/fdwb4bMjnAJJDRqQO7ZtPpIHtw
OO5tP4Eqxb1LPCltUDNEbTL5gvOBm5DQo4o2WJ9a4XWhm0AXTOzULZTbgWxh
ociFrRWtJV92qh02OwUG5n4iUPp28yYR63Yw9XeVWoNd3Tm9oSmsHW5zft74
qhPHr25Vtvx0O9Rv5yqf/0gg6a8l635kd0D0Td4ItWYCqe/06BTd3gVm1Put
HU0EEtRPyr2q1gWZpHtx9tglkVe2Us91wd3d8gtxjQQiH5jKOuKPPZaRtFhP
oD1NbRGXxrtgR4ZPR2wNgc6INyj7FH2CnVSt8tByHM8rQQHuej1At00QhTwC
HTi7dHfMkQERHc/lq3MJlMps9rMJYEAp4Tqqhz0RGLllKIEBegebNYyoBLJc
iOlktDDAWftYjG02gW4OGMTV7PsCWfXMLq90Ao1lUkW9R76A9JbgJ7aJBFro
YCQ3U/vgaV2t484QHA+2dEkJaSb8vpGYUnGVQJtUKO4P9AdBlCbp8kyRQAX6
28iyl4eBz03kcRMHgTaKFrp8UxoFU/L78lvVZBQ11BjorzkOVDfmBiNfMnLr
7U1XC5yAAskSCR51MrIbKy0SH/kFnqLhlDUzXEilqkhpzGwKLKIEN7xP4UIT
rcLuZcXToFVj1N+hw4WcTgrdqt81C+I/xiPTv3OiHRSFW2OBczAHVnm0AE4k
wrVxgzp9HroneYnDWznR0latD6Z7f8Pfkh4FLfkcyKPLNfed9SJQSbcKOFQ5
UIvtuO7I6yUY27bn4mopCa2jWG8aml+GPMcM0/9oklATkyJOF12FnbfbuLjK
2JFE76YbV3ayoS3tkv5fVNmR8LV6npV8NuTmcNhf8jUbSg3+eIKuxI5u76IL
xEuwoQuZPZFHK9mRfKEmiSG9Cg8GJMz7jpAQ37cjBlPfl0HV79P4bCUJCftT
9rm8XILIt+nmVogDOT6QXDVyXYRfi3y9xdkcSGC9F21Y8jc45I72L4txovTp
saVzffPALWyT5eHDib5NfWnaHTMHb10OCQsOciLTMLXXUkqzMHlhY5WwJhd6
ymT22g1OQ4crf4FaNBdyIIdaeDhMwaY27tTwX1xIcKtVo+qGSegUXfvy8SEy
iny9v+4BdQLWTRDvXniQkblYcpfYpXE4lZrcZFOJz81xW2qb3ygYyvB79C6T
kaz/hwAJu2EQmDqUWqxAoFOHtUPWGw/C9ieU5HX4vlHvEDN0dWVCSQ6X75HH
BPJUzJEbtGGCrfxazi/YD8h6bw1MmXCyNH/TnSACtewJ69irwYTlipHZV8G4
Dp/P3fGZjwk+eVFU8acEKrPfZ7Yvux9mSiNXvoURKOv+987Qr31AEVOcFIvH
eSrKsGYpngHdCWovTuO48Gw4zG3mz4C1hW5P6rFbqrs/0m4yYH1/2BYNHFcW
Bs+XfY4yIPOXhdDBfAL9PeCXs+brZ8j3l0wRLMBx+VNqaF7qMwhVPhKqLCKQ
ODQpemb2gNJzU92uMgIRpq+5OkJ7YOyfqRua7/H1qeutdt/tgfh0GdlX2DZ8
HszWEz2gvy8wOgjHdb746+otP7uBcbOcCypwng6uDouW64bPG8Olgqpxnk48
MnyisAt8PwYGDTbgPKKQvYUnrgvEGwqmNHAemd27+Ve9bxdQ+FeXU7CFbA0f
aht1wfX2H+yWrLzjyX5SbakTlq7yfGDgPBX9ndS66WgniHLu0iinE6g3IWLM
q7EdeJ4cI452EahCkJdHubAdjmvX8YRjf05K/vQjth2+bdYsHsVOb/NwN3Ro
h0AO4dVnOE9OW9WMivK3Q2Evu2YfzqvHT9o3xF/4CO+mP5VZfSaQnLrcst0A
HaaQhrE8ztvK4rELf9XRQY2ioPoAu+9tZEIDlQ6vXBpzWrGfnuac3XmPDgXU
yXP2OO8f2iPy7rMwHew2DD9PwXVC4O8uaSX9VrBkniSvfMN1vc5AxOpmM4zY
kzRNcd2JmlrIzj3cDArprkXx2COrCkWL3M0gH3yjjIn9j9nSzqDUJpAvagmw
xHVs+0bq88yeRkj3Mxe6OoY/77krtEWjARqs8siGP/H7bYJXS0Rq4frlCMVe
XDfpNzaP/zNSAzXtI9k8uM7um93h/rukBpIfedcexo6XTXZSMqmBV2+fDMZh
N8V4TebEfoC9Ad+LLk4TSKdboO6xZDUgRc6GDzMECvV/Oic9XQXt9IfWU9in
86SbyyurwO4f9GIrrvOUi/fuT1tWgZKvLbcztkCn1MLZtErYu9/HbjPuC3Tc
CyfXyFQAbe/2uLO4b6gRjheOW6aBhY7UJXfsVEfl6QNNNPj3mnF5PLZi2OVm
E3saKN0wuTGCre3Utisjtxyudrw0uY37lNiqOF5VxfegUrmQ4o37GM0jD77X
k9/DpbQRvxRscqkxV3F2GdgJkddXYU8sPp5bmCgF4/SSFRLui7Kbn6vccnkH
Kh48bm7Yd14c8zC6V4J//0znedxnkQ+i2LtCJUB5xkFxxj4doa2eQC2GdVH1
tcHY85f79g8xi0ApxpdUjU08HCyy1XoNjNUEbRnc5zWRfh8P6isE8UuOZE1s
pax+p+zbhbB3ev6sKXaaYVDIWEYBeJGk0x9jMyjCslYbX0Ho1G+pIWz5SY9M
r5f58ETxpuMS9s9Or6aEo/mQbh11khf3mUUJ5Wt7nPPAS5SzTBn7QlV9uM4n
KjDKdzt6Y0v9Vets4UiFObt9uuHY5Ixd5PvcVDh+jFmQhj155FfUVfds0Jc0
QnXYg4+E1OXUMyDJ3X0XBffRObvKM8xvpYPbhvlgQezSM7TIZ2kvwcFTwm87
9t0NoULT69Kgjc1DBrDrSbXZkvACyp7ldetiPzi+tcfgZirUbngqcgF7Ln+S
ndqeDFxfz+nZY+dpd3AwiGQIalVFbtjpQkkvuVWSYITeUMWaC36YlP+0jE2A
kNOT3hHYdoau4U9b4oHX2ed9Ava/Xl9+lZLioWa6KjAdO0JvW7RM03NYe1Oz
uwSbrv5vppd8NCSL+xrTWHPWlw+oJywSgqIc7WqxqZmOl+QWw+HYGwp/C/Yn
9HmD76UwULHU0enAZsreMOqtCAWm+9+8rLlpgt/rmNzOZ/Dya60Na67qeeDf
7h0YAjM+a859w5aRpcm86g+GXXpT9BFs0hfGXybpgZC8zbd/nDWX6MkHcDj5
Q+l4peckdl2Bt2e6qg80pmXmz2BfMkrkO835EMTgsOs8tuREYsR45H0gpdxu
+I1tkFbkprLnNhQ3m+YvYTuaC3/3fusIvoVje1hz6L2TL0mJ0daQZiClyJpT
PxYU3zmgbA32D6wPsUyPpc5WdlgByTXkKMs5rwxHhnitwC87XJ9lZy63Fhk/
SxA872LJsudSrU7ZDktQyBqzYXljKUfFqQoL2Fqj58ByopRigdPKFTDQK3Nj
ed1cQkSxszkoB7kEsZxyRZdXl88cstZuf8ZyVEe/f2/OZfihWxzOsu/ZTrfV
ETOoF42IZ7nuSN/rAJopkOelclkuqRBJy1q+CC1R3AUsi9QdiGhRuggWpM4i
lufs1/0rmGMMI9sk3rOsMnVVMTH6AriE+jeyHNJTsqOq4zw8vZjcwvLa9zMC
w7zn4fZoShvLav6SUzJ+ZyH17MVPLA9yCzNPVZyBH3L8vSwHVM+2OK0Ywgo9
h8Fy6k+X7GJnA7h3JWbgz/ctCcX05pyGMYPxQZY17rx4tDpyCqQJqWGWD9VI
tgbQ9GHhnc4Plk+N9ma1KJ2Ap+8Vxln+cNY1QDBHF2Z8KRMsR5idO5YYrQ2b
Lc2nWG44E7ttmFcLet2+T/9Z/0TjooyfBlifPT/Lsi3bUKfTyjEonc6YY/kV
92h+sfNRYFwYmme5N7wneHUEQa3nmt8sJw86dwbQDsM9e75FlskafMGCOaqw
LE5a+rPfRk81E6OVQDOy648jLl7WSozeCX9uJ9Z6A2L1lG+nH/r//yT/BYIw
SjA=
       "]], LineBox[CompressedData["
1:eJw12Hc4le//AHAjezxGRh+FIi2UkZC8b7LTkiKjZEQIn4w+khKpKArJqCQZ
kUNkbyJ7Ze+RvbKyx+8+/a7v+eec1/U81znnvq/7vZ69pvY6FlQUFBRclBQU
5Pf/f7Gh/30KKU4t3t4mkB270H+vA6/DObpqWrLduxLkXwfaw2aTRv0mdtzA
ob4Z0l0wFRXl28B+TFulEhT4EPh5nCdWsbkG80Le5npB1juhU8vYIp6KaJr0
FN6Xn+BcxL7f8fyFYuRzEIxOsZ3FftSndvtl4EtwQQGaU9hRP56N25cEQG5i
a/wodteMWltIbhDMrz3yG8SeGRH/rzAtGCghaLEb+3lSQOkIKQS++TP2tWIn
qBWlscSFQTblmHYD9pcUJiXpyLewmd2CF0igJ+ynCI/AD8ArO5KQjR3qMxj5
sywSTp0xFknBrqZoWzEv+QjymQ/jIrAjbzm2PMv9BFz6R0ivsd/dstX5Jysa
aPkVZXyxKzYyH3xJiwH6grCfjuT9oh1vqSHFgcbvwWFLbIlggVWjhM+wuhB0
3xDbd1Qrbyo2HobkxaWVsI/w7ONkivwC/z7UrKHF9shRDlEOTIbn261rS1sE
upOjHmep/hV+MNYljmB31Pl+J5V9BdeS1fBSbJ6rsjJyJSkwJHA+8h72mfpb
ddq536BF99jETezAXPHVV3Jp0KfqnqmDfWBesqU5Mw1yQw27D2JffK8VZpiW
DvycUufrNwlUXj3LZ0HKhD1ibmmZ2DcGx8Njj2TBHZLE+w/YjEJluaPxWaBs
MLlyG9s80bHLKjYbrPnfdezA7lmeNLr5IRc29M4jvg0CJVsdyNEOKIQ6XW6p
1XUC7aM0LudgKYLR8+5BrdjTShJjDy4WwY18sfcvsUt532hc6SyCJbvDzWtr
BDqXxW5KOVUMZf5HGtNXCUSh2zmsTpRCtr1yhC82DRWrSPKlUhB32NFxDVvi
2EkG7tBScF94EUKDHTjy/tugYBmoBPyQ1V4hUC+LhstdyR9gdiSMuWCJQLeT
zn/0u1wBc1FlaT7YSp6mD2bCKmB0JaFKF1uQuW/iXG8FXGCKhvE/BJILlLjN
alkJlyetzzFhv2Sm/vP0vyrwkhGjkF7A57cjaNvsbQ2UHv4nj+c3gQ5pmmYb
OjQAG9V6fcsMPh88lG7oVQM48d8xD8L+LOuzJvy1AQK0DxAs2J/u6EtM/26A
b8tVNmtTBLq2Sudwz74RuDvHlfMnCNTqol/y1O4nHHzu4fBrmEAcbGbI2rYZ
uP9cDAvA7ruXVqH6ohnU3/cqA/YhHYZtwcRm8KsR5w0bIlBRR5Fj62Qz2HHU
V6v9IpByhIf9KZsWeMgnp+/bT6DfHexK67daQUzemkjtxPtRINckadkOmWvn
FXWwJaeNzc2etMO5CpaFuQ4CxZs7hQTFtMOnizwzR7HvFoUNzP9qB7Toezi2
jUCGnikriSYdwHRcqcCtmUD3PjlVshp0AuezZMPqWhxv+4O+emt3Q2qnt4YR
dprr9dB4m26onbHInaohkOwTMc5a325wZ9aSYsb+JjBXyFHZDdqGjTaqVQQ6
RtCNh6r2ACFhRPnxB4Gkj62yvVLshfqp4qqNAgKJOVyW5+Tth5bg7WJHbHMf
nr2/D/bDsP7moYl8HA/s0wVVcv1w8ZeydksegXbsi+J/ZNgPGwHyndE5OP58
Bi0mIvpBYoie/1AGgX4VSTYm7R8AGcSo9yORQHzbDHSbkoNgFygqohuKz7f/
5qUI7SFwdhSZSQ0hkP1UH4260RDoMC7KsWOf+ZZr+dtmCHI0dxrXBON8duGW
PDwfAlWm5EaFIAItTQ3s7KocAoUcLxdafwJFVDhbUasPQ19dQZGCF4G0K5u6
diqNgJ2Z6cxxWwJdDuD1FpMeg5WTXk+TpQj071mTVZLVFOzX71SzX2BFdT6F
SVVoFuzO3mUvSGZF6RzCqzP75+EBPQVpwZgVWYb3GtMeXYSJFTGuGgZWdNZN
RE6HbQnUO6O82L+yoLGArci2wWVIbODPyFBjQWeNliIDWlfhmBD/TooeZjTJ
szdaN2odrpvsa3M0ZUZhOwU0CL9NEH2lWCs7yIQkTObmA25ug+Zl6dNJZkzo
JrXJdbEXFGhfWMm1zZ+MaPPW0c7xO5RI9fFldW5VRkRxMqa6SZUKoaT5uR3R
DOh5hGaP2n5qpNDi3xi/RY+MaWazVNap0ekZuQe7r9GjPiVDm4H8Hcj3Yymd
UTwdEm8olz/6nAYJ7/a+8XCNFlXJEPk6qrTo3ORmxmNNWiRpzZd/e4kWLQ+U
8Hl40aDqYeFa/a90aK/w0UTFsh2I9Fi8vUWPHjGrPBrQnqNG0ek1QRG0DCj3
K43TJz5qVHPB30v6CwNavlKiG3CeCinF2O0/q8iIWNKo2lRvU6I3U0Ntca2M
qPys5qWXwRSIEJQdpbjGhKRUWzjl7m/DhfkY5z3dTOhBxUaEVOQmTFdzGbkY
MyM7L/HGoO51uKNlP7dRx4ze0Dt0XZ5chd2lxDMBZRZ0x90n7/zOFXASyZLh
iGVBe7UmTJPQErCh9Ng+ClYUwsV70gYWgUvqCaecIStaXNpZesJwHuwVShMa
4liRIK23ka3mLDiExfZoz7Mim8/pxVauU3CsyMQ7VxLHacWRUs0PY3BuwoiB
ypJAlBHjU0/8x2B02pSmGVv/W07Md/cxKNxUuRNjRSBr+YqKk0ZjEGfgH6Fm
TSAZ56lukV1jcO10HfK8TSDdiVMeY4Gj8G6r5nOvI4EUEl5U8T0ZASaP99NH
PHCc5p04dgnHwX+ecT48OC6uPGs2CjYcgqz5Fa4c7P6OANm2M0PAKVopbITj
alrGauuq6BCMTHVVRoQRSEjZsMpw+heEZT6W4H+H43JxV/gF+19QaZDjRPOR
QNyHpespHAdh6V5TtnMCgQzGha/KmQ2CgqtKAP0XnCerGML/vTQIR/xHJ8Kx
5zISlAakBsFqLEe4AMf1vmLho/mLA/BAWS91K4lAl9I7si1dBuA+t5OU1TcC
neV5pOrj2g/X+dgLunNxX1PHn09v3Q+PLOZVjHEeOe/IvvTUoB8y7OJ1erBz
NAYTvU/2w8vdAVTdOO980tO7tbHWB7G97GlNhQRyPXG1uJyqD/Z/lTFK/E6g
hjbBQFqOHrDkMkijqsZ5qZI7b2m+G1iYzDicsBuPPrk70tQNvUL0y0PYg6Vf
okuDuyF3h6BuGc6TqseZht12dcNCg56xRx2BWAvHLVoFu2Bj9m5CXyOBpgym
YhWPdkDYFSPh0+0EWm79qe3O0gFx6WrRJOwjF/d55k62g9o8ezAPzut2PIbv
ZT63g/qb05Xj2LFyNbEH9rZD0M5+t6ddBCoLd/b9w9EGEl7W9J97CXT66Ytc
lSVcdyZIqe647lhGxTq5NOO6JKt1phV7bluoIS61GaYLXumK4zqlgD47MNg3
w4wWd3Y3Nq+Js1XFaBPIZrRXSo4SKO8LX9bxjp+Q0zdNXzpOoIC5tO3G3AaQ
a3NeuIfr5guNvAiFdw3AuEduPA/bafX7Ruz9BugypzPdwuaqLlm+d6oBwteL
uh/iupx/gHYGHtSDfNaLpfuzBGIW+pcl/3EtXNH4mnN9Hq+H2e6Dr2otlH9P
7g/Dtg3tK9CjrQVFoS8+TdgmjZvxs09rIJIh0FwV132HSintPc+rYUSRXlFo
EX/f+YVQ04BK0B/pfFCO+4SM6sMuh3Qq4QmzVPMqdk+o9uxvjkr4M+CaeAT3
GRoVooVurytA61XDsB+2iYr9oH9IOfTs8XPTXibQwdSHPNHvy2DFIEoyFfcx
9Hr6JyyulUHzcf+MbuzkB4HUIgJlEOhknE+L+55IHYaY2MhSqPf7dOkqtsBx
zgPRn77DSkJe1Ar2pX/EKALii0Er7V2VAO67koU9bm2ZFwNj6Q4TVWwZti5P
G8FisKg1N7XGjnkTXKUSgvsyEcakVGyGHZIfRxkK4ed2m4kC7vM4rp7Nzvco
ANHmaWNj7D8joqpBy/kwEr5U7o4t8w9nicJwHtAm9Q7mYR+84RzsU5QDP1RW
paRx3xg6/eWV4YkcsFl4E3oB+3WVIadYUjbIyghZ22L/EaXKrnubBQZuNLpR
2IJ0FlXMdzPgIOmXMh3uY6Xu31Drmk6HxaAxVgFs+qEXxvHm6ZB1tV1dBlv7
0RlLFZ00KOhwoTDDnqGzEHMRS4WO6OgX6dhVfK3lStEpsHLrT2EF9kNZUXYW
vhSYpBQ36cLeSjPNiaL/CvZXLo9uYRNXbyh2biVBvP3pOgL37aQsd1e7KRIw
c/HuE8TWVJ3RCy7/AimdjmyAfTpjD83B9AQosF1LOIvtJ/D4RE5UPPjZ3Uwl
zwXDbonQ4x4HPCXTdC7YQaWaAnY2sVAcTn/FkzyHfG0O2dKPAcY5OnZ/bDYp
a0t+6U9gpvSt9hP2gNiFCtLeKPBuu1ZPwi543dmiQHwEK6GZU5nYb07OHApZ
/QDJqya7irD3Uh7gSmt+D58kMm9UYLdPyt9tSH4L4jGz3OS5acKexmDKNwwG
jrHItWHXU5uW090MgblvzBU92PyCopX7lILhBNvv77+w9QBundodBMcOp4mO
Yxf3uKToLb+CrTFDqhlss3kjvV/RfmApM6Iyj9281+s7t6EPtGzpLP7BLtHi
ydVk9wZ9iSg28hx5wqHh4v1yD/hY2BS2jj0tVi1jvP4fMESMviTPobq+fHrF
lg7w/HvP/Ba2rKvIpX0iDgDUMutklzShCNpKeyBF2FKT59jx2VI/3xI7SB9z
4iQ73OisTWC6LdypnJMgmzLW1FRX0hbmRhTkyC7SMbjKnWwDB01uIrLFeufV
wj9bQ4mF7jmy2RbbBKPeWsHH/HdWZD89SvCY81rBaFanHdlC/GIsIsGWMEIs
O5GdtltgNd7/JhCNVR5/72+dqE95ZA70kb1vyL7vebPMccsMuFyJd2TflKjN
Oe5mBp0k/o9kr30wjsl2MgW/w+0Jf+9fDnMttjSBdw6ZeWQXC69201Zeh9sH
uorIZqF4/8O35Bosy/WUkr2R8TgsMN0IpO7cr/n7+zlVntzJhjASsquBbLNv
Czbhnw1AZ1dwE9k9r+dPRb3VB52jBzr/Xo+pEhEJ1oPR76d6yKZb9yES/K+A
dJpk/9/nBN4l/SmPdGE5LnOY7OPzpyqPu10Cuy/qY2R3/opOyXbSgXeMGRNk
5wbLeRZbXgChbrHff83X1Oxbcg7unTsxR/bdYI6YwHRt8N0tsEB2AIW0c/hn
LdBRG14ke9ZcTjXqrQY0VfsskX2vSpgrwV8NmEnMK2Tzhq0MpTxSgc3x26tk
J7dnpGU7KUOcJ2mN7AMBNx4XWyKgv1u9TjaJl0k96q0s/LkTtfn3/wRN4uvH
oIR8vLAbhVi9iy0F4V/ydpPXb7RTSiQ2ReF/z1H+DyG4TJA=
       "]], 
      LineBox[CompressedData["
1:eJw12Hk4ldv3AHCSeTq8iZCkEpcmuaZi7UpFJN1cSpkzKxm6lKQylCJjinQN
KfM8ZJ6nKMTJeCLzEDLL2G+/9/d8zz/nfJ5znufda79nrb3Wu9vU/i/zLXR0
dHz0dHTk+/+/tqH/fdrM5+76/ZtAwxN8jZFFZhA0pHKd9MGPSXGRRU5w38s/
ZhObR38hzCbcHUperwVuYPOqbrJFFnmC00FfmXXsCMEU90dJT2D+hJzPKnaG
mFagVbg/VNK2+P3Cnrbs4N+vGgShTD9PLWFnamjGhReFwLn61dR57HO/JgbZ
j4bBopR4wwx2cJLAZ/ekV9Bx3OHVFHZStJLuz92vwYSZJjBBrk8w77Zx+Bs4
HG6hMYL9h/SvQCuWaNhGz3N4AJv9QnyCqGoMqITW4AAJtPCHD2tg0VvgHmxm
o2JvSgmpn12OA6YLqx+aSJdzyG/KvAev1nSJKmwW1RY226QE4OQ/NlmMzeDF
PCo6kgjVrSMmedira+aG7buToWZ7tFkCtrCaGTsKTwX/r6k/o7Hd71rKL1DT
4J4r7UA4dl5L2uIllgxoGoosf4LtprX4g0k1E+J/psJ17MAc33+ti7Lhg1Ht
NX1srsQdQSeu5EBxLZ20NnbAoxuyO5ZzwG8H7bsStoF9rWedTB5MOx2J48AW
ObV1i2hSPjD+afgXHfY/NnflF88WQLJGWtb8Jt7vNA+2huECuA0Fvl3Y71Tf
eDjuLoL5Hx5BMdgFm5Ompa9KQGb9U0sw9op+3IlAuVKw5IBKT+xPtnlJJtRS
sBYIKbqOXaoh4UvPUg5bQuhZ9mBP3CVWo05VwGbYEZagDQLdiLm80FxYBfSL
U2Vu2DYnZO/oUaph5uJBYQtsq2Dl2F7zajAIO16piL34b1H3D0oN6HtHVNPW
CWQqHlZIb1kLxxSLYnmw6ca1+3YQH4HqPR67tEYgn0dBPyOsPsLO2tizPdjK
677PhEo/wkGB/PtvseWMvY2FrBugQfDe20PYujzdl/jKGkGkqK9ObhXf34i3
rLM2TdDhvUbZjv1FbG2nTXkTBPYkbS6sEEiiOezdAF8z8D6urcvErltyZ2kt
bwa+ti08+7G7Rnev6DxrAd6Twg/ofhGI0arYQ6T/CxTqB369uUggp57CeEc/
KpzrX485jX3NoCJcO4cKLJfqRISxW32kFA/SqNAT4CpZv0AgzYA09zGpr9DS
begpjJ23zMpxpfEraEm0qufNEcgvdDpLkq0DVnS1xdN+Emg71a3F63EXHFRs
+30X+2V4v5JeehdoijX6nsXOft+oItnRBZ2wM71vmkCHKZmUT+Ld4G1rAhzY
rTXGjRy13XAoc4+L7iSBbLV1ee5upcG167Hq6WN4Pw6wPPn9oBey1mctnLDv
W91WXo/vhSNvxuTlsdvcL7r/auoFppCmhZJRAr04TBfxU7gPEjrDuutGCDQ3
8E2uM78P9leM6X4eIpD0yJiyuut34Mg9vyPqO4Gilq8+b0vvh/SES6lXsCkp
x36rV/UDyt21SGAPOq1Llbf3Q9NZrujHfQRqyV76kLzRD5QuUzPbXrwe67gg
D40BSPy3K3ovjUCipa/ZBEcHgF62YNOgg0AKnyZYBESG4F0JXGHBLrE1GP/j
6BAE6KnoZ7UTyOHvhJvKakNANCVeYMT2TjpnYeI4BCqvr7PEUwnUJHX1d1zt
EEQ9r8nq+oLz28HDW9B+GMSsLJbWGgk0cP+TWnHZCHj39LyULcP1aXZ9rMZo
HCRZOqnNpQR6NqpXd9lpHJx8FKptsEWik0788BmHbWnShVEluF69Y2DlThsH
dktOBqZiAslaCXZfXB8HCx1etup8AtUqhZysfjUBGidcfjFm4f0qqufV//ID
9t3fyIl5i6+XaziicGIa3Bizcs4/IJDlYVqRXcUs8Luo+e27TKCTdvb6G9oL
YB440dB+AOcT/40PNulLcIFRVDN/lRfRn9BdrFNageCi4/67anmRqOCtOovQ
NbCrPz3H9pwXmcqp+Pr3bIDdybYjMpq8KGMlfKuQOB3a/BrMIcrGi+bTQkec
T9OjY/duWzwp4UHf7Qh/SdctSFjw7AOzGzxoF61dXiiaAWnl0k1oivAgtFXh
g0L6VpQbpXi1t4qC7qkWacc1M6JkxxeTB2wpqNz3ealaBxMaS5Hn92SioINM
kaGvppnRs6dzp3VUuFEOk/Qo3yoLolrXv3l7mwvp8crUXpliRZMfc1mzQziR
UvUd1rUpNnTAbERxVwEHurf1kl18OzsSsygZGu5hR6WqptKsORzodkS2mPEQ
G1LZdZPOPpITSU4p6T1fYkWd+5S0Gm9wIe4X/Tuip1gQ52CZwhk1bjQhzHzR
b4AZPZhTaKVjp6DcybnE24NMSH2/ufyMBQVRTKo0X9Yzol7i54hELQUpxghJ
zBduRazbPAPLBXHcGuYpb1MZkOOHx9bB1jzowobBKVGvLcg5yn/FupAH7eMt
MaVZ06PHz4e3G9LzIkNG8US+o3QouJs195I6L2qiJSeb7dgEFoGjpo2PeVEi
LW6tq2UN2NSO1D8r50Ubgr2sZy6swFTf0RSGFV6UKSuYyzi3BDXvCm0GJAiU
cPa9U93VBRjZ9YTtlh6BTvny3OlvnAUR12tHcz0I5Fgo96dw3TQ48HafNokm
0EPGvQkSWdOQQTXwHMI+aCwZIPtmGl6K2FpaxhBoq/pq4TmnaUj4JbDHLpZA
XsH7Q2/tmgahiQdWDnEEGr9+PjrWZQrEdj2QtE0gUCP1UEns/klgvvXIWSiD
QCeST6/vx3nwLJMl7ybOC7sk1py7juOQ/bLoPBX7snYe02fDcfAr2ghTxHmV
oLrl/i35caA4S6owlBMohXeuOGtsDMrn5nqDK3BeOkaX79UYg1LXBau31QSK
lKVnqOAehW7pvaG+DbgP2XMznXl9BGobG/SHsV8q+9FpjY1AT35LK8J5nHqd
L7irfAROfFloX8K2mZ26O+kwAgG+/xwy+oyvL6adQE8dBq7nEqK7W3CdMegP
+/FyCIQyG5asvxJI6JHF5FOvIXDw4NcoxN7T8mJe0mEIZIYTL7HhujLWLShg
eW4IujIjHiZi14a1V3xbHwQJqWfaQ7gupVR2dBabDAL/wdgCjW5cV3x0hFSl
BsD4fH5GP65zscrP/+zmH4CxEfdnErgODn7LZru1dQBst5sL2mNzXv0xEvGt
Hxa3hOqsYWvQ77efCuiHVwO6SpR+AlnzZ/32XvgO/y49bZAaJFC8Q7w2l1sf
iOYVLEniup3rxxxN0+6DJ0dSfOyw/xlOMk0S7wM7eamSNOxz3zJVVVt7YVK5
YacMrvsUNY9AB8leoHHYpcqO49/TE1NZHTT4HXSSUfIHgbYl2k98PdoNr7JS
AprwOUOv0cITytoN0mZcPxnxuTT1W7r6Yl8X6Lh0LxzH1tBu/dT4tAu+TqfO
J2KL5Ac/KuzvhEGH/aUeMwRKDhMT9wzoAGpyqLcgPgcXD8R61E5Qweu9ZCcH
PkfT9W1rNaqoIJ5VxSOH/WV5oajlNRVYo1Q3DLG73bNzuzSpgN78Gk/Hbu+s
WhhNa4O98/yCWkv4/uRaSCw5toLcgTSq2zKB1uri3v6j0QrXum9IR2Orlml0
LO1pBeYlNrlqbFqsis0S9QtsPdNjyI7P/RGD6Atzcl9Ae38NUxh2s9hhKFps
huVmtfRI3CfE3c9ty37fDNTRqL3F2NvKjCaT9ZpB8cAnjR5s/dXltIiCJjio
H5sugPsQVz72147unyFJRuFzAHbWv0Y7ORkbocf1nZE97mMa7A56b+Y2QFy/
wJwv9lURF6+fFg3QY6UvF4etFq+h1VL/EWIUzlA7sC23dB7296uHnolc82O4
jxozVkCLRC2kzcT0zmP3HPjOoFJaAz6rW66x4z5MlRpk5mNVA0Z0Hu5i2Frr
Sht8JdWgf7k25QK2z8my6sMWVTD426f4HXayXkvIP5QqiIzL0S/EvkI5zl5c
WAktoquRTdimMxorp7kroVq6kXMJu+Ca9cbf+eWw3uAWjXDf6OFsqxRuWg57
Lhsa/YUdabhDmsZRDoP0upVm2DL5Jy0rK0tB4Ianszf2mNrmevO2YlDUbPKt
xkY9K/x/WReB67WL1m3YbDtnctpKCoFQGJ3sx44yEXn41aIA+NXOfd8g+1T1
0vy2/DxgGR1xOYL75OLYRsW/OPPgmOmKizJ21BmXv1tMcuFohbCwOraK6ZpV
I1sOMOq+0DbCTuxYt1AzyoaGfRPfrbHtQqbZa7KzQILzAp8zttaPBd2Sa5mQ
bqVm8xh7IkiGQTEzA5Y9aU8DsfNDskxzGDNAgPHBBXIu6I14GaBjkApa4QvV
ieT3fwrHqzOlQIFxze1M7HraR2WV9CR4vxTXkI9NLVOlF6dPgF6WQONa7CuK
15V2JL2H7DOvYz6Rc5biRXaOS+9gd3uOTyu5/mHZu5trb4EzksbdiZ1rrOA/
ExcLTB68yt+wLdu8zg2cjwFlS10ucm4aavS5FT8VBf4qCZ7kXFXlpVTgC2/A
ZYb5DTl3iUu4uNkGRYCYzW39aewD3AFVmoMvwTBipmgW+8gL6psDf76AKIc7
FQvY9/kjtnM9Dga6AW7bZWz1CTNnWmYAnO7Lzl/Bdtz5TTLy76fQYWietIZ9
2k/V4uqKF9To7UXknGm14u4lq+QBtZUzd8g5dNxuICXzoTPIRzTokXOqD//M
aNIhZ2CupDcgfcVrTCzumxNID+4xJR28/fWrMEUncOCRtCP9/QrF023WAUZ3
ynuQroh3L3GOcgA9Sq0n6XynzuUb5x1gxzo8IU1r0LMzTrwF4WULgaS3zXIm
Pq28Cd5LJjGkrddahd1FbkJgtto70inmroH2d2/AjLVgIun+QQsXHRk7SKy8
n0Fa0m/4lEisNTDu1SglLbSnPI+yaQWpyb4VpMvdH0gy6FtBgnR2NelfzLlc
YzyW8EqwroH01dt0nZkPr4Pp+7mvpFfyhM7FfTODuF9POkmziIoVhymagZIq
Ww9pw7m5KLdZEzCu+9xHOjSnlOfmeROY2eQeIC2i7eppnGgMbYeUh/6LT8n+
89NKQwhxvzxGuljLPcP+rgHcijgzQfrjHbsQHZlrEJ2xa/K//RGfvywSewVW
64N/kq686X+MQf8y7GuUniXdIswlMsajB7G1mXOk/1irG8h8qANhifcWSf89
y1ATpngJOIIql0jbvJGKd5u9CO0O88v/xfsA+RonasO8BvcKaenSx+1PK7Xg
+q7tq6QFNm5E6MhogsQk89p/8ZbJGYrEqoNK1tB/7nk+tHuM5ywkOKSsk3ZY
vDOc+VAVzP8w2iDd2fu582mlCnQ99t4kneQqPpL5UBbCyb8Xdk3KRey9EE9u
NzarU1dZOnfe8f89R/k/PkZg0Q==
       "]], LineBox[CompressedData["
1:eJw12Hk8VOv/AHApTEl2h3IrFG0KXbKkz6OskYo2t9JGStlJ0YKrLIkW15p9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       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHASkmSIY9jmWRlL3VS37yJjXGVoQCmipAF1dU0XJfOYzFOS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       "]], LineBox[CompressedData["
1:eJw12Hc8Vf//AHBURsgeRfco0kIZCeH1JiOlJUVGH6GIwscqodCkUkiiksyM
S/YWIjPjY2WPbNe6ttDvffs9vvefe5+Pe+6597zv+7XOLnN7vWsMdHR0AvR0
dLTn/3+IoP+9CilJK/nzh0B2XKJ3XgfawxmmGkaaPTsTlF4H3of1phP169hx
/ft7p8hPwFxCQmgN+yFjtUZQ4EsgCbiMr2DzDRSEvMsPgpz3oipL2OI+qmiS
HAIfKo7yzGN7tD97rhrxDkSiU2/OYHv3at16GfgRXFGADgU78vvTMfvST5Cf
1Bo/gt05pdUWkh8F1FXvFwPYU8NSd75mxAA9BM13YT9LDigbJsdBuv/W3lbs
BK3iDPa4eMilH9VtwE5MZVWTi0iE9dwWfIEEesylwuEVmAKCCsMJudhvfQci
/iv/AiqnTMVTsWvo2pYtS1NBKft+XDh2xA2nlqf56cBneJD8Gvv9jZt6O3Iy
gJGkKu+HXbmWfS8xIxOYi0L/c6KtF+NYSy05G05MDwxZYUsHEysmCTmwMhfk
YYztN3KygBKbC4NKUnJq2AcFdvOwRuTDv/d1ahmxvfLUQ9QDv8KzP62rixsE
cszTjrPSLobvW+uShrHb6/y+kcuLwa10JawMW+CygrxiaQkMEmcj7mKfqr9R
p5v/DVr0D49fxw7Ml1p5pVgGvZqe2XrYe6kyLc3ZZZD/1rhrH/b5DydDjTPK
gcQje7Z+nUAVNTNC18gVsFPSPSMb++rAWFjswUpwJEt/+Ii9VbQ8fyS+EtSN
JpZvYVsmOXVax1aBDel9+2bs7qUJk+sfa2DN4CwSWiNQivXePN2AeqjT55dd
+U2g3fSmFdzsDTBy1jOoFXtSTXr03vkGuFoo+eEldpngmxOXOhpg0e5A8+oq
gc7kcJnTUxqh3P9gY+YKgej0O4a0OZoh11493A97C8M28ZQLzSDlsLn9Crb0
4WMs/G+bwXPuecgW7MDhD+kDIi2gEfBdQXeZQD3sJ1xvy7SCxcFQtqJFAt1K
PvvpxcWfMBtZnuGLreZjfm8q9CeMLCdU62OLsPWOn+n5CedYo2FsgUCKgdK3
tlm1w8UJmzOs2C/ZNi08udMBD+Ql6eTm8P5tD/pj8a4Lyg7sKBCYJtB+HfNc
Y4c+4GT4Xd8yhfeHAL07etUHziRHyyDszwq+q2Jf+iBAdy8HO3aUo6H05HQf
pC9V265SCHRlhcnhrn0/8HeMqReOE6jV1bD0id0A7Hvm5fBriEDcnBbI5uYg
8C+cDw3A7r2bUan5fBC0P/SoA/Z+PZY/IkmD8KJWSjB0kEDF7cVOrRODYMdd
X6P1i0Dq4V72KrZDcF9I0dCvj0DT7Vxqv28Mg6SSDUdaB16PIsUmGatRyF49
q6qHLTNpamnxeBTOVLLPzbYTKN7SOSQoZhSizgtMHcK+XRzaT/01Cmje70Bs
G4GMfVKXk8zGgPWIWpF7M4HuRjlXbTMaB56nKcY1P3C87Qn68kiXAmkdj06Y
YGe4/fM23pYCP6au5VNqCaTwWJLnhx8FPNlOyrJhpxOzX7mrKKBr3GirWU2g
wxxMY281J4FD2oT+03cCyR1e4XylOgX1lJLqtSICSTpcVOIRnIGW4D8lTtiW
vgK7pvfNwJDh+v7xQhwPXJNF1YozcP6Xum5LAYE2744keRvPwFqAUkd0Ho4/
34Fr4+EzID3ITNqfRaBfxTKNyXtmQR5tNfieRCChPyxM6zJUsAuUENd/i/e3
//qFcN15cHESn0oLIZA9pXeLtsk86G2dV+TCPpWebzVtOw95OrymtcE4n527
oQTP5kGTNaVROYhAi5R+3s6qeVDOe+DK6E+g8EoX603aC9BbV1Ss/IBAulVN
nbxqi2BnYT515CaBLgYIPpKUW4blYw+epMgS6N/TZitk6zXYY9ihZT9HQnW+
X5OrER2yO32bqyiFhDK5xVam9jCge8x05DlTErIK6zFlPLQZjS9L8tWykNBp
d3FFPU5GpN0R+YDry040GrAR0TbAhJIaSFlZWjvRaZPFiIBWFnRYlMRL1y2M
JgR2RetHsqJ/zHa3OZkLo1Be4gTHC3Yk8Ur1h8KAEJI2m6UGXOdAOhfljidb
CKHrm8z+kXzOiXaHll5Z/28HWr9xqGPMkQtpPryoza+5A9Edi6lp0uRGKJk6
uzl6O3oWrtOttYcHKbf4N8ZvCCLTLTM5Gr950PEpxXvCVwRRr5qxbX8hL/L7
VMZkEi+ApBoqlA4940Niwo+u3l/lR9XyHIV6mvzozMR61kMdfiRjI1R4a5Ef
LfWXCnk94EM1Q2I/DL8IoF1ih5JUy3kR+aHUzxYDQcSm4d2vO8uDojNrg8IZ
t6P8L1uco4R4UO05/wdyidvR0qVS/YCz3Egtxm7PadUdiD2DoU3zFhd6Qxls
i2vdgSpO61x4GcyJOEQURuiuCCFZzRYeRQ8OdI4a47KzSwjdq1wLl41gR5M1
fCaupsLI7oFUY1AXK3I8aT+7VieM3jA7dF6cYEHCZRxPCfWdyNHTt+AsLzNy
Fs+R547diXadHDdPRoyIE2XG9tKRUAif4DFb2Iz4ZB/zKBqT0Pwib9lRYwZk
r1yW0BBHQiKMj0xu6tAhh9DYbl0qCdl+ziyxdluDw8Vmj/JlcJxWHizT+bgM
Z8ZNWBisCEQfPkZ57L8MI5PmW5qxDdPzYr55LsPXdQ3HGGsC2ShVVh4zWYY4
I/9wLRsCybtQusS3L8OV43XI5xaB9MdVvEYDl+D9Ru3nHicCKSc8rxZ6vAis
Xh8mD3rhOC04evgCjoM7PnG+AjguLj1tNgk2nocc6jJfHnZfe4BC26l54JGo
EjPBcTUpb71xWWIehimdVeGhBBJVN642npyD0OyH0qT3OC7nt4eds5+DKqM8
5y2fCMR/QK6ezokKi3ebcl0SCGQ0JnZZ0YIKym4aAcyJOE9Ws4T9e4EKB/1H
xsOwZ7MS1PplqWA9midWhON6d4nYocL5WbinbpC2kUygC5ntuVaus+DB7yxr
nU6g0wLemr5uM/CPEFdRVz7ua+pIhcw2M+B9japhivPIWSeuxSdGM5BlF6/X
jZ13YiDp0bEZeCkcwNCF806UgcGNtdVpiO3hymj6SiC3o5dLKhimYc8XeZOk
bwRqaBMJZOSeBCs+owyGGpyXqvgLFqkUYGe14HbGbjz0+PZwEwV6RJmXBrEH
yhKjy4IpkL9ZRL8c50nNI6xD7tspMNdgYOpVR6BtX8eutYpMwNrM7YTeRgJR
jCixqofGIPSSidjxnwRaav1P15N9DOIytaLJ2AfP7/bJnxgFLSpXsADO63YC
xh/kP4+C9pvjVWPYsYq1sXt3jUIQb5/7k04ClYe5+C1wj4D0Axvmzz0EOv7k
eb7GIq474+Q0T1x3rCJjnV2bcV1SOHmqFXv2j2hDXNogTBa90pfCdUoZfXZg
sR+EqZP8uV3YgmYu1pUjv0Ah62eVzAiBChKFco60D0Be7yRz2RiBAmYz/jTm
94Fim8vcXVw3n58oCFd+3wdbdyqOFWA7r3xbi/Xog05LJvMNbL6a0qW7Kn0Q
9ru46z6uy4V7GafgXi8o5Txf9JghEJvov+yFD7vh0okvef9Q8fWw2X300+yG
im8pfaHYN9/2FhkwdoOqaKJvE7ZZ43r8zJMuiGAJtNTEdd+hSlZ357NOGFZl
VhWdx+c7O/fWPKAdDIc77lXgPiGr5oDrfr12eMwm27yC3f1Wd2aaux0W+t2S
DuI+40SlxFf31z/h5KuGoRfYZhr2A/4hbdC984W77hKB9qXdF4j+0ALLRpEy
abiPYTYwPHrtSgs0H/HP6sJOuRe4SZxogUBn00JG3PdE6LHExEY0Q/2LqAuX
sYkjPHujo5pgOaEgchn7wg5JuoD4RjiZ8b6awH1XipjXjQ3LRthattlME1ue
s9PHVqQRrv2wNLfBjnkTXK0Rgvsy8a3Jadgsm2U+jbDUw39/2syUcZ/Hffl0
bqFXHUg0T5qaYi8MS2gGLf2A4bDFCk9s+R08pcpDtcCY3DNQgL3vqkuwb3E1
fNdYkZXDfePbycRXxkerwXbuzdtz2K+rjXkkk6tAQV7U5ib2ggRDbt27SjBy
36IfiS3CdK2a7fZ32Ef+pc6E+1hZj6tanZPlMB80uo3AZh58bhpvWQ45l39q
y2Prep+y0tArg6J2VzoL7Cmma5KukqXQHh39PBO7Wqi1Qi26BJZvLHytxL6v
IMHFLlQCE/RSZp3YGxnmeZHMxWB/6eLIBjbH5auqHRtFEG9/vI4D9+3kHE83
O0ohsPEJ7hbB1tGcMgiuyIfUDidOwD6etXPLvsw8KLq5mnAa+wXx8GheZC68
sLueRpsLhtyToNszGwRKJ5lcsYPKdAg72ywoCWO+5EObQ740h2wYZsLWWSYu
f2xOWRsrklw6WKil/4jC7pc8V0nelQaP2q7Uk7GLXne0KHOkgrXolEo29ptj
U/tDVlIgZcVsezH2Lvq9fBnNZIiSzr5aif1zQul2Q0oiSMXM8NPmpnH7LUYU
v3joP8yu2IZdv8m8gul6HMyms1V2Y5NEJKp2q8XAUc7pb7+wDQBuqAhHweED
GRJj2CXdrqkGSxGwMWrMMIVtQTUx+BX9AazkhzWo2M27HnzjNw6Flg29+QXs
0pMC+TpcwWAoHclJmyOPOjSc96h4BZ++NoX+xp6UrJE3/f0UWMJHXtLmUH0/
IYMSKy949q2buoGt4CZ+Ybe4F8Am+d80lzahcMaq+0AOv7mJNseOzZS98Cu9
B5mjzjw0h5mctg3M9ADHqllpmuljzc31ZTxgdlhZkeZiPaPL/CnusM/sOqJZ
soeqFfb5LpRe0z9DM+d8m0jkuzvwqfC9Nc1PDnEIWAregZGcDjuaRUmS7OLB
t2GYY8mZ5gxhYiXe3xU4Gqu9/h7fOl6f6u0MzBE9b2j28Lle7rThBHxuHO9p
vi79I++IuxN0kEmfaF79aBqT6+wILw78TPh7/FKoW4mVA7x3yC6guURspYux
yh5u7e0sppmd7sN3v1I7WFLsLqN5LethaGDmTZB19Kj9+/151T78KbYwHLK9
gWaL9DnbsM82oLc9uInm7tdUlch31qB3aG/H3/djqsXFg61g5JtKN81Mv305
Evyvg1yGTN/f+wSPSvtSvS1hKS57iOYjVJWqI+4WYJeoPUpzx6/o1Fxnc3i/
NWuc5vxgRZ8SKzMQ7ZKc/muhpma/0itw98zRWZpvB3PHBGaagJ8wMUdzAJ2c
S9hnI9DTGpqnecZSUTPynSE01fgu0ny3Wowvwf8SsJHZlmkWDF0eTPXWh/Wx
Wys0p/zMysh11oM4H/IqzXsDrj4ssToHzLdrftNcz7sYF5ipC7srKtZoJguy
ake+OwELjpHrNGerMA6nemvA/bvGG39/b9AE/jyCUtr2w24U3faoxOow/Ev7
O2jrY8IrKx5bovy/+yz/B0ijbtM=
       "]], LineBox[CompressedData["
1:eJw12Hk4VdvfAHDVSYakY57ZLoW4RUoR34VISokKxb2IJheRIZSha0hJSSTk
0knJcGXILMMRQoRCSIY4pgzHPPaufd/nd/455/M853nW3muv77QJW2cT+40s
LCyCG1hYyO///0ij//0aDJvt/vWLQI2FkX9fr3QBMdWW66Q9RFlsrlcGgNZC
TNU6drc4d3E67S4sdBg0rWGn0rLaXCsjYMO3vshVbHPfXA7uvdEgx2bHs4Lt
YKI/nEqLBQPrJsMl7PTT4n/o8/0DJuO/aS5gF37zzLhWmQQ6uTYjs+R63wuH
SpdpIF9x5yQTO69hdwvH3pcgJ/7UeRK7ga56ycwhBVxaHx0dx7b88dszGi0V
9Kbcvw1j+500d5jsSodFf51dg9i9O5U+qPNlQsKBGHyDBOqyeMR2uTILwv2I
ax3Y9Z3rs2E92WDi/Ti5FftH7/STrOUcoLaraX3A/txGTC2p5EGYzeUkOvan
+cJ48ZP5MDB1+10pts1q+ARyKIAf3h47srCNdr68FkwrgpiXJ11SsdtDdGNS
yorh0EFeDxq2z+HPpnVdJSC14VzGY+zt54Ldt/KVwRuzEbzhBBq+w++uV1kB
7yaFfl7FLs/aE3/auBK4h/ZW2GDnyq36XOipBLtbik9OYKvb/bL0X6bDVIDi
sgy2Krva5TyVaijYXTwgjE2JPC1EL68GI8/9Iduw/zL+6tx0ogZGgmZW5tcJ
tDJ1fSvjai1UFIXFV2GjQacyKq0OrI8GncnHzpA44iSqXA8Ppx1qX2M71Gjm
yJTVw3tbSvd97Cmif35fVwOINV8qMsH+6hEqZ8rbBL5Jiqeb1gjUr5AnV1zR
DLkPShRLsPWTDKTebmsB5s357BTsXVfV3v97vgVCiq7U+mN3d6VQk+Za4GqP
maAStvmkaXiA/Gc46Z+i57FKIP+EqP49EW3Q8cfmJSts/comDtmeNhDx4zmn
h60WbVsntKsd5g1Alhfbjkbl+FXVDnlZk99TVwgUy021r17sgMtyAoy6ZQJp
vPA6A9ZdkLIr0z0DO7Tl9xOKGV2wUZEl+wH2i5/qtULLXWCl37DXFNu/ql19
KrIbrGXELNuWCEQ40WZiar5BqpMw+riI90eBDpcFe2FbQaPFrXkCnXgUvueS
bz/IK68dNsd2VLe5a/C8Hwhl/2EV7NI/O5/KV/cDj2iwOWOOQAv+f7ePcg3A
mV3Pu49j311ke3fl2QCk36W5c8wSKCuIVmRe8gP0TxhMnpwmEJ+r852FpSHo
FtYaIrA1OOoDGsUZcOPAs6iZKQI53RyVSNZmALdprHg09uLsAZ1ToQz4w/tF
S/skgTiyr4knCw2Dp2Ris9EEgZT4VV+rq41AYXmaHGWMQOzziUrCbmOwZW2r
buMogTpSRz7tfjIG6eX5QjHYWtO2HPpFYzAu/nNOATt4sUHThWUc7OQnPI1G
CPQyu+ZJZdg4tGVQ4oIYBBpRoz03Tv4J90oeXagcIFDg3eSLAm2TQDlWP/w3
9uhlh3qJpUkwPXtFXg/bP+7DOd5tU8D66mt3dT+BviQt3BNRnoLz9OStNX0E
urfIu2mH5xTEdNEfFn0nkPiuMHblTdOgys+l4tRFoL0SiUn8okwwqJIUJ7Af
eqtv5vqdCRtuJ+S3dhLoeE6dAEWbCT3/DC6rYR++6KEzfZEJEszyotUOAiV2
JmTXZDPBkmVQyrONQL+ELNLsDGdAomru4e5mAq1rjb2y9JqFP3i8zmS+J9AQ
3JJQaZsHZuJc8mnstZG4oSbGPDTqPX2zVIXjVz7ntOPSPHhdOT+rg73VJ494
JbYAZh7MfS2VBIpS8PUUuLAAlUKpzwfKCJQdEPhlYHIBrE47KLYU4vyoc8JT
jX0JJswEz/ak4/2hFe/LUV+BkuaDJTz3CSRpFlZAn/sFUc2dTyYuE4jN5wnl
h8FGFC7aOtKpg9eLMuhIv0pBNRRj6lc+fD2OsfKMXFZE6R6pvz0ohfINj/lb
trCh2ljOTvYcKSRrJxGl8p0D2Zxxqa72lELtO/m/XKByofoZY07jQ1JoWD35
wD8C3MghndWkckISRftExJj/sx2p2A4N+f0hicSqXwllv6Yi5vdYTplPEqh1
03HOnGc8SH88lsNKSQJpmrnzH0niRY2qaHvhfXFk3S+sFx7Oh9goyg+DOsSQ
ZQuzYDKUH/3ILOf0kxBD7KzbjDO8BRCn4oZtvVdEkWhqdcyzM4KoeF/pnZAE
EaRaJyUddUgIpZS9NWr6Koxo4ll8a1zCqCDlm9FbHmF0o/2dm8YXYbRfS0Ny
aq8QCrz9YejCSxGUzPY2YMhKEOmeUY38ZCuKwv/KuuXhLIDMj+tfdN0phlou
BvcL+vGjIREWvrheMdSWdM7v76d8aMRLrE4gWBw94BiImIjlRfJ3+1puKksg
f89sTe0UHkSVkaRUfJBAP+d3iva+paLYN+dkkswkUc0eJ3bx1O3IIShmp+yI
JOo2PX1shzk36n3aeMRJVQq9Zu+JLpfjQsY9d0qU3aWQVIZI7lcBTpQUVaN1
NUMK2Uce2V3Fxo7YZ99/vNUrhQyFfJ6b17CikpsrIsa8BGqJelKS8JKC1m22
Wdtr4br2kn/4qclGdDIv49AxfC5Kfp8fN6SwING/WH1Cwwh0UTtrVSVnBRp0
D8tOvyZQRXNwnVniCrQkb9G9lEogOruryM37K1DcqL/9G3a+dp82/dIKrPPs
KaxJI9C3TXcLjomtwOBmt8NPMwiU8ErvoV7QMhw4OaOllIXjHHp0v59dAtaY
lLdCBQQqytGKLl2cB7uDTpprOA5shJ3Z2HCc3GGzTDfHcSPG/0LS5Ms81Mtl
fc7BrtfcpzWYNQ/ab++dulJNoEupL3W3OMyD/qvOlU81uO7vtcpQ/zYH1NYU
amQdgSwyRUasK2ZBYS74QH8TgYKCjwYmZs6CSmBes+onnCcpxz5+fzYLiyAt
E4LdxNV7xcp7FoqkX88q4LjWt2D/cnrvLFziP3XYuQXH8RhflmryDLw8Ph0/
+hnXGXVlp6I7TLD/Z0Qh/SvOIymVn496MkHYotZjFrswqXW2w56J87Sf7yGc
V5ojfG3ndZiwPdGlop7MO4T2itLaNGhyGfIzcF5S3V1p+dBlGvjpPTPbewhk
76WS/du5KeBIdw1SxnmPp7nhQ6rBFKjlmRm6YA95a9CU1aZA6fFs3RvssoTE
eC2+KXi90eTX7zhvTsSl26TFT0KofYCq3A9cp+dfqkwHTkC450AT1xCBDIc+
+Ow4Mw55U9erknGeblN2nFfcPQ6/V19K78M2jrvIVGEfhyNCnbriOK9berO6
aJaOwR3K/oBI7K7y5LjjsmMQyfnvvpu4TkicqNI4PTcCDSPFgVo/cV0XWjfh
imLAZGtAbjCuO7keGrqbnRmQUmZxtwB70k+ubtWAAfYOEdyj2IcNShNGV4dg
x10xueO4joluDXSvsBsC/6HQiK1MvD+EpLOl6iB8/bhZz3cGn8cHaXC8tR+2
H2XKyeI6mtAcqVKV2Q9npfboGmI/v2HZrRHWD8VyMoLO2Ddkis8q6PVDyH3F
8Xzscx4Dc5vy+yBpZ6ah/gI+z7QHZqmxvfBGbtPXM7iO72ZkLIl79oJUj224
B3bpe6vzEaa90Kp7bS0au/p9wp+eW3vhquwjtnbsBJ2iOf/VHrCh/WgxxX3B
RAF1PJzeDY+I82oI9w1KslMvnG52A2e+ZYgl9tKusxNG+7pB5AEl4gb2KRse
Nc5XXaBwSq85E3tcsfSd/91OaLD22yyK+xbHFOdY81MdoGjqc+gH9oiNbo8y
RwccWc/csYod1Eip4qC3w6OIwDqy75m9mepVrNoOVb84QQebHjeXJiTUBopS
d7visJ+VqkjRe1rx9S/2aeM+S0/+zf6EiFbQ/3cjqxm2puv+mRuHWyE0x7zd
Adv76PAFpdQWGH07GPCY/L90uuEj92YY8vOa78MWua1RcFWuGSxqvgTOYo9q
j7TpdH0CIt+7nBX3he/eKSgx0ScY0H4GCthGXDK1sUKNkLn/kJUj9jGHio1H
fD/C+PDnM7ewh3Rr3jIHGsC/MWclDPuxq/RDg8x6uMCvezINm5KSdWFC7wNc
pCby/8AuTFPKjE6rhYOttjemsUP9tUK1qLVwI/vKnXVsj2nV2bDuavDp1Hkj
iPvg8RTqjMz1KiiKF5PUx9b9/omlroMO8ZzLY8bYD8pO5Thp0YGvT/jieewE
zkxqPnslJLBI2TpjC1UK0M85V0DTxOYfN7D78s/KrH8uh/Z7Sry3sZlc4xvv
oDKg7NL2isTmdKzY/JHzHez6pvgmjpxTaG6+1PYS2J1g8ZicC2w5nzNiHItA
qdTdLhtbdk1loOtAIXC12xkXkn2/ftNVCUoBRHs+HinDdvUyU30e+xZqP+f+
1oD9bO+5gAH7XNCwSK5qxj7LiLomo5wDozNfeNqxAzdEb7FfzQLXMP1t5BxE
mxo8llzzBsY5F/J6sU2PSgfXyWbCqCVjKzk3McT1B4+WpIOfg+D2Eeyjh0+U
15qkwgHZkHJy7pJ+cUr6yMgrkPTaLzGFrbPzksB7v2QoNpOVn8H2Kkx+pSNA
A+4c0745ci40kOkrS0+EWN8K/UXsbcEzcV7B8WCe6WSxjC2i6s10zXkClRrn
hck5UsuXo9uh9xHUi4YEk3NmWuSLb7UiYTBowEwk59CElfWAQrfbsF4af5mc
U/80uPdsSOE2tNqccCQt7kkp5O0LAG3hny6k/655N+loFABDldPepAUDz1tK
7/AH4w1CYaQrlv+dSCjwg2FtlYekhZ4FySzJ+IFA9MHHpGcONj/IWLsFml7c
8aQfMZl2Apk+kKbQkUr6Bv/002uiPrCR7fy/pBkVLY11Id4wvViXRdqQRfeA
n7UXxPC7FpA2Vx5mH6Z6AkX9WxXpBhNeLR1fDxDLra0hHdm+wzV+1B3qtZPq
SC+Zsnca091g8onwJ9J/7f+YUujmCua7d3aSzpA53s3b5wJK+j7/zfFbjAu4
nYxcIO5aSQ/piZfnPKR3XANNFtYB0h1UGdMlGWdwsd82SLpJ3rUwY80RtHo2
MUh7Md4ECWQ6QAJH3ihp7mXaWF3IVVB55zpO+rK6zyk/6ytgFSQ2QVqprVNs
mHoJfE6oTZO++cb+dvyoPTgZpzBJn/H/yjCm28GiPessadda/+xCN1v4XB86
T/ppWZ6gk5ENyIplLpDmdeu8Kb3DGrb5VyySpvl30jPWrCB8oXyJdHhE732B
zPPw6nbGMukPFz6Y+VlbgBkRskJaI/0JMUw1g4RWo1XS73OMxozpp8H36YY1
0sfpP3ML3Uxg1vX5f8518PaV3mEMm6z3rJOm+4w/EMg8BqnWaf/ZaXON9DD1
CDDceH+RVmENfVvopgP/HT/sY8OZ2Cqwh3wc2HcYHkujnfRD/3vP8n/yTnJt

       "]], LineBox[CompressedData["
1:eJw12HlYTO37APBCaaOFtGqZQ+qtLOlto+4HoUTy8hbRinaSeIukaCGiVZRo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       "]], LineBox[CompressedData["
1:eJw12Hc8lf/7B3C7kmSUEdl34tMy0kfF9dagJGVUyEoRkRmlbBnZZZSQLUKl
bDKzskdIZoqsjCN7/N735/f4nn/OeT7O4zzu+33u+/26rusWNLJSN6ahoqLi
pKaiIt///7UP/e8T1y/xr5ubBFrjecFWnW0PDOHpmqRHHK78rsr2ghJWD5cN
bOF6C9kwpRDw1H+rvo796KcyVGWHwy/XI62r2H25iTN/BaOg5NHWlWXsh8vi
vKFKcXBSW6ZxEduLiKP6ZyMBOgUKlf9ipxUIRFVkJ4Nab6jtHDY/K++Qtnkq
lEdUnpnGvutLXTsjmA7euufLJ7B9nNFZn+5MUDtB/B7Fptov8jpI6T3wnLpW
MIwdfuSMxbeELDjsPiA9gL2PMX9SeOMD9E/P4QUSiGnNkTE/OwdCFF2Sm7El
nI/FULPkQaGw4Zc6bM540U5l83xYahRl/4R9MsuF6BUsgqCGHcdysWVYr0iI
OBdDUrYy/Tvs0NWTTebdnyDlQ11cLLaDNEu7k1IZeNAxWT7HfpZ7doL/bxkU
5SX/CsI+7GpXXpFQDs61A+1O2H+sRGO2bFTAKx/bDE3sfwfXawKzq+B9s13D
eWy9OBrvQ0bVYPq6MUIe+05v/2TTzhr4mOMvLort9jDwDbN5LUwZy6jObxBo
i3Nr1BPBelA/Tl0+gj2mEHdVtLketgns6+/GXmDal/zZqQGol104i7Evvaie
W+9qBGKvnbcLNnfAUc+jSi1A926XiiV2Yr2bH82rFpAXZSvWw+b05VRrnm+B
HU2CUSewvbwHOEwTWmFMM+oKZZ1Apsd/GESst4FzgEyxOvYS52rpz49fQVWH
X+MEdvAQf9syaydM7zPxEsZOKTztymzdCVK2O4vn1gjEbNSUKHOgC84f6LMJ
wDbX6x5xT+oG0bnGzYxVvF4ppl6a8O/QnNGoEoxdc0qjg4XyHQR2SB21wT5t
lKXCp9YLJqNHuqWwt+1dzj22ow8GPLfezl4hECt74qlbXv3QcTEtNWGZQBM1
I/qthYPAMKiU4YIdWDC80D42CPz+Vy7oYF/VclTo5BqCmpqy6yzYPrvYJr45
DMEX97Gq+0sESuCyfdAn+QMe7uYvk1okUGxyTmnHm2G4va6mZjhPoBcio3wu
L0fA/OnahiS2iptgmlb1CMzcY75Cjz2a6dQtOTcCSXTmK6kUAsXFfBMeOT8K
F/x4xCfnCDS0wKhzbnkUpquo+IxmCWSSKJu+cm0MMgy09Jj+4Osl48vFtnsS
XLVMuTumCETZv0QZQJMgyLTsHIW91JKhn2kxCfEH4pAYtuk/YgOKnychQ5cv
A00SKOrbZcd7dlMweuo1r8E43o/+DxwLWv/A5pbIOzojBGr8cGx2rnoG9Nc6
/biw2UKprtzqnYFcR+5rnb8IJE0v8ODr7AwIbH1PuYytns29mss7C5M+IHfq
J/4/tq2MO9jOwoOOBrbdPwh064ib+PjeOQjM3Nr8qA/njZjxWNQ9Cugw9Noc
xs5ILH9B50eBg7s6y370EkhR5fC6RSwFIn6funkOu77q7/DJLxT4/Ie/cOd3
Atn0SAt845+HwhvT74O6CSSilr6dtn4emtSN6y+2E0j+4VHrPYILQJNnED7d
RqBxXbfGc/8uwN6D/Wsh2BGLXtUOlxbg3NrdpLZWAlX/4fNrdV4AvTNbr6q1
EGjdiVPFo2cBfvCmnDnZiPdnXbJBS+giEExd12urCVRVkjnGw7AMGUnyPQX5
BLJKdPqoPbYKhlaFtBewuX+xpw5trAJXTVfX9zx8/3AkHDLbtQbv59Zd13IJ
pNR8ecYB1qD02v4W2RwCtSXnngwMX4NtIQ9tkrII9I0S/y5JYR1kD3l+ln1D
oFrp02+dIjdAN2mY3fglXs+w24WBRCp0XFY809cOr/eobdSiDy2K5M1101XC
+ayn9J5DmwGdpKfJaOMiUEHk04j981tRF/2M9/NBEaS6i608tWw7EowKVi1O
EUF+Y2HMNleZEeuCKyOTmQi6TPdOft6cBTkcPhoTIyCC7A3S+B5XsiKJ/I4d
M13CyLas88jLTTakkDCa+M5TGInph7uvXN6F+Gh5dvj8I4yE5uivPY7YjRJW
pJp8OoRQBp3IzZIyDqRUR0gw2wihYgnqAOoNTjT9hVHNdacQEpCg/ZdWgBs1
dF01qYwTRJuyZ60VNPagSEm2sl2HBZHhFmUXF0ce1NReE/GxTACFPoyh7Pbi
RTsPXztrdUYAQUnbjGHsXvSBgXOf1Qt+dHVivlItlg/5C8c84kjmQ/Qf6H92
PuNH2Qv/7GsJ24vW9LbtkDsvgDJbyw7IBPOiY6uxdDeLBVDIJ9bcOnMeNFQc
TR8oLYio231KqRT3oIAumz3ZyYIo7Jh/x+2D3CiGtXjbV0Yh9CwvcQta4ESv
je7eCrUTQnNfHrMlN3IgxoiFV3EtQig0NkHudvJu9JzjB9IUFUZddRedhfV3
Iak1VQMFN2Gku9IcmyzKjg55rv262CSMRun7GOpbWVF7p1+m/V4RJO/9qnUh
kAVZv3zldcBIBE0RNLXTL5jR9ujoisg4EfR+r4KNVNd2xHfaQi6vXwSFtEdn
WshtQwFjJvYG7ASy+C2zOX+LATk/MeoOUyTQl+ED9A9CaZHg4w8Tg7YEKuXu
z/WYokIcQ1YmrREEio8erFgbokLBtNmVN57j3Lo+4+7QSYXsLINLZrHFUrft
MSulQhr91IEskbjuhvzIU35KhdSaAgPORxFoz1Px7k1pKrR9mmlXWizOjTvu
MiZLG7D1nK4UXyq+jxNUjJ6xr8EHscRDg3hfOJxIMphaX4X+fTzTl/C+CfOv
nVL6vQoXVZW1S7G9LzR/Wi3G30vWiMcUEGjmoZyMvskqyMpvr9AsIlD+++F2
5oIVuMOHyj6WEKi/YJRXUH8Zntwqnz5SRaDesmc9lueWQZt9YDgcm+LQKFUs
uQwlEq7uK9j+RcqFV7YsQ60rKqjA+zr4SZvA4/dLkLcetedSLc41bf/YJpol
sG82SLxWTyBGt6elvK8XoLUivUIU58b4dUa6hqcLUJdswu+GHbhxbe6hE84Z
p4793dhUInmNXWoLkFBZqeCDcwcxWfgGrv0FtvMN/kM4p4SvTmmOqf0F7khj
V+9OAhmEOTy+tUaBvD/r35/inJN6cyl+2ygFIjmTGgawB9EB27etFEh78dXs
IM7F65wyEospFFCg7UyrwY7Nvn/QS40Crw0OoCWcqzofWUxCU+Yg016y6vwg
gTxcKtgeXZ6FJ48297/FOf2F0iKiKDsLw9EzhovYTc/vj7EIzULIVScZhHOd
N+5QQDJlBtTu6xe2YCfczjhVHzEDBLM4MYXrQnP2jVeshdMgebzOi30M57rs
kPurtklQeNp1hwPXHVV+40GhpEnIYqjU0MCecJUoSbGfhNOewj3B2OpaoysZ
XJPwWANKt+C6JngrPvij/gQorn8en8MWYtrXlzY+Bi1PhKtzZwgk2vCiFNGM
wiLtDZ95XDfLhk/ptHeOwOLpa4OCuK5S3Q+MMk4fgWu7jYdVseW60nc90RyB
lYzPo6+x1U8kUepTfkFqidvYlb8E4qqVW1a48BOKJLRb4hdwX5EadbGZ/ydE
dj74Uof9JV9WQ3d+GE6kJlvOYs+59t+zjxmGVyYiOYDrvvPLmyJJ0z9APj35
eDe2lqJoHSV0CHRdZESXcZ+ww0LO3cl0CKK5hst5cB/BlSb9l05uCLTqQxnk
sT/UWbLvHhkEqZubge7YNK4ZJyT/HQRfutkwOty3LIZdiivP7wO/V80eK9jp
97kP1N/oA5oq90+cuM+RsBw708HYByLoSII0dnTrpNAv3V5wsXEzu4u93aww
h5r6O/jlDE33YEvSyRuKnu8GStGF78m4z7KRZGntG++CGkXaD6XYyjJT7aEB
XXD0YrLwN2zhd4ERG82dULeS0sWI+7Zqozb55qtfYdA1zMMM++RBYyuPpQ7o
dw894oZd2x8ER192gIufo2MENr3Q3arIvnZI4lz+Xo7d8KEsQv9WG5wzKBpm
x32klpQDhZmhDXRqRk1FsRV5Lq2XvG4FxaNLvsexf7tI8PNNtEDT58pIA+yG
MeWIrOEmYPJZW0/Crmasdtsh2gT5v0AnB9u/IH7Q9E4jvP10S60Ku7Z1CzPf
bD3um9VYfmKPjt9x8diohSsSWS28ZF9vUm3bo1ALPflLtOLY7xqjFyW8akA9
nr9Nhpxr8pXKBrZXg0U6I1zCPj71g1HmUhV81m3q08FetPSm+D/7DA+CrDlN
sBOa7TJkuCtBJ+XS9UfYqncfe/rrVkCleICxF3bWV3GGwdhyoLZIYQzGPhhe
zeO7rwys7e2IeGxlS3rzvPYSMB4notKwe20/s+jrfII8+5z0LPJ8GSSb0m4X
wvxJ85gy7N1gSVH9kw//SD91qSHnrACmFMq9PNDKD11pJM+vtn3y+WoOpKbb
snZg17T4NZ3wyAaBuYOV37BFPJbUBrZ+hBCbqp3k3DRbPOzsEZwFUayyi+Rc
9cqIXZvgeA+5Rb6Ov7HFMqI7gmUzYd/17IhJbK7FXOsOxTdA3VekOoM9Zk0b
xqX5Gg4fiY2nYCeN7FTRvZEEt8/qBy9gnxK9kxJrGQ+SO5c5yTmxngHdqFqM
hkl3qxPkHKny0mVGme05lIaWL6+Rc9a79N0tB55CyslpdXIOle6v6koL8gZr
hyVFck7NHNGUtJL2hhNCOSqkw582BEj3eAFnpo466Tjj+wqlhBesGRjqkX5z
uCqto9gTXI5ftSUt2JZI+9LIE6r7te+T/sllqWew1RN4jRSdSJcuVbOMa3jA
X/oeL9L198McNsfdwKBi4vl/x7fuaf4c4gb8BjLRpPPpdor5ybjBnx6zONIP
avxyxehcodDKP5X0ysgPZ01JJ2BgLsgjfYdicXjA+RHIJyoXkZ4U7hk0q3sI
3pxVJaSXigxPuxo6gkLMvSrSytlSW94EOYD53pJW0mfPT+RJ99gDT3pEB+lt
M/6mpYQ99HBqdZFulPOv6yi2A8+g8F7ScoYTjgZb7cDyBesAaU3/Y+LjGrZg
6u4wRFqrOsJvc9wafGdWfpHOVks/7idjDe8c9vwmLV6g91WMzgp+fhcaJx1w
f3u4pqQFPDz9Z+q/4x/MmTeruwO9Z7OmSasUnNJ0NTSDC6J6s6SHDu5kfxNk
Alo+VvOkWYXVbEsJY5in7/xLuqLaqbWj+CbE3iQWSd8qCz0yrmEEWnF6S6SN
7Z8Hb44bgmCxyzJp0wi2PjE6A1jK9V0h7d729aWmpC70hzxaJT1r9kjL1VAb
2s9fWyMdIcrA8SboKnQO8ayTVj3k2N5RrAGjWnX/eTGuK2Rz/DJsfWewQbo3
7Fy0pqQKHPvZ/58FJyrx7xXBnrz9sMGGgi0DfOTlwPbbOOF970ztyf89Z/k/
gt6LUg==
       "]]}}, {{}, {}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.832885283134289`, 1.9101299543362336`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {10.336618828644992`, 3.762221576582356}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {9.526279441628825, 5.5}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {8.42648887430876, 7.070663706551931}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {7.070663706551931, 8.42648887430876}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {5.5, 9.526279441628825}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {3.762221576582356, 10.336618828644992`}}]}, 
     {GrayLevel[0.5], Opacity[0.5], 
      LineBox[{{0., 0.}, {1.9101299543362336`, 10.832885283134289`}}]}}}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotLabel->FormBox["\"Array Gain for drive [1,1,1,1]\"", TraditionalForm],
  PlotRange->{{0, 11}, {0, 11}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.41475874897104*^9, 3.414759401247591*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{816, 843},
WindowMargins->{{144, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 92, 1, 76, "Title"],
Cell[685, 26, 1254, 23, 123, "Text"],
Cell[1942, 51, 1383, 38, 39, "Input"],
Cell[3328, 91, 434, 7, 59, "Text"],
Cell[3765, 100, 1049, 25, 63, "Input"],
Cell[4817, 127, 4080, 116, 114, "Input"],
Cell[8900, 245, 290, 6, 28, "Input"],
Cell[9193, 253, 124, 2, 39, "Input"],
Cell[9320, 257, 286, 5, 43, "Text"],
Cell[9609, 264, 763, 20, 80, "Input"],
Cell[10375, 286, 989, 15, 91, "Text"],
Cell[CellGroupData[{
Cell[11389, 305, 1927, 38, 80, "Input"],
Cell[13319, 345, 93172, 1545, 393, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106528, 1895, 1820, 37, 80, "Input"],
Cell[108351, 1934, 91951, 1526, 393, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[200339, 3465, 1820, 37, 80, "Input"],
Cell[202162, 3504, 89129, 1480, 393, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[291328, 4989, 1819, 36, 80, "Input"],
Cell[293150, 5027, 92817, 1540, 393, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[386004, 6572, 2215, 46, 97, "Input"],
Cell[388222, 6620, 83226, 1384, 393, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[471485, 8009, 2167, 44, 97, "Input"],
Cell[473655, 8055, 89986, 1495, 393, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[563678, 9555, 2160, 44, 97, "Input"],
Cell[565841, 9601, 91472, 1519, 393, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[657350, 11125, 1863, 38, 80, "Input"],
Cell[659216, 11165, 91963, 1527, 393, "Output"]
}, Open  ]],
Cell[751194, 12695, 785, 11, 91, "Text"],
Cell[CellGroupData[{
Cell[752004, 12710, 208, 5, 28, "Input"],
Cell[752215, 12717, 171893, 2840, 393, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
